@@ -22,7 +22,7 @@ class MWException extends Exception {
 	function useOutputPage() {
 		return $this->useMessageCache() &&
 			!empty( $GLOBALS['wgFullyInitialised'] ) &&
-			( !empty( $GLOBALS['wgArticle'] ) || ( !empty( $GLOBALS['wgOut'] ) && !$GLOBALS['wgOut']->isArticle() ) ) &&
+			!empty( $GLOBALS['wgOut'] ) &&
 			!empty( $GLOBALS['wgTitle'] );
 	}
 
@@ -39,7 +39,7 @@ class MWException extends Exception {
 			}
 		}
 
-		return is_object( $wgLang );
+		return $wgLang instanceof Language;
 	}
 
 	/**
@@ -88,7 +88,7 @@ class MWException extends Exception {
 		$args = array_slice( func_get_args(), 2 );
 
 		if ( $this->useMessageCache() ) {
-			return wfMsgReal( $key, $args );
+			return wfMsgNoTrans( $key, $args );
 		} else {
 			return wfMsgReplaceArgs( $fallback, $args );
 		}
@@ -133,13 +133,8 @@ class MWException extends Exception {
 
 	/* Return titles of this error page */
 	function getPageTitle() {
-		if ( $this->useMessageCache() ) {
-			return wfMsg( 'internalerror' );
-		} else {
-			global $wgSitename;
-
-			return "$wgSitename error";
-		}
+		global $wgSitename;
+		return $this->msg( 'internalerror', "$wgSitename error" );
 	}
 
 	/**
@@ -155,7 +150,7 @@ class MWException extends Exception {
 		$line = $this->getLine();
 		$message = $this->getMessage();
 
-		if ( isset( $wgRequest ) ) {
+		if ( isset( $wgRequest ) && !$wgRequest instanceof FauxRequest ) {
 			$url = $wgRequest->getRequestURL();
 			if ( !$url ) {
 				$url = '[no URL]';
@@ -170,7 +165,6 @@ class MWException extends Exception {
 	/** Output the exception report using HTML */
 	function reportHTML() {
 		global $wgOut;
-
 		if ( $this->useOutputPage() ) {
 			$wgOut->setPageTitle( $this->getPageTitle() );
 			$wgOut->setRobotPolicy( "noindex,nofollow" );
@@ -193,13 +187,8 @@ class MWException extends Exception {
 				die( $hookResult );
 			}
 
-			if ( defined( 'MEDIAWIKI_INSTALL' ) || $this->htmlBodyOnly() ) {
-				echo $this->getHTML();
-			} else {
-				echo $this->htmlHeader();
-				echo $this->getHTML();
-				echo $this->htmlFooter();
-			}
+			echo $this->getHTML();
+			die(1);
 		}
 	}
 
@@ -215,55 +204,14 @@ class MWException extends Exception {
 		}
 
 		if ( self::isCommandLine() ) {
-			wfPrintError( $this->getText() );
+			MWExceptionHandler::printError( $this->getText() );
 		} else {
 			$this->reportHTML();
 		}
 	}
 
-	/**
-	 * Send headers and output the beginning of the html page if not using
-	 * $wgOut to output the exception.
-	 */
-	function htmlHeader() {
-		global $wgLogo, $wgOutputEncoding;
-
-		if ( !headers_sent() ) {
-			header( 'HTTP/1.0 500 Internal Server Error' );
-			header( 'Content-type: text/html; charset=' . $wgOutputEncoding );
-			/* Don't cache error pages!  They cause no end of trouble... */
-			header( 'Cache-control: none' );
-			header( 'Pragma: nocache' );
-		}
-
-		$logo = htmlspecialchars( $wgLogo, ENT_QUOTES );
-		$title = htmlspecialchars( $this->getPageTitle() );
-
-		return "<html>
-		<head>
-		<title>$title</title>
-		</head>
-		<body>
-		<h1><img src='$logo' style='float:left;margin-right:1em' alt=''/>$title</h1>
-		";
-	}
-
-	/**
-	 * print the end of the html page if not using $wgOut.
-	 */
-	function htmlFooter() {
-		return "</body></html>";
-	}
-
-	/**
-	 * headers handled by subclass?
-	 */
-	function htmlBodyOnly() {
-		return false;
-	}
-
 	static function isCommandLine() {
-		return !empty( $GLOBALS['wgCommandLineMode'] ) && !defined( 'MEDIAWIKI_INSTALL' );
+		return !empty( $GLOBALS['wgCommandLineMode'] );
 	}
 }
 
@@ -283,122 +231,253 @@ class FatalError extends MWException {
 }
 
 /**
+ * An error page which can definitely be safely rendered using the OutputPage
  * @ingroup Exception
  */
 class ErrorPageError extends MWException {
-	public $title, $msg;
+	public $title, $msg, $params;
 
 	/**
 	 * Note: these arguments are keys into wfMsg(), not text!
 	 */
-	function __construct( $title, $msg ) {
+	function __construct( $title, $msg, $params = null ) {
 		$this->title = $title;
 		$this->msg = $msg;
-		parent::__construct( wfMsg( $msg ) );
+		$this->params = $params;
+
+		if( $msg instanceof Message ){
+			parent::__construct( $msg );
+		} else {
+			parent::__construct( wfMsg( $msg ) );
+		}
 	}
 
 	function report() {
 		global $wgOut;
 
-		$wgOut->showErrorPage( $this->title, $this->msg );
+		$wgOut->showErrorPage( $this->title, $this->msg, $this->params );
 		$wgOut->output();
 	}
 }
 
 /**
- * Install an exception handler for MediaWiki exception types.
+ * Show an error when a user tries to do something they do not have the necessary
+ * permissions for.
+ * @ingroup Exception
  */
-function wfInstallExceptionHandler() {
-	set_exception_handler( 'wfExceptionHandler' );
+class PermissionsError extends ErrorPageError {
+	public $permission;
+
+	function __construct( $permission ) {
+		global $wgLang;
+
+		$this->permission = $permission;
+
+		$groups = array_map(
+			array( 'User', 'makeGroupLinkWiki' ),
+			User::getGroupsWithPermission( $this->permission )
+		);
+
+		if( $groups ) {
+			parent::__construct(
+				'badaccess',
+				'badaccess-groups',
+				array(
+					$wgLang->commaList( $groups ),
+					count( $groups )
+				)
+			);
+		} else {
+			parent::__construct(
+				'badaccess',
+				'badaccess-group0'
+			);
+		}
+	}
 }
 
 /**
- * Report an exception to the user
+ * Show an error when the wiki is locked/read-only and the user tries to do
+ * something that requires write access
+ * @ingroup Exception
  */
-function wfReportException( Exception $e ) {
-	global $wgShowExceptionDetails;
+class ReadOnlyError extends ErrorPageError {
+	public function __construct(){
+		parent::__construct(
+			'readonly',
+			'readonlytext',
+			wfReadOnlyReason()
+		);
+	}
+}
 
-	$cmdLine = MWException::isCommandLine();
+/**
+ * Show an error when the user hits a rate limit
+ * @ingroup Exception
+ */
+class ThrottledError extends ErrorPageError {
+	public function __construct(){
+		parent::__construct(
+			'actionthrottled',
+			'actionthrottledtext'
+		);
+	}
+	public function report(){
+		global $wgOut;
+		$wgOut->setStatusCode( 503 );
+		return parent::report();
+	}
+}
 
-	if ( $e instanceof MWException ) {
-		try {
-			$e->report();
-		} catch ( Exception $e2 ) {
-			// Exception occurred from within exception handler
-			// Show a simpler error message for the original exception,
-			// don't try to invoke report()
-			$message = "MediaWiki internal error.\n\n";
+/**
+ * Show an error when the user tries to do something whilst blocked
+ * @ingroup Exception
+ */
+class UserBlockedError extends ErrorPageError {
+	public function __construct( Block $block ){
+		global $wgLang;
+
+		$blockerUserpage = $block->getBlocker()->getUserPage();
+		$link = "[[{$blockerUserpage->getPrefixedText()}|{$blockerUserpage->getText()}]]";
+
+		$reason = $block->mReason;
+		if( $reason == '' ) {
+			$reason = wfMsg( 'blockednoreason' );
+		}
+
+		/* $ip returns who *is* being blocked, $intended contains who was meant to be blocked.
+		 * This could be a username, an IP range, or a single IP. */
+		$intended = $block->getTarget();
+
+		parent::__construct(
+			'blockedtitle',
+			$block->mAuto ? 'autoblockedtext' : 'blockedtext',
+			array(
+				$link,
+				$reason,
+				wfGetIP(),
+				$block->getBlocker()->getName(),
+				$block->getId(),
+				$wgLang->formatExpiry( $block->mExpiry ),
+				$intended,
+				$wgLang->timeanddate( wfTimestamp( TS_MW, $block->mTimestamp ), true )
+			)
+		);
+	}
+}
+
+/**
+ * Handler class for MWExceptions
+ * @ingroup Exception
+ */
+class MWExceptionHandler {
+	/**
+	 * Install an exception handler for MediaWiki exception types.
+	 */
+	public static function installHandler() {
+		set_exception_handler( array( 'MWExceptionHandler', 'handle' ) );
+	}
+
+	/**
+	 * Report an exception to the user
+	 */
+	protected static function report( Exception $e ) {
+		global $wgShowExceptionDetails;
+
+		$cmdLine = MWException::isCommandLine();
+
+		if ( $e instanceof MWException ) {
+			try {
+				// Try and show the exception prettily, with the normal skin infrastructure
+				$e->report();
+			} catch ( Exception $e2 ) {
+				// Exception occurred from within exception handler
+				// Show a simpler error message for the original exception,
+				// don't try to invoke report()
+				$message = "MediaWiki internal error.\n\n";
+
+				if ( $wgShowExceptionDetails ) {
+					$message .= 'Original exception: ' . $e->__toString() . "\n\n" .
+						'Exception caught inside exception handler: ' . $e2->__toString();
+				} else {
+					$message .= "Exception caught inside exception handler.\n\n" .
+						"Set \$wgShowExceptionDetails = true; at the bottom of LocalSettings.php " .
+						"to show detailed debugging information.";
+				}
+
+				$message .= "\n";
+
+				if ( $cmdLine ) {
+					self::printError( $message );
+				} else {
+					self::escapeEchoAndDie( $message );
+				}
+			}
+		} else {
+			$message = "Unexpected non-MediaWiki exception encountered, of type \"" . get_class( $e ) . "\"\n" .
+				$e->__toString() . "\n";
 
 			if ( $wgShowExceptionDetails ) {
-				$message .= 'Original exception: ' . $e->__toString() . "\n\n" .
-					'Exception caught inside exception handler: ' . $e2->__toString();
-			} else {
-				$message .= "Exception caught inside exception handler.\n\n" .
-					"Set \$wgShowExceptionDetails = true; at the bottom of LocalSettings.php " .
-					"to show detailed debugging information.";
+				$message .= "\n" . $e->getTraceAsString() . "\n";
 			}
 
-			$message .= "\n";
-
 			if ( $cmdLine ) {
-				wfPrintError( $message );
+				self::printError( $message );
 			} else {
-				echo nl2br( htmlspecialchars( $message ) ) . "\n";
+				self::escapeEchoAndDie( $message );
 			}
 		}
-	} else {
-		$message = "Unexpected non-MediaWiki exception encountered, of type \"" . get_class( $e ) . "\"\n" .
-			$e->__toString() . "\n";
+	}
 
-		if ( $wgShowExceptionDetails ) {
-			$message .= "\n" . $e->getTraceAsString() . "\n";
-		}
-
-		if ( $cmdLine ) {
-			wfPrintError( $message );
+	/**
+	 * Print a message, if possible to STDERR.
+	 * Use this in command line mode only (see isCommandLine)
+	 * @param $message String Failure text
+	 */
+	public static function printError( $message ) {
+		# NOTE: STDERR may not be available, especially if php-cgi is used from the command line (bug #15602).
+		#      Try to produce meaningful output anyway. Using echo may corrupt output to STDOUT though.
+		if ( defined( 'STDERR' ) ) {
+			fwrite( STDERR, $message );
 		} else {
-			echo nl2br( htmlspecialchars( $message ) ) . "\n";
+			echo( $message );
 		}
 	}
-}
 
-/**
- * Print a message, if possible to STDERR.
- * Use this in command line mode only (see isCommandLine)
- */
-function wfPrintError( $message ) {
-	# NOTE: STDERR may not be available, especially if php-cgi is used from the command line (bug #15602).
-	#      Try to produce meaningful output anyway. Using echo may corrupt output to STDOUT though.
-	if ( defined( 'STDERR' ) ) {
-		fwrite( STDERR, $message );
-	} else {
-		echo( $message );
-	}
-}
-
-/**
- * Exception handler which simulates the appropriate catch() handling:
- *
- *   try {
- *       ...
- *   } catch ( MWException $e ) {
- *       $e->report();
- *   } catch ( Exception $e ) {
- *       echo $e->__toString();
- *   }
- */
-function wfExceptionHandler( $e ) {
-	global $wgFullyInitialised;
-
-	wfReportException( $e );
-
-	// Final cleanup
-	if ( $wgFullyInitialised ) {
-		try {
-			wfLogProfilingData(); // uses $wgRequest, hence the $wgFullyInitialised condition
-		} catch ( Exception $e ) {}
+	/**
+	 * Print a message after escaping it and converting newlines to <br>
+	 * Use this for non-command line failures
+	 * @param $message String Failure text
+	 */
+	private static function escapeEchoAndDie( $message ) {
+		echo nl2br( htmlspecialchars( $message ) ) . "\n";
+		die(1);
 	}
 
-	// Exit value should be nonzero for the benefit of shell jobs
-	exit( 1 );
+	/**
+	 * Exception handler which simulates the appropriate catch() handling:
+	 *
+	 *   try {
+	 *       ...
+	 *   } catch ( MWException $e ) {
+	 *       $e->report();
+	 *   } catch ( Exception $e ) {
+	 *       echo $e->__toString();
+	 *   }
+	 */
+	public static function handle( $e ) {
+		global $wgFullyInitialised;
+
+		self::report( $e );
+
+		// Final cleanup
+		if ( $wgFullyInitialised ) {
+			try {
+				wfLogProfilingData(); // uses $wgRequest, hence the $wgFullyInitialised condition
+			} catch ( Exception $e ) {}
+		}
+
+		// Exit value should be nonzero for the benefit of shell jobs
+		exit( 1 );
+	}
 }
