@@ -9,12 +9,9 @@ if ( ! defined( 'MEDIAWIKI' ) )
  *
  * @ingroup Media
  */
-class ImageGallery
-{
+class ImageGallery {
 	var $mImages, $mShowBytes, $mShowFilename;
 	var $mCaption = false;
-	var $mSkin = false;
-	var $mRevisionId = 0;
 
 	/**
 	 * Hide blacklisted images?
@@ -23,6 +20,7 @@ class ImageGallery
 
 	/**
 	 * Registered parser object for output callbacks
+	 * @var Parser
 	 */
 	var $mParser;
 
@@ -39,13 +37,13 @@ class ImageGallery
 	 */
 	const THUMB_PADDING = 30;
 	const GB_PADDING = 5;
-	//2px borders on each side + 2px implied padding on each side
+	// 2px borders on each side + 2px implied padding on each side
 	const GB_BORDERS = 8;
 
 	/**
 	 * Create a new image gallery object.
 	 */
-	function __construct( ) {
+	function __construct() {
 		global $wgGalleryOptions;
 		$this->mImages = array();
 		$this->mShowBytes = $wgGalleryOptions['showBytes'];
@@ -60,6 +58,8 @@ class ImageGallery
 
 	/**
 	 * Register a parser object
+	 *
+	 * @param $parser Parser
 	 */
 	function setParser( $parser ) {
 		$this->mParser = $parser;
@@ -97,7 +97,7 @@ class ImageGallery
 	 * invalid numbers will be rejected
 	 */
 	public function setPerRow( $num ) {
-		if ($num >= 0) {
+		if ( $num >= 0 ) {
 			$this->mPerRow = (int)$num;
 		}
 	}
@@ -108,7 +108,7 @@ class ImageGallery
 	 * @param $num Integer > 0; invalid numbers will be ignored
 	 */
 	public function setWidths( $num ) {
-		if ($num > 0) {
+		if ( $num > 0 ) {
 			$this->mWidths = (int)$num;
 		}
 	}
@@ -119,7 +119,7 @@ class ImageGallery
 	 * @param $num Integer > 0; invalid numbers will be ignored
 	 */
 	public function setHeights( $num ) {
-		if ($num > 0) {
+		if ( $num > 0 ) {
 			$this->mHeights = (int)$num;
 		}
 	}
@@ -128,56 +128,44 @@ class ImageGallery
 	 * Instruct the class to use a specific skin for rendering
 	 *
 	 * @param $skin Skin object
+	 * @deprecated since 1.18 Not used anymore
 	 */
 	function useSkin( $skin ) {
-		$this->mSkin = $skin;
-	}
-
-	/**
-	 * Return the skin that should be used
-	 *
-	 * @return Skin object
-	 */
-	function getSkin() {
-		if( !$this->mSkin ) {
-			global $wgUser;
-			$skin = $wgUser->getSkin();
-		} else {
-			$skin = $this->mSkin;
-		}
-		return $skin;
+		wfDeprecated( __METHOD__ );
+		/* no op */
 	}
 
 	/**
 	 * Add an image to the gallery.
 	 *
 	 * @param $title Title object of the image that is added to the gallery
-	 * @param $html  String: additional HTML text to be shown. The name and size of the image are always shown.
+	 * @param $html  String: Additional HTML text to be shown. The name and size of the image are always shown.
+	 * @param $alt   String: Alt text for the image
 	 */
-	function add( $title, $html='' ) {
+	function add( $title, $html = '', $alt = '' ) {
 		if ( $title instanceof File ) {
 			// Old calling convention
 			$title = $title->getTitle();
 		}
-		$this->mImages[] = array( $title, $html );
-		wfDebug( "ImageGallery::add " . $title->getText() . "\n" );
+		$this->mImages[] = array( $title, $html, $alt );
+		wfDebug( 'ImageGallery::add ' . $title->getText() . "\n" );
 	}
 
 	/**
 	* Add an image at the beginning of the gallery.
 	*
 	* @param $title Title object of the image that is added to the gallery
-	* @param $html  String:  Additional HTML text to be shown. The name and size of the image are always shown.
+	* @param $html  String: Additional HTML text to be shown. The name and size of the image are always shown.
+	* @param $alt   String: Alt text for the image
 	*/
-	function insert( $title, $html='' ) {
+	function insert( $title, $html = '', $alt = '' ) {
 		if ( $title instanceof File ) {
 			// Old calling convention
 			$title = $title->getTitle();
 		}
-		array_unshift( $this->mImages, array( &$title, $html ) );
+		array_unshift( $this->mImages, array( &$title, $html, $alt ) );
 	}
 
-
 	/**
 	 * isEmpty() returns true if the gallery contains no images
 	 */
@@ -231,47 +219,56 @@ class ImageGallery
 	function toHTML() {
 		global $wgLang;
 
-		$sk = $this->getSkin();
-
 		if ( $this->mPerRow > 0 ) {
 			$maxwidth = $this->mPerRow * ( $this->mWidths + self::THUMB_PADDING + self::GB_PADDING + self::GB_BORDERS );
-			$oldStyle = isset( $this->mAttribs['style'] ) ? $this->mAttribs['style'] : ""; 
+			$oldStyle = isset( $this->mAttribs['style'] ) ? $this->mAttribs['style'] : '';
+			# _width is ignored by any sane browser. IE6 doesn't know max-width so it uses _width instead
 			$this->mAttribs['style'] = "max-width: {$maxwidth}px;_width: {$maxwidth}px;" . $oldStyle;
 		}
 
 		$attribs = Sanitizer::mergeAttributes(
-			array(
-				'class' => 'gallery'),
-			$this->mAttribs );
-		$s = Xml::openElement( 'ul', $attribs );
+			array( 'class' => 'gallery' ), $this->mAttribs );
+
+		$output = Xml::openElement( 'ul', $attribs );
 		if ( $this->mCaption ) {
-			$s .= "\n\t<li class='gallerycaption'>{$this->mCaption}</li>";
+			$output .= "\n\t<li class='gallerycaption'>{$this->mCaption}</li>";
 		}
 
-		$params = array( 'width' => $this->mWidths, 'height' => $this->mHeights );
-		$i = 0;
+		$params = array(
+			'width' => $this->mWidths,
+			'height' => $this->mHeights
+		);
+		# Output each image...
 		foreach ( $this->mImages as $pair ) {
 			$nt = $pair[0];
 			$text = $pair[1]; # "text" means "caption" here
+			$alt = $pair[2];
 
-			# Give extensions a chance to select the file revision for us
-			$time = $descQuery = false;
-			wfRunHooks( 'BeforeGalleryFindFile', array( &$this, &$nt, &$time, &$descQuery ) );
-
+			$descQuery = false;
 			if ( $nt->getNamespace() == NS_FILE ) {
-				$img = wfFindFile( $nt, array( 'time' => $time ) );
+				# Get the file...
+				if ( $this->mParser instanceof Parser ) {
+					# Give extensions a chance to select the file revision for us
+					$time = $sha1 = false;
+					wfRunHooks( 'BeforeParserFetchFileAndTitle',
+						array( $this->mParser, $nt, &$time, &$sha1, &$descQuery ) );
+					# Fetch and register the file (file title may be different via hooks)
+					list( $img, $nt ) = $this->mParser->fetchFileAndTitle( $nt, $time, $sha1 );
+				} else {
+					$img = wfFindFile( $nt );
+				}
 			} else {
 				$img = false;
 			}
 
 			if( !$img ) {
 				# We're dealing with a non-image, spit out the name and be done with it.
-				$thumbhtml = "\n\t\t\t".'<div style="height: '.(self::THUMB_PADDING + $this->mHeights).'px;">'
+				$thumbhtml = "\n\t\t\t" . '<div style="height: ' . ( self::THUMB_PADDING + $this->mHeights ) . 'px;">'
 					. htmlspecialchars( $nt->getText() ) . '</div>';
 			} elseif( $this->mHideBadImages && wfIsBadImage( $nt->getDBkey(), $this->getContextTitle() ) ) {
 				# The image is blacklisted, just show it as a text link.
-				$thumbhtml = "\n\t\t\t".'<div style="height: '.(self::THUMB_PADDING + $this->mHeights).'px;">' .
-					$sk->link(
+				$thumbhtml = "\n\t\t\t" . '<div style="height: ' . ( self::THUMB_PADDING + $this->mHeights ) . 'px;">' .
+					Linker::link(
 						$nt,
 						htmlspecialchars( $nt->getText() ),
 						array(),
@@ -281,31 +278,28 @@ class ImageGallery
 					'</div>';
 			} elseif( !( $thumb = $img->transform( $params ) ) ) {
 				# Error generating thumbnail.
-				$thumbhtml = "\n\t\t\t".'<div style="height: '.(self::THUMB_PADDING + $this->mHeights).'px;">'
+				$thumbhtml = "\n\t\t\t" . '<div style="height: ' . ( self::THUMB_PADDING + $this->mHeights ) . 'px;">'
 					. htmlspecialchars( $img->getLastError() ) . '</div>';
 			} else {
-				//We get layout problems with the margin, if the image is smaller 
-				//than the line-height, so we less margin in these cases.
-				$minThumbHeight =  $thumb->height > 17 ? $thumb->height : 17;
-				$vpad = floor(( self::THUMB_PADDING + $this->mHeights - $minThumbHeight ) /2);
-				
-				
+				$vpad = ( self::THUMB_PADDING + $this->mHeights - $thumb->height ) /2;
+
 				$imageParameters = array(
 					'desc-link' => true,
-					'desc-query' => $descQuery
+					'desc-query' => $descQuery,
+					'alt' => $alt,
 				);
-				# In the absence of a caption, fall back on providing screen readers with the filename as alt text
-				if ( $text == '' ) {
+				# In the absence of both alt text and caption, fall back on providing screen readers with the filename as alt text
+				if ( $alt == '' && $text == '' ) {
 					$imageParameters['alt'] = $nt->getText();
 				}
-				
+
 				# Set both fixed width and min-height.
-				$thumbhtml = "\n\t\t\t".
-					'<div class="thumb" style="width: ' .($this->mWidths + self::THUMB_PADDING).'px;">'
+				$thumbhtml = "\n\t\t\t" .
+					'<div class="thumb" style="width: ' . ( $this->mWidths + self::THUMB_PADDING ) . 'px;">'
 					# Auto-margin centering for block-level elements. Needed now that we have video
 					# handlers since they may emit block-level elements as opposed to simple <img> tags.
 					# ref http://css-discuss.incutio.com/?page=CenteringBlockElement
-					. '<div style="margin:'.$vpad.'px auto;">'
+					. '<div style="margin:' . $vpad . 'px auto;">'
 					. $thumb->toHtml( $imageParameters ) . '</div></div>';
 
 				// Call parser transform hook
@@ -316,22 +310,22 @@ class ImageGallery
 
 			//TODO
 			// $linkTarget = Title::newFromText( $wgContLang->getNsText( MWNamespace::getUser() ) . ":{$ut}" );
-			// $ul = $sk->link( $linkTarget, $ut );
+			// $ul = Linker::link( $linkTarget, $ut );
 
 			if( $this->mShowBytes ) {
 				if( $img ) {
-					$nb = wfMsgExt( 'nbytes', array( 'parsemag', 'escape'),
+					$fileSize = wfMsgExt( 'nbytes', array( 'parsemag', 'escape'),
 						$wgLang->formatNum( $img->getSize() ) );
 				} else {
-					$nb = wfMsgHtml( 'filemissing' );
+					$fileSize = wfMsgHtml( 'filemissing' );
 				}
-				$nb = "$nb<br />\n";
+				$fileSize = "$fileSize<br />\n";
 			} else {
-				$nb = '';
+				$fileSize = '';
 			}
 
 			$textlink = $this->mShowFilename ?
-				$sk->link(
+				Linker::link(
 					$nt,
 					htmlspecialchars( $wgLang->truncate( $nt->getText(), $this->mCaptionLength ) ),
 					array(),
@@ -344,21 +338,20 @@ class ImageGallery
 			# in version 4.8.6 generated crackpot html in its absence, see:
 			# http://bugzilla.wikimedia.org/show_bug.cgi?id=1765 -Ævar
 
-			# Weird double wrapping in div needed due to FF2 bug
+			# Weird double wrapping (the extra div inside the li) needed due to FF2 bug
 			# Can be safely removed if FF2 falls completely out of existance
-			$s .=
+			$output .=
 				"\n\t\t" . '<li class="gallerybox" style="width: ' . ( $this->mWidths + self::THUMB_PADDING + self::GB_PADDING ) . 'px">'
 					. '<div style="width: ' . ( $this->mWidths + self::THUMB_PADDING + self::GB_PADDING ) . 'px">'
 					. $thumbhtml
 					. "\n\t\t\t" . '<div class="gallerytext">' . "\n"
-						. $textlink . $text . $nb
+						. $textlink . $text . $fileSize
 					. "\n\t\t\t</div>"
 				. "\n\t\t</div></li>";
-			++$i;
 		}
-		$s .= "\n</ul>";
+		$output .= "\n</ul>";
 
-		return $s;
+		return $output;
 	}
 
 	/**
