@@ -117,14 +117,6 @@ unknown/unknown application/octet-stream application/x-empty [UNKNOWN]
 END_STRING
 );
 
-#note: because this file is possibly included by a function,
-#we need to access the global scope explicitely!
-global $wgLoadFileinfoExtension;
-
-if ($wgLoadFileinfoExtension) {
-	wfDl( 'fileinfo' );
-}
-
 /**
  * Implements functions related to mime types such as detection and mapping to
  * file extension.
@@ -138,19 +130,19 @@ class MimeMagic {
 	* Mapping of media types to arrays of mime types.
 	* This is used by findMediaType and getMediaType, respectively
 	*/
-	var $mMediaTypes= null;
+	var $mMediaTypes = null;
 
 	/** Map of mime type aliases
 	*/
-	var $mMimeTypeAliases= null;
+	var $mMimeTypeAliases = null;
 
 	/** map of mime types to file extensions (as a space seprarated list)
 	*/
-	var $mMimeToExt= null;
+	var $mMimeToExt = null;
 
 	/** map of file extensions types to mime types (as a space seprarated list)
 	*/
-	var $mExtToMime= null;
+	var $mExtToMime = null;
 
 	/** IEContentAnalyzer instance
 	 */
@@ -160,16 +152,20 @@ class MimeMagic {
 	 */
 	private static $instance;
 
+	/** True if the fileinfo extension has been loaded
+	 */
+	private static $extensionLoaded = false;
+
 	/** Initializes the MimeMagic object. This is called by MimeMagic::singleton().
-	*
-	* This constructor parses the mime.types and mime.info files and build internal mappings.
-	*/
+	 *
+	 * This constructor parses the mime.types and mime.info files and build internal mappings.
+	 */
 	function __construct() {
-		/*
+		/**
 		*   --- load mime.types ---
 		*/
 
-		global $wgMimeTypeFile, $IP;
+		global $wgMimeTypeFile, $IP, $wgLoadFileinfoExtension;
 
 		$types = MM_WELL_KNOWN_MIME_TYPES;
 
@@ -177,6 +173,11 @@ class MimeMagic {
 			$wgMimeTypeFile = "$IP/$wgMimeTypeFile";
 		}
 
+		if ( $wgLoadFileinfoExtension && !self::$extensionLoaded ) {
+			self::$extensionLoaded = true;
+			wfDl( 'fileinfo' );
+		}
+
 		if ( $wgMimeTypeFile ) {
 			if ( is_file( $wgMimeTypeFile ) and is_readable( $wgMimeTypeFile ) ) {
 				wfDebug( __METHOD__.": loading mime types from $wgMimeTypeFile\n" );
@@ -198,20 +199,28 @@ class MimeMagic {
 		$lines = explode( "\n",$types );
 		foreach ( $lines as $s ) {
 			$s = trim( $s );
-			if ( empty( $s ) ) continue;
-			if ( strpos( $s, '#' ) === 0 ) continue;
+			if ( empty( $s ) ) {
+				continue;
+			}
+			if ( strpos( $s, '#' ) === 0 ) {
+				continue;
+			}
 
 			$s = strtolower( $s );
 			$i = strpos( $s, ' ' );
 
-			if ( $i === false ) continue;
+			if ( $i === false ) {
+				continue;
+			}
 
 			#print "processing MIME line $s<br>";
 
 			$mime = substr( $s, 0, $i );
 			$ext = trim( substr($s, $i+1 ) );
 
-			if ( empty( $ext ) ) continue;
+			if ( empty( $ext ) ) {
+				continue;
+			}
 
 			if ( !empty( $this->mMimeToExt[$mime] ) ) {
 				$this->mMimeToExt[$mime] .= ' ' . $ext;
@@ -223,7 +232,9 @@ class MimeMagic {
 
 			foreach ( $extensions as $e ) {
 				$e = trim( $e );
-				if ( empty( $e ) ) continue;
+				if ( empty( $e ) ) {
+					continue;
+				}
 
 				if ( !empty( $this->mExtToMime[$e] ) ) {
 					$this->mExtToMime[$e] .= ' ' . $mime;
@@ -233,9 +244,9 @@ class MimeMagic {
 			}
 		}
 
-		/*
-		*   --- load mime.info ---
-		*/
+		/**
+		 *   --- load mime.info ---
+		 */
 
 		global $wgMimeInfoFile;
 		if ( $wgMimeInfoFile == 'includes/mime.info' ) {
@@ -265,13 +276,19 @@ class MimeMagic {
 		$lines = explode( "\n", $info );
 		foreach ( $lines as $s ) {
 			$s = trim( $s );
-			if ( empty( $s ) ) continue;
-			if ( strpos( $s, '#' ) === 0 ) continue;
+			if ( empty( $s ) ) {
+				continue;
+			}
+			if ( strpos( $s, '#' ) === 0 ) {
+				continue;
+			}
 
 			$s = strtolower( $s );
 			$i = strpos( $s, ' ' );
 
-			if ( $i === false ) continue;
+			if ( $i === false ) {
+				continue;
+			}
 
 			#print "processing MIME INFO line $s<br>";
 
@@ -291,7 +308,9 @@ class MimeMagic {
 
 			foreach ( $m as $mime ) {
 				$mime = trim( $mime );
-				if ( empty( $mime ) ) continue;
+				if ( empty( $mime ) ) {
+					continue;
+				}
 
 				$this->mMediaTypes[$mtype][] = $mime;
 			}
@@ -309,47 +328,70 @@ class MimeMagic {
 
 	/**
 	 * Get an instance of this class
+	 * @return MimeMagic
 	 */
-	static function &singleton() {
+	public static function &singleton() {
 		if ( !isset( self::$instance ) ) {
 			self::$instance = new MimeMagic;
 		}
 		return self::$instance;
 	}
 
-	/** returns a list of file extensions for a given mime type
-	* as a space separated string.
-	*/
-	function getExtensionsForType( $mime ) {
+	/** 
+	 * Returns a list of file extensions for a given mime type as a space 
+	 * separated string or null if the mime type was unrecognized. Resolves
+	 * mime type aliases.
+	 * 
+	 * @param $mime string
+	 * @return string|null
+	 */
+	public function getExtensionsForType( $mime ) {
 		$mime = strtolower( $mime );
 
-		$r = @$this->mMimeToExt[$mime];
-
-		if ( @!$r and isset( $this->mMimeTypeAliases[$mime] ) ) {
-			$mime = $this->mMimeTypeAliases[$mime];
-			$r = @$this->mMimeToExt[$mime];
+		// Check the mime-to-ext map
+		if ( isset( $this->mMimeToExt[$mime] ) ) {
+			return $this->mMimeToExt[$mime];
 		}
 
-		return $r;
+		// Resolve the mime type to the canonical type
+		if ( isset( $this->mMimeTypeAliases[$mime] ) ) {
+			$mime = $this->mMimeTypeAliases[$mime];
+			if ( isset( $this->mMimeToExt[$mime] ) ) {
+				return $this->mMimeToExt[$mime];
+			}
+		}
+
+		return null;
 	}
 
-	/** returns a list of mime types for a given file extension
-	* as a space separated string.
-	*/
-	function getTypesForExtension( $ext ) {
+	/** 
+	 * Returns a list of mime types for a given file extension as a space 
+	 * separated string or null if the extension was unrecognized.
+	 * 
+	 * @param $ext string
+	 * @return string|null
+	 */
+	public function getTypesForExtension( $ext ) {
 		$ext = strtolower( $ext );
 
 		$r = isset( $this->mExtToMime[$ext] ) ? $this->mExtToMime[$ext] : null;
 		return $r;
 	}
 
-	/** returns a single mime type for a given file extension.
-	* This is always the first type from the list returned by getTypesForExtension($ext).
-	*/
-	function guessTypesForExtension( $ext ) {
+	/** 
+	 * Returns a single mime type for a given file extension or null if unknown.
+	 * This is always the first type from the list returned by getTypesForExtension($ext).
+	 * 
+	 * @param $ext string
+	 * @return string|null
+	 */
+	public function guessTypesForExtension( $ext ) {
 		$m = $this->getTypesForExtension( $ext );
-		if ( is_null( $m ) ) return null;
+		if ( is_null( $m ) ) {
+			return null;
+		}
 
+		// TODO: Check if this is needed; strtok( $m, ' ' ) should be sufficient
 		$m = trim( $m );
 		$m = preg_replace( '/\s.*$/', '', $m );
 
@@ -357,32 +399,38 @@ class MimeMagic {
 	}
 
 
-	/** tests if the extension matches the given mime type.
-	* returns true if a match was found, NULL if the mime type is unknown,
-	* and false if the mime type is known but no matches where found.
-	*/
-	function isMatchingExtension( $extension, $mime ) {
+	/** 
+	 * Tests if the extension matches the given mime type. Returns true if a 
+	 * match was found, null if the mime type is unknown, and false if the 
+	 * mime type is known but no matches where found.
+	 * 
+	 * @param $extension string
+	 * @param $mime string
+	 * @return bool|null
+	 */
+	public function isMatchingExtension( $extension, $mime ) {
 		$ext = $this->getExtensionsForType( $mime );
 
 		if ( !$ext ) {
-			return null;  //unknown
+			return null;  // Unknown mime type
 		}
 
 		$ext = explode( ' ', $ext );
 
 		$extension = strtolower( $extension );
- 		if ( in_array( $extension, $ext ) ) {
-			return true;
-		}
-
-		return false;
+ 		return  in_array( $extension, $ext );
 	}
 
-	/** returns true if the mime type is known to represent
-	* an image format supported by the PHP GD library.
-	*/
-	function isPHPImageType( $mime ) {
-		#as defined by imagegetsize and image_type_to_mime
+	/** 
+	 * Returns true if the mime type is known to represent an image format 
+	 * supported by the PHP GD library.
+	 *
+	 * @param $mime string
+	 * 
+	 * @return bool
+	 */
+	public function isPHPImageType( $mime ) {
+		// As defined by imagegetsize and image_type_to_mime
 		static $types = array(
 			'image/gif', 'image/jpeg', 'image/png',
 			'image/x-bmp', 'image/xbm', 'image/tiff',
@@ -426,44 +474,45 @@ class MimeMagic {
 		return in_array( strtolower( $extension ), $types );
 	}
 
-	/** improves a mime type using the file extension. Some file formats are very generic,
-	* so their mime type is not very meaningful. A more useful mime type can be derived 
-	* by looking at the file extension. Typically, this method would be called on the 
-	* result of guessMimeType().
-	* 
-	* Currently, this method does the following:
-	*
-	* If $mime is "unknown/unknown" and isRecognizableExtension( $ext ) returns false,
-	* return the result of guessTypesForExtension($ext). 
-	*
-	* If $mime is "application/x-opc+zip" and isMatchingExtension( $ext, $mime )
-	* gives true, return the result of guessTypesForExtension($ext). 
-	*
-	* @param $mime String: the mime type, typically guessed from a file's content.
-	* @param $ext String: the file extension, as taken from the file name
-	*
-	* @return string the mime type
-	*/
-	function improveTypeFromExtension( $mime, $ext ) {
-		if ( $mime === "unknown/unknown" ) {
-			if( $this->isRecognizableExtension( $ext ) ) {
-				wfDebug( __METHOD__. ": refusing to guess mime type for .$ext file, " .
-					"we should have recognized it\n" );
+	/** 
+	 * Improves a mime type using the file extension. Some file formats are very generic,
+	 * so their mime type is not very meaningful. A more useful mime type can be derived 
+	 * by looking at the file extension. Typically, this method would be called on the 
+	 * result of guessMimeType().
+	 * 
+	 * Currently, this method does the following:
+	 *
+	 * If $mime is "unknown/unknown" and isRecognizableExtension( $ext ) returns false,
+	 * return the result of guessTypesForExtension($ext). 
+	 *
+	 * If $mime is "application/x-opc+zip" and isMatchingExtension( $ext, $mime )
+	 * gives true, return the result of guessTypesForExtension($ext). 
+	 *
+	 * @param $mime String: the mime type, typically guessed from a file's content.
+	 * @param $ext String: the file extension, as taken from the file name
+	 *
+	 * @return string the mime type
+	 */
+	public function improveTypeFromExtension( $mime, $ext ) {
+		if ( $mime === 'unknown/unknown' ) {
+			if ( $this->isRecognizableExtension( $ext ) ) {
+				wfDebug( __METHOD__. ': refusing to guess mime type for .' . 
+					"$ext file, we should have recognized it\n" );
 			} else {
-				/* Not something we can detect, so simply 
-				* trust the file extension */
+				// Not something we can detect, so simply 
+				// trust the file extension
 				$mime = $this->guessTypesForExtension( $ext );
 			}
 		}
-		else if ( $mime === "application/x-opc+zip" ) {
+		elseif ( $mime === 'application/x-opc+zip' ) {
 			if ( $this->isMatchingExtension( $ext, $mime ) ) {
-				/* A known file extension for an OPC file,
-				* find the proper mime type for that file extension */
+				// A known file extension for an OPC file,
+				// find the proper mime type for that file extension
 				$mime = $this->guessTypesForExtension( $ext );
 			} else {
 				wfDebug( __METHOD__. ": refusing to guess better type for $mime file, " . 
 					".$ext is not a known OPC extension.\n" );
-				$mime = "application/zip";
+				$mime = 'application/zip';
 			}
 		}
 
@@ -475,20 +524,22 @@ class MimeMagic {
 		return $mime;
 	}
 
-	/** mime type detection. This uses detectMimeType to detect the mime type of the file,
-	* but applies additional checks to determine some well known file formats that may be missed
-	* or misinterpreter by the default mime detection (namely XML based formats like XHTML or SVG,
-	* as well as ZIP based formats like OPC/ODF files).
-	*
-	* @param $file String: the file to check
-	* @param $ext Mixed: the file extension, or true (default) to extract it from the filename.
-	*             Set it to false to ignore the extension. DEPRECATED! Set to false, use 
-	*             improveTypeFromExtension($mime, $ext) later to improve mime type.
-	*
-	* @return string the mime type of $file
-	*/
-	function guessMimeType( $file, $ext = true ) {
-		if( $ext ) { # TODO: make $ext default to false. Or better, remove it.
+	/** 
+	 * Mime type detection. This uses detectMimeType to detect the mime type 
+	 * of the file, but applies additional checks to determine some well known 
+	 * file formats that may be missed or misinterpreter by the default mime 
+	 * detection (namely XML based formats like XHTML or SVG, as well as ZIP 
+	 * based formats like OPC/ODF files).
+	 *
+	 * @param $file String: the file to check
+	 * @param $ext Mixed: the file extension, or true (default) to extract it from the filename.
+	 *             Set it to false to ignore the extension. DEPRECATED! Set to false, use 
+	 *             improveTypeFromExtension($mime, $ext) later to improve mime type.
+	 *
+	 * @return string the mime type of $file
+	 */
+	public function guessMimeType( $file, $ext = true ) {
+		if ( $ext ) { // TODO: make $ext default to false. Or better, remove it.
 			wfDebug( __METHOD__.": WARNING: use of the \$ext parameter is deprecated. " .
 				"Use improveTypeFromExtension(\$mime, \$ext) instead.\n" );
 		}
@@ -508,12 +559,22 @@ class MimeMagic {
 		return $mime;
 	}
 
-	private function doGuessMimeType( $file, $ext ) { # TODO: remove $ext param
+	/**
+	 * Guess the mime type from the file contents.
+	 *
+	 * @param string $file
+	 * @param mixed $ext
+	 */
+	private function doGuessMimeType( $file, $ext ) { // TODO: remove $ext param
 		// Read a chunk of the file
 		wfSuppressWarnings();
-		$f = fopen( $file, "rt" );
+		// @todo FIXME: Shouldn't this be rb?
+		$f = fopen( $file, 'rt' );
 		wfRestoreWarnings();
-		if( !$f ) return "unknown/unknown";
+		
+		if( !$f ) {
+			return 'unknown/unknown';
+		}
 		$head = fread( $f, 1024 );
 		fseek( $f, -65558, SEEK_END );
 		$tail = fread( $f, 65558 ); // 65558 = maximum size of a zip EOCDR
@@ -540,23 +601,23 @@ class MimeMagic {
 			"\x7fELF"          => 'application/octet-stream', // ELF binary
 		);
 
-		foreach( $headers as $magic => $candidate ) {
-			if( strncmp( $head, $magic, strlen( $magic ) ) == 0 ) {
+		foreach ( $headers as $magic => $candidate ) {
+			if ( strncmp( $head, $magic, strlen( $magic ) ) == 0 ) {
 				wfDebug( __METHOD__ . ": magic header in $file recognized as $candidate\n" );
 				return $candidate;
 			}
 		}
 
 		/* Look for WebM and Matroska files */
-		if( strncmp( $head, pack( "C4", 0x1a, 0x45, 0xdf, 0xa3 ), 4 ) == 0 ) {
+		if ( strncmp( $head, pack( "C4", 0x1a, 0x45, 0xdf, 0xa3 ), 4 ) == 0 ) {
 			$doctype = strpos( $head, "\x42\x82" );
-			if( $doctype ) {
+			if ( $doctype ) {
 				// Next byte is datasize, then data (sizes larger than 1 byte are very stupid muxers)
 				$data = substr($head, $doctype+3, 8);
-				if( strncmp( $data, "matroska", 8 ) == 0 ) {
+				if ( strncmp( $data, "matroska", 8 ) == 0 ) {
 					wfDebug( __METHOD__ . ": recognized file as video/x-matroska\n" );
 					return "video/x-matroska";
-				} else if ( strncmp( $data, "webm", 4 ) == 0 ) {
+				} elseif ( strncmp( $data, "webm", 4 ) == 0 ) {
 					wfDebug( __METHOD__ . ": recognized file as video/webm\n" );
 					return "video/webm";
 				}
@@ -566,24 +627,24 @@ class MimeMagic {
 		}
 
 		/* Look for WebP */
-		if( strncmp( $head, "RIFF", 4 ) == 0 && strncmp( substr( $head, 8, 8), "WEBPVP8 ", 8 ) == 0 ) {
+		if ( strncmp( $head, "RIFF", 4 ) == 0 && strncmp( substr( $head, 8, 8), "WEBPVP8 ", 8 ) == 0 ) {
 			wfDebug( __METHOD__ . ": recognized file as image/webp\n" );
 			return "image/webp";
 		}
 
-		/*
+		/**
 		 * Look for PHP.  Check for this before HTML/XML...  Warning: this is a
 		 * heuristic, and won't match a file with a lot of non-PHP before.  It
 		 * will also match text files which could be PHP. :)
 		 *
-		 * FIXME: For this reason, the check is probably useless -- an attacker
+		 * @todo FIXME: For this reason, the check is probably useless -- an attacker
 		 * could almost certainly just pad the file with a lot of nonsense to
 		 * circumvent the check in any case where it would be a security
 		 * problem.  On the other hand, it causes harmful false positives (bug
 		 * 16583).  The heuristic has been cut down to exclude three-character
 		 * strings like "<? ", but should it be axed completely?
 		 */
-		if( ( strpos( $head, '<?php' ) !== false ) ||
+		if ( ( strpos( $head, '<?php' ) !== false ) ||
 
 		    ( strpos( $head, "<\x00?\x00p\x00h\x00p" ) !== false ) ||
 		    ( strpos( $head, "<\x00?\x00 " ) !== false ) ||
@@ -592,23 +653,23 @@ class MimeMagic {
 		    ( strpos( $head, "<\x00?\x00=" ) !== false ) ) {
 
 			wfDebug( __METHOD__ . ": recognized $file as application/x-php\n" );
-			return "application/x-php";
+			return 'application/x-php';
 		}
 
-		/*
+		/**
 		 * look for XML formats (XHTML and SVG)
 		 */
 		$xml = new XmlTypeCheck( $file );
-		if( $xml->wellFormed ) {
+		if ( $xml->wellFormed ) {
 			global $wgXMLMimeTypes;
-			if( isset( $wgXMLMimeTypes[$xml->getRootElement()] ) ) {
+			if ( isset( $wgXMLMimeTypes[$xml->getRootElement()] ) ) {
 				return $wgXMLMimeTypes[$xml->getRootElement()];
 			} else {
 				return 'application/xml';
 			}
 		}
 
-		/*
+		/**
 		 * look for shell scripts
 		 */
 		$script_type = null;
@@ -718,18 +779,18 @@ class MimeMagic {
 
 		$openxmlRegex = "/^\[Content_Types\].xml/";
 
-		if( preg_match( $opendocRegex, substr( $header, 30 ), $matches ) ) {
+		if ( preg_match( $opendocRegex, substr( $header, 30 ), $matches ) ) {
 			$mime = $matches[1];
 			wfDebug( __METHOD__.": detected $mime from ZIP archive\n" );
-		} elseif( preg_match( $openxmlRegex, substr( $header, 30 ) ) ) {
+		} elseif ( preg_match( $openxmlRegex, substr( $header, 30 ) ) ) {
 			$mime = "application/x-opc+zip";
 			# TODO: remove the block below, as soon as improveTypeFromExtension is used everywhere 
-			if( $ext !== true && $ext !== false ) { 
+			if ( $ext !== true && $ext !== false ) { 
 				/** This is the mode used by getPropsFromPath
 				* These mime's are stored in the database, where we don't really want
 				* x-opc+zip, because we use it only for internal purposes
 				*/
-				if( $this->isMatchingExtension( $ext, $mime) ) {
+				if ( $this->isMatchingExtension( $ext, $mime) ) {
 					/* A known file extension for an OPC file,
 					* find the proper mime type for that file extension */
 					$mime = $this->guessTypesForExtension( $ext );
@@ -738,10 +799,10 @@ class MimeMagic {
 				}
 			}
 			wfDebug( __METHOD__.": detected an Open Packaging Conventions archive: $mime\n" );
-		} else if( substr( $header, 0, 8 ) == "\xd0\xcf\x11\xe0\xa1\xb1\x1a\xe1" && 
+		} elseif ( substr( $header, 0, 8 ) == "\xd0\xcf\x11\xe0\xa1\xb1\x1a\xe1" && 
 				($headerpos = strpos( $tail, "PK\x03\x04" ) ) !== false &&
 				preg_match( $openxmlRegex, substr( $tail, $headerpos + 30 ) ) ) {
-			if( substr( $header, 512, 4) == "\xEC\xA5\xC1\x00" ) {
+			if ( substr( $header, 512, 4) == "\xEC\xA5\xC1\x00" ) {
 				$mime = "application/msword";
 			} 
 			switch( substr( $header, 512, 6) ) {
@@ -773,31 +834,34 @@ class MimeMagic {
 		return $mime;
 	}
 
-	/** Internal mime type detection, please use guessMimeType() for application code instead.
-	* Detection is done using an external program, if $wgMimeDetectorCommand is set.
-	* Otherwise, the fileinfo extension and mime_content_type are tried (in this order), if they are available.
-	* If the dections fails and $ext is not false, the mime type is guessed from the file extension, using
-	* guessTypesForExtension.
-	* If the mime type is still unknown, getimagesize is used to detect the mime type if the file is an image.
-	* If no mime type can be determined, this function returns "unknown/unknown".
-	*
-	* @param $file String: the file to check
-	* @param $ext Mixed: the file extension, or true (default) to extract it from the filename.
-	*             Set it to false to ignore the extension. DEPRECATED! Set to false, use 
-	*             improveTypeFromExtension($mime, $ext) later to improve mime type.
-	*
-	* @return string the mime type of $file
-	* @access private
-	*/
+	/** 
+	 * Internal mime type detection. Detection is done using an external 
+	 * program, if $wgMimeDetectorCommand is set. Otherwise, the fileinfo 
+	 * extension and mime_content_type are tried (in this order), if they 
+	 * are available. If the dections fails and $ext is not false, the mime 
+	 * type is guessed from the file extension, using guessTypesForExtension.
+	 * 
+	 * If the mime type is still unknown, getimagesize is used to detect the 
+	 * mime type if the file is an image. If no mime type can be determined, 
+	 * this function returns 'unknown/unknown'.
+	 *
+	 * @param $file String: the file to check
+	 * @param $ext Mixed: the file extension, or true (default) to extract it from the filename.
+	 *             Set it to false to ignore the extension. DEPRECATED! Set to false, use 
+	 *             improveTypeFromExtension($mime, $ext) later to improve mime type.
+	 *
+	 * @return string the mime type of $file
+	 */
 	private function detectMimeType( $file, $ext = true ) {
 		global $wgMimeDetectorCommand;
 
-		if( $ext ) { # TODO:  make $ext default to false. Or better, remove it.
+		if ( $ext ) { # TODO:  make $ext default to false. Or better, remove it.
 			wfDebug( __METHOD__.": WARNING: use of the \$ext parameter is deprecated. Use improveTypeFromExtension(\$mime, \$ext) instead.\n" );
 		}
 
 		$m = null;
 		if ( $wgMimeDetectorCommand ) {
+			// @todo FIXME: Use wfShellExec
 			$fn = wfEscapeShellArg( $file );
 			$m = `$wgMimeDetectorCommand $fn`;
 		} elseif ( function_exists( "finfo_open" ) && function_exists( "finfo_file" ) ) {
@@ -812,9 +876,9 @@ class MimeMagic {
 			# If you may need to load the fileinfo extension at runtime, set
 			# $wgLoadFileinfoExtension in LocalSettings.php
 
-			$mime_magic_resource = finfo_open(FILEINFO_MIME); /* return mime type ala mimetype extension */
+			$mime_magic_resource = finfo_open( FILEINFO_MIME ); /* return mime type ala mimetype extension */
 
-			if ($mime_magic_resource) {
+			if ( $mime_magic_resource ) {
 				$m = finfo_file( $mime_magic_resource, $file );
 				finfo_close( $mime_magic_resource );
 			} else {
@@ -850,7 +914,7 @@ class MimeMagic {
 			}
 		}
 
-		# if desired, look at extension as a fallback.
+		// If desired, look at extension as a fallback.
 		if ( $ext === true ) {
 			$i = strrpos( $file, '.' );
 			$ext = strtolower( $i ? substr( $file, $i + 1 ) : '' );
@@ -867,36 +931,40 @@ class MimeMagic {
 			}
 		}
 
-		#unknown type
-		wfDebug( __METHOD__.": failed to guess mime type for $file!\n" );
-		return "unknown/unknown";
+		// Unknown type
+		wfDebug( __METHOD__ . ": failed to guess mime type for $file!\n" );
+		return 'unknown/unknown';
 	}
 
 	/**
-	* Determine the media type code for a file, using its mime type, name and possibly
-	* its contents.
-	*
-	* This function relies on the findMediaType(), mapping extensions and mime
-	* types to media types.
-	*
-	* @todo analyse file if need be
-	* @todo look at multiple extension, separately and together.
-	*
-	* @param $path String: full path to the image file, in case we have to look at the contents
-	*        (if null, only the mime type is used to determine the media type code).
-	* @param $mime String: mime type. If null it will be guessed using guessMimeType.
-	*
-	* @return (int?string?) a value to be used with the MEDIATYPE_xxx constants.
-	*/
+	 * Determine the media type code for a file, using its mime type, name and
+	 * possibly its contents.
+	 *
+	 * This function relies on the findMediaType(), mapping extensions and mime
+	 * types to media types.
+	 *
+	 * @todo analyse file if need be
+	 * @todo look at multiple extension, separately and together.
+	 *
+	 * @param $path String: full path to the image file, in case we have to look at the contents
+	 *        (if null, only the mime type is used to determine the media type code).
+	 * @param $mime String: mime type. If null it will be guessed using guessMimeType.
+	 *
+	 * @return (int?string?) a value to be used with the MEDIATYPE_xxx constants.
+	 */
 	function getMediaType( $path = null, $mime = null ) {
-		if( !$mime && !$path ) return MEDIATYPE_UNKNOWN;
+		if( !$mime && !$path ) {
+			return MEDIATYPE_UNKNOWN;
+		}
 
-		# If mime type is unknown, guess it
-		if( !$mime ) $mime = $this->guessMimeType( $path, false );
+		// If mime type is unknown, guess it
+		if( !$mime ) {
+			$mime = $this->guessMimeType( $path, false );
+		}
 
-		# Special code for ogg - detect if it's video (theora),
-		# else label it as sound.
-		if( $mime == "application/ogg" && file_exists( $path ) ) {
+		// Special code for ogg - detect if it's video (theora),
+		// else label it as sound.
+		if ( $mime == 'application/ogg' && file_exists( $path ) ) {
 
 			// Read a chunk of the file
 			$f = fopen( $path, "rt" );
@@ -906,7 +974,7 @@ class MimeMagic {
 
 			$head = strtolower( $head );
 
-			# This is an UGLY HACK, file should be parsed correctly
+			// This is an UGLY HACK, file should be parsed correctly
 			if ( strpos( $head, 'theora' ) !== false ) return MEDIATYPE_VIDEO;
 			elseif ( strpos( $head, 'vorbis' ) !== false ) return MEDIATYPE_AUDIO;
 			elseif ( strpos( $head, 'flac' ) !== false ) return MEDIATYPE_AUDIO;
@@ -914,58 +982,69 @@ class MimeMagic {
 			else return MEDIATYPE_MULTIMEDIA;
 		}
 
-		# check for entry for full mime type
+		// Check for entry for full mime type
 		if( $mime ) {
 			$type = $this->findMediaType( $mime );
-			if( $type !== MEDIATYPE_UNKNOWN ) return $type;
+			if ( $type !== MEDIATYPE_UNKNOWN ) {
+				return $type;
+			}
 		}
 
-		# Check for entry for file extension
+		// Check for entry for file extension
 		if ( $path ) {
 			$i = strrpos( $path, '.' );
 			$e = strtolower( $i ? substr( $path, $i + 1 ) : '' );
 
-			# TODO: look at multi-extension if this fails, parse from full path
-
+			// TODO: look at multi-extension if this fails, parse from full path
 			$type = $this->findMediaType( '.' . $e );
-			if ( $type !== MEDIATYPE_UNKNOWN ) return $type;
-		}
-
-		# Check major mime type
-		if( $mime ) {
-			$i = strpos( $mime, '/' );
-			if( $i !== false ) {
-				$major = substr( $mime, 0, $i );
-				$type = $this->findMediaType( $major );
-				if( $type !== MEDIATYPE_UNKNOWN ) return $type;
+			if ( $type !== MEDIATYPE_UNKNOWN ) {
+				return $type;
 			}
 		}
 
-		if( !$type ) $type = MEDIATYPE_UNKNOWN;
+		// Check major mime type
+		if ( $mime ) {
+			$i = strpos( $mime, '/' );
+			if ( $i !== false ) {
+				$major = substr( $mime, 0, $i );
+				$type = $this->findMediaType( $major );
+				if ( $type !== MEDIATYPE_UNKNOWN ) {
+					return $type;
+				}
+			}
+		}
+
+		if( !$type ) {
+			$type = MEDIATYPE_UNKNOWN;
+		}
 
 		return $type;
 	}
 
-	/** returns a media code matching the given mime type or file extension.
-	* File extensions are represented by a string starting with a dot (.) to
-	* distinguish them from mime types.
-	*
-	* This funktion relies on the mapping defined by $this->mMediaTypes
-	* @access private
-	*/
+	/** 
+	 * Returns a media code matching the given mime type or file extension.
+	 * File extensions are represented by a string starting with a dot (.) to
+	 * distinguish them from mime types.
+	 *
+	 * This funktion relies on the mapping defined by $this->mMediaTypes
+	 * @access private
+	 */
 	function findMediaType( $extMime ) {
-		if ( strpos( $extMime, '.' ) === 0 ) { #if it's an extension, look up the mime types
+		if ( strpos( $extMime, '.' ) === 0 ) { 
+			// If it's an extension, look up the mime types
 			$m = $this->getTypesForExtension( substr( $extMime, 1 ) );
-			if ( !$m ) return MEDIATYPE_UNKNOWN;
+			if ( !$m ) {
+				return MEDIATYPE_UNKNOWN;
+			}
 
 			$m = explode( ' ', $m );
 		} else {
-			# Normalize mime type
+			// Normalize mime type
 			if ( isset( $this->mMimeTypeAliases[$extMime] ) ) {
 				$extMime = $this->mMimeTypeAliases[$extMime];
 			}
 
-			$m = array($extMime);
+			$m = array( $extMime );
 		}
 
 		foreach ( $m as $mime ) {
@@ -994,6 +1073,8 @@ class MimeMagic {
 
 	/**
 	 * Get a cached instance of IEContentAnalyzer
+	 *
+	 * @return IEContentAnalyzer
 	 */
 	protected function getIEContentAnalyzer() {
 		if ( is_null( $this->mIEAnalyzer ) ) {
