@@ -31,8 +31,11 @@
 class WikiError {
 	/**
 	 * @param $message string
+	 *
+	 * @deprecated since 1.17
 	 */
 	function __construct( $message ) {
+		wfDeprecated( __METHOD__ );
 		$this->mMessage = $message;
 	}
 
@@ -58,8 +61,11 @@ class WikiError {
 	 *
 	 * @param $object mixed
 	 * @return bool
+	 *
+	 * @deprecated since 1.17
 	 */
 	public static function isError( $object ) {
+		wfDeprecated( __METHOD__ );
 		if ( $object instanceof WikiError ) {
 			return true;
 		} elseif ( $object instanceof Status ) {
@@ -78,8 +84,11 @@ class WikiErrorMsg extends WikiError {
 	/**
 	 * @param $message String: wiki message name
 	 * @param ... parameters to pass to wfMsg()
+	 *
+	 * @deprecated since 1.17
 	 */
 	function __construct( $message/*, ... */ ) {
+		wfDeprecated( __METHOD__ );
 		$args = func_get_args();
 		array_shift( $args );
 		$this->mMessage = wfMsgReal( $message, $args, true );
@@ -107,8 +116,11 @@ class WikiXmlError extends WikiError {
 	 * @param $message string
 	 * @param $context
 	 * @param $offset Int
+	 *
+	 * @deprecated since 1.17
 	 */
 	function __construct( $parser, $message = 'XML parsing error', $context = null, $offset = 0 ) {
+		wfDeprecated( __METHOD__ );
 		$this->mXmlError = xml_get_error_code( $parser );
 		$this->mColumn = xml_get_current_column_number( $parser );
 		$this->mLine = xml_get_current_line_number( $parser );
