@@ -1,6 +1,6 @@
 <?php
 /**
- * API for MediaWiki 1.8+
+ *
  *
  * Created on July 7, 2007
  *
@@ -52,6 +52,10 @@ class ApiQueryAllLinks extends ApiQueryGeneratorBase {
 		$this->run( $resultPageSet );
 	}
 
+	/**
+	 * @param $resultPageSet ApiPageSet
+	 * @return void
+	 */
 	private function run( $resultPageSet = null ) {
 		$db = $this->getDB();
 		$params = $this->extractRequestParams();
@@ -90,27 +94,22 @@ class ApiQueryAllLinks extends ApiQueryGeneratorBase {
 			);
 		}
 
-		if ( !is_null( $params['from'] ) ) {
-			$this->addWhere( 'pl_title>=' . $db->addQuotes( $this->titlePartToKey( $params['from'] ) ) );
-		}
-		if ( !is_null( $params['to'] ) ) {
-			$this->addWhere( 'pl_title<=' . $db->addQuotes( $this->titlePartToKey( $params['to'] ) ) );
-		}
+		$from = ( is_null( $params['from'] ) ? null : $this->titlePartToKey( $params['from'] ) );
+		$to = ( is_null( $params['to'] ) ? null : $this->titlePartToKey( $params['to'] ) );
+		$this->addWhereRange( 'pl_title', 'newer', $from, $to );
+
 		if ( isset( $params['prefix'] ) ) {
 			$this->addWhere( 'pl_title' . $db->buildLike( $this->titlePartToKey( $params['prefix'] ), $db->anyString() ) );
 		}
 
-		$this->addFields( array(
-			'pl_title',
-		) );
+		$this->addFields( 'pl_title' );
 		$this->addFieldsIf( 'pl_from', !$params['unique'] );
 
 		$this->addOption( 'USE INDEX', 'pl_namespace' );
 		$limit = $params['limit'];
 		$this->addOption( 'LIMIT', $limit + 1 );
-		if ( $params['unique'] ) {
-			$this->addOption( 'ORDER BY', 'pl_title' );
-		} else {
+
+		if ( !$params['unique'] ) {
 			$this->addOption( 'ORDER BY', 'pl_title, pl_from' );
 		}
 
@@ -228,7 +227,11 @@ class ApiQueryAllLinks extends ApiQueryGeneratorBase {
 		);
 	}
 
+	public function getHelpUrls() {
+		return 'https://www.mediawiki.org/wiki/API:Alllinks';
+	}
+
 	public function getVersion() {
-		return __CLASS__ . ': $Id$';
+		return __CLASS__ . ': $Id: ApiQueryAllLinks.php 104449 2011-11-28 15:52:04Z reedy $';
 	}
 }
