@@ -47,7 +47,8 @@ class ApiRsd extends ApiBase {
 
 		$service = array( 'apis' => $this->formatRsdApiList() );
 		ApiResult::setContent( $service, 'MediaWiki', 'engineName' );
-		ApiResult::setContent( $service, 'http://www.mediawiki.org/', 'engineLink' );
+		ApiResult::setContent( $service, 'https://www.mediawiki.org/', 'engineLink' );
+		ApiResult::setContent( $service, Title::newMainPage()->getCanonicalUrl(), 'homePageLink' );
 
 		$result->setIndexedTagName( $service['apis'], 'api' );
 
@@ -67,7 +68,7 @@ class ApiRsd extends ApiBase {
 	}
 
 	public function getDescription() {
-		return 'Export an RSD schema';
+		return 'Export an RSD (Really Simple Discovery) schema';
 	}
 
 	protected function getExamples() {
@@ -97,10 +98,10 @@ class ApiRsd extends ApiBase {
 		$apis = array(
 			'MediaWiki' => array(
 				// The API link is required for all RSD API entries.
-				'apiLink' => wfExpandUrl( wfScript( 'api' ) ),
+				'apiLink' => wfExpandUrl( wfScript( 'api' ), PROTO_CURRENT ),
 
 				// Docs link is optional, but recommended.
-				'docs' => 'http://mediawiki.org/wiki/API',
+				'docs' => 'https://www.mediawiki.org/wiki/API',
 
 				// Some APIs may need a blog ID, but it may be left blank.
 				'blogID' => '',
@@ -160,7 +161,7 @@ class ApiRsd extends ApiBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id$';
+		return __CLASS__ . ': $Id: ApiRsd.php 104449 2011-11-28 15:52:04Z reedy $';
 	}
 }
 
@@ -169,12 +170,12 @@ class ApiFormatXmlRsd extends ApiFormatXml {
 		parent::__construct( $main, $format );
 		$this->setRootElement( 'rsd' );
 	}
-	
+
 	public function getMimeType() {
 		return 'application/rsd+xml';
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id$';
+		return __CLASS__ . ': $Id: ApiRsd.php 104449 2011-11-28 15:52:04Z reedy $';
 	}
 }
