@@ -51,7 +51,7 @@
 * @author Matt Knapp <mdknapp[at]gmail[dot]com>
 * @author Brett Stimmerman <brettstimmerman[at]gmail[dot]com>
 * @copyright 2005 Michal Migurski
-* @version CVS: $Id$
+* @version CVS: $Id: Services_JSON.php 95607 2011-08-27 19:28:13Z hashar $
 * @license http://www.opensource.org/licenses/bsd-license.php
 * @see http://pear.php.net/pepr/pepr-proposal-show.php?id=198
 */
@@ -168,7 +168,7 @@ class Services_JSON
 			return mb_convert_encoding($utf16, 'UTF-8', 'UTF-16');
 		}
 
-		$bytes = (ord($utf16{0}) << 8) | ord($utf16{1});
+		$bytes = (ord($utf16[0]) << 8) | ord($utf16[1]);
 
 		switch(true) {
 			case ((0x7F & $bytes) == $bytes):
@@ -182,11 +182,11 @@ class Services_JSON
 				return chr(0xC0 | (($bytes >> 6) & 0x1F))
 					 . chr(0x80 | ($bytes & 0x3F));
 
-			case (0xFC00 & $bytes) == 0xD800 && strlen($utf16) >= 4 && (0xFC & ord($utf16{2})) == 0xDC:
+			case (0xFC00 & $bytes) == 0xD800 && strlen($utf16) >= 4 && (0xFC & ord($utf16[2])) == 0xDC:
 				// return a 4-byte UTF-8 character
 				$char = ((($bytes & 0x03FF) << 10)
-					   | ((ord($utf16{2}) & 0x03) << 8)
-					   | ord($utf16{3}));
+					   | ((ord($utf16[2]) & 0x03) << 8)
+					   | ord($utf16[3]));
 				$char += 0x10000;
 				return chr(0xF0 | (($char >> 18) & 0x07))
 					 . chr(0x80 | (($char >> 12) & 0x3F))
@@ -232,25 +232,25 @@ class Services_JSON
 			case 2:
 				// return a UTF-16 character from a 2-byte UTF-8 char
 				// see: http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-				return chr(0x07 & (ord($utf8{0}) >> 2))
-					 . chr((0xC0 & (ord($utf8{0}) << 6))
-						 | (0x3F & ord($utf8{1})));
+				return chr(0x07 & (ord($utf8[0]) >> 2))
+					 . chr((0xC0 & (ord($utf8[0]) << 6))
+						 | (0x3F & ord($utf8[1])));
 
 			case 3:
 				// return a UTF-16 character from a 3-byte UTF-8 char
 				// see: http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-				return chr((0xF0 & (ord($utf8{0}) << 4))
-						 | (0x0F & (ord($utf8{1}) >> 2)))
-					 . chr((0xC0 & (ord($utf8{1}) << 6))
-						 | (0x7F & ord($utf8{2})));
+				return chr((0xF0 & (ord($utf8[0]) << 4))
+						 | (0x0F & (ord($utf8[1]) >> 2)))
+					 . chr((0xC0 & (ord($utf8[1]) << 6))
+						 | (0x7F & ord($utf8[2])));
 
 			case 4:
 				// return a UTF-16 surrogate pair from a 4-byte UTF-8 char
-				if(ord($utf8{0}) > 0xF4) return ''; # invalid
-				$char = ((0x1C0000 & (ord($utf8{0}) << 18))
-					   | (0x03F000 & (ord($utf8{1}) << 12))
-					   | (0x000FC0 & (ord($utf8{2}) << 6))
-					   | (0x00003F & ord($utf8{3})));
+				if(ord($utf8[0]) > 0xF4) return ''; # invalid
+				$char = ((0x1C0000 & (ord($utf8[0]) << 18))
+					   | (0x03F000 & (ord($utf8[1]) << 12))
+					   | (0x000FC0 & (ord($utf8[2]) << 6))
+					   | (0x00003F & ord($utf8[3])));
 				if($char > 0x10FFFF) return ''; # invalid
 				$char -= 0x10000;
 				return chr(0xD8 | (($char >> 18) & 0x03))
@@ -331,7 +331,7 @@ class Services_JSON
 				*/
 				for ($c = 0; $c < $strlen_var; ++$c) {
 
-					$ord_var_c = ord($var{$c});
+					$ord_var_c = ord($var[$c]);
 
 					switch (true) {
 						case $ord_var_c == 0x08:
@@ -354,18 +354,18 @@ class Services_JSON
 						case $ord_var_c == 0x2F:
 						case $ord_var_c == 0x5C:
 							// double quote, slash, slosh
-							$ascii .= '\\'.$var{$c};
+							$ascii .= '\\'.$var[$c];
 							break;
 
 						case (($ord_var_c >= 0x20) && ($ord_var_c <= 0x7F)):
 							// characters U-00000000 - U-0000007F (same as ASCII)
-							$ascii .= $var{$c};
+							$ascii .= $var[$c];
 							break;
 
 						case (($ord_var_c & 0xE0) == 0xC0):
 							// characters U-00000080 - U-000007FF, mask 110XXXXX
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
-							$char = pack('C*', $ord_var_c, ord($var{$c + 1}));
+							$char = pack('C*', $ord_var_c, ord($var[$c + 1]));
 							$c += 1;
 							$utf16 = $this->utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -375,8 +375,8 @@ class Services_JSON
 							// characters U-00000800 - U-0000FFFF, mask 1110XXXX
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
 							$char = pack('C*', $ord_var_c,
-									ord($var{$c + 1}),
-									ord($var{$c + 2}));
+									ord($var[$c + 1]),
+									ord($var[$c + 2]));
 							$c += 2;
 							$utf16 = $this->utf82utf16($char);
 							$ascii .= sprintf('\u%04s', bin2hex($utf16));
@@ -387,9 +387,9 @@ class Services_JSON
 							// see http://www.cl.cam.ac.uk/~mgk25/unicode.html#utf-8
 							// These will always return a surrogate pair
 							$char = pack('C*', $ord_var_c,
-									ord($var{$c + 1}),
-									ord($var{$c + 2}),
-									ord($var{$c + 3}));
+									ord($var[$c + 1]),
+									ord($var[$c + 2]),
+									ord($var[$c + 3]));
 							$c += 3;
 							$utf16 = $this->utf82utf16($char);
 							if($utf16 == '') {
@@ -575,7 +575,7 @@ class Services_JSON
 					for ($c = 0; $c < $strlen_chrs; ++$c) {
 
 						$substr_chrs_c_2 = substr($chrs, $c, 2);
-						$ord_chrs_c = ord($chrs{$c});
+						$ord_chrs_c = ord($chrs[$c]);
 
 						switch (true) {
 							case $substr_chrs_c_2 == '\b':
@@ -605,7 +605,7 @@ class Services_JSON
 							case $substr_chrs_c_2 == '\\/':
 								if (($delim == '"' && $substr_chrs_c_2 != '\\\'') ||
 								   ($delim == "'" && $substr_chrs_c_2 != '\\"')) {
-									$utf8 .= $chrs{++$c};
+									$utf8 .= $chrs[++$c];
 								}
 								break;
 
@@ -628,7 +628,7 @@ class Services_JSON
 								break;
 
 							case ($ord_chrs_c >= 0x20) && ($ord_chrs_c <= 0x7F):
-								$utf8 .= $chrs{$c};
+								$utf8 .= $chrs[$c];
 								break;
 
 							case ($ord_chrs_c & 0xE0) == 0xC0:
@@ -675,7 +675,7 @@ class Services_JSON
 				} elseif (preg_match('/^\[.*\]$/s', $str) || preg_match('/^\{.*\}$/s', $str)) {
 					// array, or object notation
 
-					if ($str{0} == '[') {
+					if ($str[0] == '[') {
 						$stk = array(SERVICES_JSON_IN_ARR);
 						$arr = array();
 					} else {
@@ -714,7 +714,7 @@ class Services_JSON
 						$top = end($stk);
 						$substr_chrs_c_2 = substr($chrs, $c, 2);
 
-						if (($c == $strlen_chrs) || (($chrs{$c} == ',') && ($top['what'] == SERVICES_JSON_SLICE))) {
+						if (($c == $strlen_chrs) || (($chrs[$c] == ',') && ($top['what'] == SERVICES_JSON_SLICE))) {
 							// found a comma that is not inside a string, array, etc.,
 							// OR we've reached the end of the character list
 							$slice = substr($chrs, $top['where'], ($c - $top['where']));
@@ -756,37 +756,37 @@ class Services_JSON
 
 							}
 
-						} elseif ((($chrs{$c} == '"') || ($chrs{$c} == "'")) && ($top['what'] != SERVICES_JSON_IN_STR)) {
+						} elseif ((($chrs[$c] == '"') || ($chrs[$c] == "'")) && ($top['what'] != SERVICES_JSON_IN_STR)) {
 							// found a quote, and we are not inside a string
-							array_push($stk, array('what' => SERVICES_JSON_IN_STR, 'where' => $c, 'delim' => $chrs{$c}));
+							array_push($stk, array('what' => SERVICES_JSON_IN_STR, 'where' => $c, 'delim' => $chrs[$c]));
 							//print("Found start of string at {$c}\n");
 
-						} elseif (($chrs{$c} == $top['delim']) &&
+						} elseif (($chrs[$c] == $top['delim']) &&
 								 ($top['what'] == SERVICES_JSON_IN_STR) &&
-								 (($chrs{$c - 1} != '\\') ||
-								 ($chrs{$c - 1} == '\\' && $chrs{$c - 2} == '\\'))) {
+								 (($chrs[$c - 1] != '\\') ||
+								 ($chrs[$c - 1] == '\\' && $chrs[$c - 2] == '\\'))) {
 							// found a quote, we're in a string, and it's not escaped
 							array_pop($stk);
 							//print("Found end of string at {$c}: ".substr($chrs, $top['where'], (1 + 1 + $c - $top['where']))."\n");
 
-						} elseif (($chrs{$c} == '[') &&
+						} elseif (($chrs[$c] == '[') &&
 								 in_array($top['what'], array(SERVICES_JSON_SLICE, SERVICES_JSON_IN_ARR, SERVICES_JSON_IN_OBJ))) {
 							// found a left-bracket, and we are in an array, object, or slice
 							array_push($stk, array('what' => SERVICES_JSON_IN_ARR, 'where' => $c, 'delim' => false));
 							//print("Found start of array at {$c}\n");
 
-						} elseif (($chrs{$c} == ']') && ($top['what'] == SERVICES_JSON_IN_ARR)) {
+						} elseif (($chrs[$c] == ']') && ($top['what'] == SERVICES_JSON_IN_ARR)) {
 							// found a right-bracket, and we're in an array
 							array_pop($stk);
 							//print("Found end of array at {$c}: ".substr($chrs, $top['where'], (1 + $c - $top['where']))."\n");
 
-						} elseif (($chrs{$c} == '{') &&
+						} elseif (($chrs[$c] == '{') &&
 								 in_array($top['what'], array(SERVICES_JSON_SLICE, SERVICES_JSON_IN_ARR, SERVICES_JSON_IN_OBJ))) {
 							// found a left-brace, and we are in an array, object, or slice
 							array_push($stk, array('what' => SERVICES_JSON_IN_OBJ, 'where' => $c, 'delim' => false));
 							//print("Found start of object at {$c}\n");
 
-						} elseif (($chrs{$c} == '}') && ($top['what'] == SERVICES_JSON_IN_OBJ)) {
+						} elseif (($chrs[$c] == '}') && ($top['what'] == SERVICES_JSON_IN_OBJ)) {
 							// found a right-brace, and we're in an object
 							array_pop($stk);
 							//print("Found end of object at {$c}: ".substr($chrs, $top['where'], (1 + $c - $top['where']))."\n");
