@@ -215,6 +215,8 @@ $wikiUpperChars = array(
 	'ȱ' => 'Ȱ',
 	'ȳ' => 'Ȳ',
 	'ȼ' => 'Ȼ',
+	'ȿ' => 'Ȿ',
+	'ɀ' => 'Ɀ',
 	'ɂ' => 'Ɂ',
 	'ɇ' => 'Ɇ',
 	'ɉ' => 'Ɉ',
@@ -223,6 +225,7 @@ $wikiUpperChars = array(
 	'ɏ' => 'Ɏ',
 	'ɐ' => 'Ɐ',
 	'ɑ' => 'Ɑ',
+	'ɒ' => 'Ɒ',
 	'ɓ' => 'Ɓ',
 	'ɔ' => 'Ɔ',
 	'ɖ' => 'Ɖ',
@@ -231,6 +234,7 @@ $wikiUpperChars = array(
 	'ɛ' => 'Ɛ',
 	'ɠ' => 'Ɠ',
 	'ɣ' => 'Ɣ',
+	'ɥ' => 'Ɥ',
 	'ɨ' => 'Ɨ',
 	'ɩ' => 'Ɩ',
 	'ɫ' => 'Ɫ',
@@ -453,6 +457,8 @@ $wikiUpperChars = array(
 	'ԟ' => 'Ԟ',
 	'ԡ' => 'Ԡ',
 	'ԣ' => 'Ԣ',
+	'ԥ' => 'Ԥ',
+	'ԧ' => 'Ԧ',
 	'ա' => 'Ա',
 	'բ' => 'Բ',
 	'գ' => 'Գ',
@@ -863,6 +869,8 @@ $wikiUpperChars = array(
 	'ⳟ' => 'Ⳟ',
 	'ⳡ' => 'Ⳡ',
 	'ⳣ' => 'Ⳣ',
+	'ⳬ' => 'Ⳬ',
+	'ⳮ' => 'Ⳮ',
 	'ⴀ' => 'Ⴀ',
 	'ⴁ' => 'Ⴁ',
 	'ⴂ' => 'Ⴂ',
@@ -917,6 +925,7 @@ $wikiUpperChars = array(
 	'ꙛ' => 'Ꙛ',
 	'ꙝ' => 'Ꙝ',
 	'ꙟ' => 'Ꙟ',
+	'ꙡ' => 'Ꙡ',
 	'ꙣ' => 'Ꙣ',
 	'ꙥ' => 'Ꙥ',
 	'ꙧ' => 'Ꙧ',
@@ -981,6 +990,12 @@ $wikiUpperChars = array(
 	'ꞅ' => 'Ꞅ',
 	'ꞇ' => 'Ꞇ',
 	'ꞌ' => 'Ꞌ',
+	'ꞑ' => 'Ꞑ',
+	'ꞡ' => 'Ꞡ',
+	'ꞣ' => 'Ꞣ',
+	'ꞥ' => 'Ꞥ',
+	'ꞧ' => 'Ꞧ',
+	'ꞩ' => 'Ꞩ',
 	'ａ' => 'Ａ',
 	'ｂ' => 'Ｂ',
 	'ｃ' => 'Ｃ',
@@ -1477,6 +1492,8 @@ $wikiLowerChars = array(
 	'Ԟ' => 'ԟ',
 	'Ԡ' => 'ԡ',
 	'Ԣ' => 'ԣ',
+	'Ԥ' => 'ԥ',
+	'Ԧ' => 'ԧ',
 	'Ա' => 'ա',
 	'Բ' => 'բ',
 	'Գ' => 'գ',
@@ -1877,8 +1894,11 @@ $wikiLowerChars = array(
 	'Ɑ' => 'ɑ',
 	'Ɱ' => 'ɱ',
 	'Ɐ' => 'ɐ',
+	'Ɒ' => 'ɒ',
 	'Ⱳ' => 'ⱳ',
 	'Ⱶ' => 'ⱶ',
+	'Ȿ' => 'ȿ',
+	'Ɀ' => 'ɀ',
 	'Ⲁ' => 'ⲁ',
 	'Ⲃ' => 'ⲃ',
 	'Ⲅ' => 'ⲅ',
@@ -1929,6 +1949,8 @@ $wikiLowerChars = array(
 	'Ⳟ' => 'ⳟ',
 	'Ⳡ' => 'ⳡ',
 	'Ⳣ' => 'ⳣ',
+	'Ⳬ' => 'ⳬ',
+	'Ⳮ' => 'ⳮ',
 	'Ꙁ' => 'ꙁ',
 	'Ꙃ' => 'ꙃ',
 	'Ꙅ' => 'ꙅ',
@@ -1945,6 +1967,7 @@ $wikiLowerChars = array(
 	'Ꙛ' => 'ꙛ',
 	'Ꙝ' => 'ꙝ',
 	'Ꙟ' => 'ꙟ',
+	'Ꙡ' => 'ꙡ',
 	'Ꙣ' => 'ꙣ',
 	'Ꙥ' => 'ꙥ',
 	'Ꙧ' => 'ꙧ',
@@ -2010,6 +2033,13 @@ $wikiLowerChars = array(
 	'Ꞅ' => 'ꞅ',
 	'Ꞇ' => 'ꞇ',
 	'Ꞌ' => 'ꞌ',
+	'Ɥ' => 'ɥ',
+	'Ꞑ' => 'ꞑ',
+	'Ꞡ' => 'ꞡ',
+	'Ꞣ' => 'ꞣ',
+	'Ꞥ' => 'ꞥ',
+	'Ꞧ' => 'ꞧ',
+	'Ꞩ' => 'ꞩ',
 	'Ａ' => 'ａ',
 	'Ｂ' => 'ｂ',
 	'Ｃ' => 'ｃ',
