@@ -1,18 +1,31 @@
 <?php
 /**
  * List for revision table items
+ *
+ * This will check both the 'revision' table for live revisions and the
+ * 'archive' table for traditionally-deleted revisions that have an
+ * ar_rev_id saved.
+ *
+ * See RevDel_RevisionItem and RevDel_ArchivedRevisionItem for items.
  */
 class RevDel_RevisionList extends RevDel_List {
 	var $currentRevId;
-	var $type = 'revision';
-	var $idField = 'rev_id';
-	var $dateField = 'rev_timestamp';
-	var $authorIdField = 'rev_user';
-	var $authorNameField = 'rev_user_text';
 
+	public function getType() {
+		return 'revision';
+	}
+
+	public static function getRelationType() {
+		return 'rev_id';
+	}
+
+	/**
+	 * @param $db DatabaseBase
+	 * @return mixed
+	 */
 	public function doQuery( $db ) {
 		$ids = array_map( 'intval', $this->ids );
-		return $db->select( array('revision','page'), '*',
+		$live = $db->select( array('revision','page'), '*',
 			array(
 				'rev_page' => $this->title->getArticleID(),
 				'rev_id'   => $ids,
@@ -21,16 +34,54 @@ class RevDel_RevisionList extends RevDel_List {
 			__METHOD__,
 			array( 'ORDER BY' => 'rev_id DESC' )
 		);
+
+		if ( $live->numRows() >= count( $ids ) ) {
+			// All requested revisions are live, keeps things simple!
+			return $live;
+		}
+
+		// Check if any requested revisions are available fully deleted.
+		$archived = $db->select( array( 'archive' ), '*',
+			array(
+				'ar_rev_id' => $ids
+			),
+			__METHOD__,
+			array( 'ORDER BY' => 'ar_rev_id DESC' )
+		);
+
+		if ( $archived->numRows() == 0 ) {
+			return $live;
+		} elseif ( $live->numRows() == 0 ) {
+			return $archived;
+		} else {
+			// Combine the two! Whee
+			$rows = array();
+			foreach ( $live as $row ) {
+				$rows[$row->rev_id] = $row;
+			}
+			foreach ( $archived as $row ) {
+				$rows[$row->ar_rev_id] = $row;
+			}
+			krsort( $rows );
+			return new FakeResultWrapper( array_values( $rows ) );
+		}
 	}
 
 	public function newItem( $row ) {
-		return new RevDel_RevisionItem( $this, $row );
+		if ( isset( $row->rev_id ) ) {
+			return new RevDel_RevisionItem( $this, $row );
+		} elseif ( isset( $row->ar_rev_id ) ) {
+			return new RevDel_ArchivedRevisionItem( $this, $row );
+		} else {
+			// This shouldn't happen. :)
+			throw new MWException( 'Invalid row type in RevDel_RevisionList' );
+		}
 	}
 
 	public function getCurrent() {
 		if ( is_null( $this->currentRevId ) ) {
 			$dbw = wfGetDB( DB_MASTER );
-			$this->currentRevId = $dbw->selectField( 
+			$this->currentRevId = $dbw->selectField(
 				'page', 'page_latest', $this->title->pageCond(), __METHOD__ );
 		}
 		return $this->currentRevId;
@@ -54,7 +105,7 @@ class RevDel_RevisionList extends RevDel_List {
 }
 
 /**
- * Item class for a revision table row
+ * Item class for a live revision table row
  */
 class RevDel_RevisionItem extends RevDel_Item {
 	var $revision;
@@ -64,10 +115,26 @@ class RevDel_RevisionItem extends RevDel_Item {
 		$this->revision = new Revision( $row );
 	}
 
+	public function getIdField() {
+		return 'rev_id';
+	}
+
+	public function getTimestampField() {
+		return 'rev_timestamp';
+	}
+
+	public function getAuthorIdField() {
+		return 'rev_user';
+	}
+
+	public function getAuthorNameField() {
+		return 'rev_user_text';
+	}
+
 	public function canView() {
 		return $this->revision->userCan( Revision::DELETED_RESTRICTED );
 	}
-	
+
 	public function canViewContent() {
 		return $this->revision->userCan( Revision::DELETED_TEXT );
 	}
@@ -81,8 +148,8 @@ class RevDel_RevisionItem extends RevDel_Item {
 		// Update revision table
 		$dbw->update( 'revision',
 			array( 'rev_deleted' => $bits ),
-			array( 
-				'rev_id' => $this->revision->getId(), 
+			array(
+				'rev_id' => $this->revision->getId(),
 				'rev_page' => $this->revision->getPage(),
 				'rev_deleted' => $this->getBits()
 			),
@@ -94,7 +161,7 @@ class RevDel_RevisionItem extends RevDel_Item {
 		}
 		// Update recentchanges table
 		$dbw->update( 'recentchanges',
-			array( 
+			array(
 				'rc_deleted' => $bits,
 				'rc_patrolled' => 1
 			),
@@ -113,7 +180,7 @@ class RevDel_RevisionItem extends RevDel_Item {
 	}
 
 	public function isHideCurrentOp( $newBits ) {
-		return ( $newBits & Revision::DELETED_TEXT ) 
+		return ( $newBits & Revision::DELETED_TEXT )
 			&& $this->list->getCurrent() == $this->getId();
 	}
 
@@ -122,14 +189,13 @@ class RevDel_RevisionItem extends RevDel_Item {
 	 * Overridden by RevDel_ArchiveItem.
 	 */
 	protected function getRevisionLink() {
-		global $wgLang;
-		$date = $wgLang->timeanddate( $this->revision->getTimestamp(), true );
+		$date = $this->list->getLang()->timeanddate( $this->revision->getTimestamp(), true );
 		if ( $this->isDeleted() && !$this->canViewContent() ) {
 			return $date;
 		}
-		return $this->special->skin->link(
+		return Linker::link(
 			$this->list->title,
-			$date, 
+			$date,
 			array(),
 			array(
 				'oldid' => $this->revision->getId(),
@@ -146,9 +212,9 @@ class RevDel_RevisionItem extends RevDel_Item {
 		if ( $this->isDeleted() && !$this->canViewContent() ) {
 			return wfMsgHtml('diff');
 		} else {
-			return 
-				$this->special->skin->link( 
-					$this->list->title, 
+			return
+				Linker::link(
+					$this->list->title,
 					wfMsgHtml('diff'),
 					array(),
 					array(
@@ -167,8 +233,8 @@ class RevDel_RevisionItem extends RevDel_Item {
 	public function getHTML() {
 		$difflink = $this->getDiffLink();
 		$revlink = $this->getRevisionLink();
-		$userlink = $this->special->skin->revUserLink( $this->revision );
-		$comment = $this->special->skin->revComment( $this->revision );
+		$userlink = Linker::revUserLink( $this->revision );
+		$comment = Linker::revComment( $this->revision );
 		if ( $this->isDeleted() ) {
 			$revlink = "<span class=\"history-deleted\">$revlink</span>";
 		}
@@ -180,12 +246,18 @@ class RevDel_RevisionItem extends RevDel_Item {
  * List for archive table items, i.e. revisions deleted via action=delete
  */
 class RevDel_ArchiveList extends RevDel_RevisionList {
-	var $type = 'archive';
-	var $idField = 'ar_timestamp';
-	var $dateField = 'ar_timestamp';
-	var $authorIdField = 'ar_user';
-	var $authorNameField = 'ar_user_text';
+	public function getType() {
+		return 'archive';
+	}
 
+	public static function getRelationType() {
+		return 'ar_timestamp';
+	}
+
+	/**
+	 * @param $db DatabaseBase
+	 * @return mixed
+	 */
 	public function doQuery( $db ) {
 		$timestamps = array();
 		foreach ( $this->ids as $id ) {
@@ -225,34 +297,50 @@ class RevDel_ArchiveItem extends RevDel_RevisionItem {
 			array( 'page' => $this->list->title->getArticleId() ) );
 	}
 
+	public function getIdField() {
+		return 'ar_timestamp';
+	}
+
+	public function getTimestampField() {
+		return 'ar_timestamp';
+	}
+
+	public function getAuthorIdField() {
+		return 'ar_user';
+	}
+
+	public function getAuthorNameField() {
+		return 'ar_user_text';
+	}
+
 	public function getId() {
 		# Convert DB timestamp to MW timestamp
 		return $this->revision->getTimestamp();
 	}
-	
+
 	public function setBits( $bits ) {
 		$dbw = wfGetDB( DB_MASTER );
 		$dbw->update( 'archive',
 			array( 'ar_deleted' => $bits ),
-			array( 'ar_namespace' => $this->list->title->getNamespace(),
-				'ar_title'     => $this->list->title->getDBkey(),
+			array(
+				'ar_namespace' 	=> $this->list->title->getNamespace(),
+				'ar_title'     	=> $this->list->title->getDBkey(),
 				// use timestamp for index
-				'ar_timestamp' => $this->row->ar_timestamp,
-				'ar_rev_id'    => $this->row->ar_rev_id,
-				'ar_deleted' => $this->getBits()
+				'ar_timestamp' 	=> $this->row->ar_timestamp,
+				'ar_rev_id'    	=> $this->row->ar_rev_id,
+				'ar_deleted' 	=> $this->getBits()
 			),
 			__METHOD__ );
 		return (bool)$dbw->affectedRows();
 	}
 
 	protected function getRevisionLink() {
-		global $wgLang;
 		$undelete = SpecialPage::getTitleFor( 'Undelete' );
-		$date = $wgLang->timeanddate( $this->revision->getTimestamp(), true );
+		$date = $this->list->getLang()->timeanddate( $this->revision->getTimestamp(), true );
 		if ( $this->isDeleted() && !$this->canViewContent() ) {
 			return $date;
 		}
-		return $this->special->skin->link( $undelete, $date, array(),
+		return Linker::link( $undelete, $date, array(),
 			array(
 				'target' => $this->list->title->getPrefixedText(),
 				'timestamp' => $this->revision->getTimestamp()
@@ -263,8 +351,8 @@ class RevDel_ArchiveItem extends RevDel_RevisionItem {
 		if ( $this->isDeleted() && !$this->canViewContent() ) {
 			return wfMsgHtml( 'diff' );
 		}
-		$undelete = SpecialPage::getTitleFor( 'Undelete' );		
-		return $this->special->skin->link( $undelete, wfMsgHtml('diff'), array(), 
+		$undelete = SpecialPage::getTitleFor( 'Undelete' );
+		return Linker::link( $undelete, wfMsgHtml('diff'), array(),
 			array(
 				'target' => $this->list->title->getPrefixedText(),
 				'diff' => 'prev',
@@ -273,17 +361,57 @@ class RevDel_ArchiveItem extends RevDel_RevisionItem {
 	}
 }
 
+
+/**
+ * Item class for a archive table row by ar_rev_id -- actually
+ * used via RevDel_RevisionList.
+ */
+class RevDel_ArchivedRevisionItem extends RevDel_ArchiveItem {
+	public function __construct( $list, $row ) {
+		RevDel_Item::__construct( $list, $row );
+
+		$this->revision = Revision::newFromArchiveRow( $row,
+			array( 'page' => $this->list->title->getArticleId() ) );
+	}
+
+	public function getIdField() {
+		return 'ar_rev_id';
+	}
+
+	public function getId() {
+		return $this->revision->getId();
+	}
+
+	public function setBits( $bits ) {
+		$dbw = wfGetDB( DB_MASTER );
+		$dbw->update( 'archive',
+			array( 'ar_deleted' => $bits ),
+			array( 'ar_rev_id' => $this->row->ar_rev_id,
+				   'ar_deleted' => $this->getBits()
+			),
+			__METHOD__ );
+		return (bool)$dbw->affectedRows();
+	}
+}
+
 /**
  * List for oldimage table items
  */
 class RevDel_FileList extends RevDel_List {
-	var $type = 'oldimage';
-	var $idField = 'oi_archive_name';
-	var $dateField = 'oi_timestamp';
-	var $authorIdField = 'oi_user';
-	var $authorNameField = 'oi_user_text';
+	public function getType() {
+		return 'oldimage';
+	}
+
+	public static function getRelationType() {
+		return 'oi_archive_name';
+	}
+
 	var $storeBatch, $deleteBatch, $cleanupBatch;
 
+	/**
+	 * @param $db DatabaseBase
+	 * @return mixed
+	 */
 	public function doQuery( $db ) {
 		$archiveNames = array();
 		foreach( $this->ids as $timestamp ) {
@@ -348,6 +476,10 @@ class RevDel_FileList extends RevDel_List {
  * Item class for an oldimage table row
  */
 class RevDel_FileItem extends RevDel_Item {
+
+	/**
+	 * @var File
+	 */
 	var $file;
 
 	public function __construct( $list, $row ) {
@@ -355,6 +487,22 @@ class RevDel_FileItem extends RevDel_Item {
 		$this->file = RepoGroup::singleton()->getLocalRepo()->newFileFromRow( $row );
 	}
 
+	public function getIdField() {
+		return 'oi_archive_name';
+	}
+
+	public function getTimestampField() {
+		return 'oi_timestamp';
+	}
+
+	public function getAuthorIdField() {
+		return 'oi_user';
+	}
+
+	public function getAuthorNameField() {
+		return 'oi_user_text';
+	}
+
 	public function getId() {
 		$parts = explode( '!', $this->row->oi_archive_name );
 		return $parts[0];
@@ -363,7 +511,7 @@ class RevDel_FileItem extends RevDel_Item {
 	public function canView() {
 		return $this->file->userCan( File::DELETED_RESTRICTED );
 	}
-	
+
 	public function canViewContent() {
 		return $this->file->userCan( File::DELETED_FILE );
 	}
@@ -374,7 +522,7 @@ class RevDel_FileItem extends RevDel_Item {
 
 	public function setBits( $bits ) {
 		# Queue the file op
-		# FIXME: move to LocalFile.php
+		# @todo FIXME: Move to LocalFile.php
 		if ( $this->isDeleted() ) {
 			if ( $bits & File::DELETED_FILE ) {
 				# Still deleted
@@ -395,12 +543,12 @@ class RevDel_FileItem extends RevDel_Item {
 			$dstRel = $this->file->repo->getDeletedHashPath( $key ) . $key;
 			$this->list->deleteBatch[] = array( $this->file->getRel(), $dstRel );
 		}
-		
+
 		# Do the database operations
 		$dbw = wfGetDB( DB_MASTER );
 		$dbw->update( 'oldimage',
 			array( 'oi_deleted' => $bits ),
-			array( 
+			array(
 				'oi_name' => $this->row->oi_name,
 				'oi_timestamp' => $this->row->oi_timestamp,
 				'oi_deleted' => $this->getBits()
@@ -415,24 +563,25 @@ class RevDel_FileItem extends RevDel_Item {
 	}
 
 	/**
-	 * Get the link to the file. 
+	 * Get the link to the file.
 	 * Overridden by RevDel_ArchivedFileItem.
 	 */
 	protected function getLink() {
-		global $wgLang, $wgUser;
-		$date = $wgLang->timeanddate( $this->file->getTimestamp(), true  );		
+		$date = $this->list->getLang()->timeanddate( $this->file->getTimestamp(), true  );
 		if ( $this->isDeleted() ) {
 			# Hidden files...
 			if ( !$this->canViewContent() ) {
 				$link = $date;
 			} else {
-				$link = $this->special->skin->link( 
-					$this->special->getTitle(), 
-					$date, array(), 
+				$revdelete = SpecialPage::getTitleFor( 'Revisiondelete' );
+				$link = Linker::link(
+					$revdelete,
+					$date, array(),
 					array(
 						'target' => $this->list->title->getPrefixedText(),
 						'file'   => $this->file->getArchiveName(),
-						'token'  => $wgUser->editToken( $this->file->getArchiveName() )
+						'token'  => $this->list->getUser()->editToken(
+							$this->file->getArchiveName() )
 					)
 				);
 			}
@@ -448,8 +597,8 @@ class RevDel_FileItem extends RevDel_Item {
 	 */
 	protected function getUserTools() {
 		if( $this->file->userCan( Revision::DELETED_USER ) ) {
-			$link = $this->special->skin->userLink( $this->file->user, $this->file->user_text ) .
-				$this->special->skin->userToolLinks( $this->file->user, $this->file->user_text );
+			$link = Linker::userLink( $this->file->user, $this->file->user_text ) .
+				Linker::userToolLinks( $this->file->user, $this->file->user_text );
 		} else {
 			$link = wfMsgHtml( 'rev-deleted-user' );
 		}
@@ -467,7 +616,7 @@ class RevDel_FileItem extends RevDel_Item {
 	 */
 	protected function getComment() {
 		if( $this->file->userCan( File::DELETED_COMMENT ) ) {
-			$block = $this->special->skin->commentBlock( $this->file->description );
+			$block = Linker::commentBlock( $this->file->description );
 		} else {
 			$block = ' ' . wfMsgHtml( 'rev-deleted-comment' );
 		}
@@ -478,15 +627,14 @@ class RevDel_FileItem extends RevDel_Item {
 	}
 
 	public function getHTML() {
-		global $wgLang;
-		$data = 
+		$data =
 			wfMsg(
-				'widthheight', 
-				$wgLang->formatNum( $this->file->getWidth() ),
-				$wgLang->formatNum( $this->file->getHeight() ) 
+				'widthheight',
+				$this->list->getLang()->formatNum( $this->file->getWidth() ),
+				$this->list->getLang()->formatNum( $this->file->getHeight() )
 			) .
-			' (' . 
-			wfMsgExt( 'nbytes', 'parsemag', $wgLang->formatNum( $this->file->getSize() ) ) . 
+			' (' .
+			wfMsgExt( 'nbytes', 'parsemag', $this->list->getLang()->formatNum( $this->file->getSize() ) ) .
 			')';
 
 		return '<li>' . $this->getLink() . ' ' . $this->getUserTools() . ' ' .
@@ -498,12 +646,18 @@ class RevDel_FileItem extends RevDel_Item {
  * List for filearchive table items
  */
 class RevDel_ArchivedFileList extends RevDel_FileList {
-	var $type = 'filearchive';
-	var $idField = 'fa_id';
-	var $dateField = 'fa_timestamp';
-	var $authorIdField = 'fa_user';
-	var $authorNameField = 'fa_user_text';
-	
+	public function getType() {
+		return 'filearchive';
+	}
+
+	public static function getRelationType() {
+		return 'fa_id';
+	}
+
+	/**
+	 * @param $db DatabaseBase
+	 * @return mixed
+	 */
 	public function doQuery( $db ) {
 		$ids = array_map( 'intval', $this->ids );
 		return $db->select( 'filearchive', '*',
@@ -530,6 +684,22 @@ class RevDel_ArchivedFileItem extends RevDel_FileItem {
 		$this->file = ArchivedFile::newFromRow( $row );
 	}
 
+	public function getIdField() {
+		return 'fa_id';
+	}
+
+	public function getTimestampField() {
+		return 'fa_timestamp';
+	}
+
+	public function getAuthorIdField() {
+		return 'fa_user';
+	}
+
+	public function getAuthorNameField() {
+		return 'fa_user_text';
+	}
+
 	public function getId() {
 		return $this->row->fa_id;
 	}
@@ -548,19 +718,18 @@ class RevDel_ArchivedFileItem extends RevDel_FileItem {
 	}
 
 	protected function getLink() {
-		global $wgLang, $wgUser;
-		$date = $wgLang->timeanddate( $this->file->getTimestamp(), true  );
+		$date = $this->list->getLang()->timeanddate( $this->file->getTimestamp(), true  );
 		$undelete = SpecialPage::getTitleFor( 'Undelete' );
 		$key = $this->file->getKey();
 		# Hidden files...
 		if( !$this->canViewContent() ) {
 			$link = $date;
 		} else {
-			$link = $this->special->skin->link( $undelete, $date, array(),
+			$link = Linker::link( $undelete, $date, array(),
 				array(
 					'target' => $this->list->title->getPrefixedText(),
 					'file' => $key,
-					'token' => $wgUser->editToken( $key )
+					'token' => $this->list->getUser()->editToken( $key )
 				)
 			);
 		}
@@ -575,12 +744,18 @@ class RevDel_ArchivedFileItem extends RevDel_FileItem {
  * List for logging table items
  */
 class RevDel_LogList extends RevDel_List {
-	var $type = 'logging';
-	var $idField = 'log_id';
-	var $dateField = 'log_timestamp';
-	var $authorIdField = 'log_user';
-	var $authorNameField = 'log_user_text';
+	public function getType() {
+		return 'logging';
+	}
 
+	public static function getRelationType() {
+		return 'log_id';
+	}
+
+	/**
+	 * @param $db DatabaseBase
+	 * @return mixed
+	 */
 	public function doQuery( $db ) {
 		$ids = array_map( 'intval', $this->ids );
 		return $db->select( 'logging', '*',
@@ -615,10 +790,26 @@ class RevDel_LogList extends RevDel_List {
  * Item class for a logging table row
  */
 class RevDel_LogItem extends RevDel_Item {
+	public function getIdField() {
+		return 'log_id';
+	}
+
+	public function getTimestampField() {
+		return 'log_timestamp';
+	}
+
+	public function getAuthorIdField() {
+		return 'log_user';
+	}
+
+	public function getAuthorNameField() {
+		return 'log_user_text';
+	}
+
 	public function canView() {
 		return LogEventsList::userCan( $this->row, Revision::DELETED_RESTRICTED );
 	}
-	
+
 	public function canViewContent() {
 		return true; // none
 	}
@@ -630,9 +821,9 @@ class RevDel_LogItem extends RevDel_Item {
 	public function setBits( $bits ) {
 		$dbw = wfGetDB( DB_MASTER );
 		$dbw->update( 'recentchanges',
-			array( 
-				'rc_deleted' => $bits, 
-				'rc_patrolled' => 1 
+			array(
+				'rc_deleted' => $bits,
+				'rc_patrolled' => 1
 			),
 			array(
 				'rc_logid' => $this->row->log_id,
@@ -652,14 +843,12 @@ class RevDel_LogItem extends RevDel_Item {
 	}
 
 	public function getHTML() {
-		global $wgLang;
-
-		$date = htmlspecialchars( $wgLang->timeanddate( $this->row->log_timestamp ) );
+		$date = htmlspecialchars( $this->list->getLang()->timeanddate( $this->row->log_timestamp ) );
 		$paramArray = LogPage::extractParams( $this->row->log_params );
 		$title = Title::makeTitle( $this->row->log_namespace, $this->row->log_title );
 
 		// Log link for this page
-		$loglink = $this->special->skin->link(
+		$loglink = Linker::link(
 			SpecialPage::getTitleFor( 'Log' ),
 			wfMsgHtml( 'log' ),
 			array(),
@@ -669,19 +858,20 @@ class RevDel_LogItem extends RevDel_Item {
 		if( !$this->canView() ) {
 			$action = '<span class="history-deleted">' . wfMsgHtml('rev-deleted-event') . '</span>';
 		} else {
-			$action = LogPage::actionText( $this->row->log_type, $this->row->log_action, $title,
-				$this->special->skin, $paramArray, true, true );
+			$skin = $this->list->getUser()->getSkin();
+			$action = LogPage::actionText( $this->row->log_type, $this->row->log_action,
+				$title, $skin, $paramArray, true, true );
 			if( $this->row->log_deleted & LogPage::DELETED_ACTION )
 				$action = '<span class="history-deleted">' . $action . '</span>';
 		}
 		// User links
-		$userLink = $this->special->skin->userLink( $this->row->log_user,
+		$userLink = Linker::userLink( $this->row->log_user,
 			User::WhoIs( $this->row->log_user ) );
 		if( LogEventsList::isDeleted($this->row,LogPage::DELETED_USER) ) {
 			$userLink = '<span class="history-deleted">' . $userLink . '</span>';
 		}
 		// Comment
-		$comment = $wgLang->getDirMark() . $this->special->skin->commentBlock( $this->row->log_comment );
+		$comment = $this->list->getLang()->getDirMark() . Linker::commentBlock( $this->row->log_comment );
 		if( LogEventsList::isDeleted($this->row,LogPage::DELETED_COMMENT) ) {
 			$comment = '<span class="history-deleted">' . $comment . '</span>';
 		}
