@@ -426,7 +426,11 @@ class HTMLBlockedUsersItemSelect extends HTMLSelectField {
 			return true;
 		}
 
-		if ( !in_array( $value, $this->mParams['options'] ) ) {
+		// Let folks pick an explicit limit not from our list, as long as it's a real numbr.
+		if ( !in_array( $value, $this->mParams['options'] ) && $value == intval( $value ) && $value > 0 ) {
+			// This adds the explicitly requested limit value to the drop-down,
+			// then makes sure it's sorted correctly so when we output the list
+			// later, the custom option doesn't just show up last.
 			$this->mParams['options'][ $this->mParent->getLanguage()->formatNum( $value ) ] = intval($value);
 			asort( $this->mParams['options'] );
 		}
