@@ -29,38 +29,45 @@ $messages = array(
 'thu'           => 'Kam',
 'fri'           => 'Jum',
 'sat'           => 'Sat',
-'january'       => 'Uléŋ 1',
-'february'      => 'ᨙᨄᨅᨛᨑᨘᨕᨑᨗ',
-'march'         => 'ᨆᨙᨑ',
-'april'         => 'ᨕᨄᨛᨑᨗᨒᨗ',
-'may_long'      => 'ᨙᨆᨕᨗ',
-'june'          => 'ᨍᨘᨊᨗ',
-'july'          => 'ᨍᨘᨒᨗ',
-'august'        => 'ᨕᨁᨘᨔᨘᨈᨘᨔᨘ',
-'september'     => 'ᨙᨔᨙᨈᨇᨛᨑᨛ',
-'october'       => 'ᨕᨚᨀᨛᨈᨚᨅᨛᨑᨛ',
-'november'      => 'Uleŋ 11',
-'december'      => 'ᨉᨗᨙᨔᨇᨛᨑᨛ',
-'january-gen'   => 'Uleŋ 1',
-'february-gen'  => 'Uleŋ 2',
-'march-gen'     => 'Uleŋ 3',
-'april-gen'     => 'Uleŋ 4',
-'may-gen'       => 'Uleŋ 5',
-'june-gen'      => 'Uleŋ 6',
-'july-gen'      => 'Uleŋ 7',
-'august-gen'    => 'Uleŋ 8',
-'september-gen' => 'Uleŋ 9',
-'october-gen'   => 'Uleŋ 10',
-'november-gen'  => 'Uleŋ 11',
-'december-gen'  => 'Uleŋ 12',
+'january'       => 'Januari',
+'february'      => 'Fébruari',
+'march'         => "Maré'",
+'april'         => 'April',
+'may_long'      => 'Méi',
+'june'          => 'Juni',
+'july'          => 'Juli',
+'august'        => "Ogoso'",
+'september'     => 'September',
+'october'       => 'Oktober',
+'november'      => 'November',
+'december'      => 'Désémber',
+'january-gen'   => 'Januari',
+'february-gen'  => 'Fébruari',
+'march-gen'     => "Maré'",
+'april-gen'     => 'April',
+'may-gen'       => 'Méi',
+'june-gen'      => 'Juni',
+'july-gen'      => 'Juli',
+'august-gen'    => "Ogoso'",
+'september-gen' => 'September',
+'october-gen'   => 'Oktober',
+'november-gen'  => 'November',
+'december-gen'  => 'Désémber',
 
 # Categories related messages
 'category_header' => 'Leppa rilaleŋ kategori "$1"',
 'subcategories'   => 'Subkategori',
 
-'about'          => 'Atajangeng',
-'article'        => 'Lontara',
-'cancel'         => 'Rusa',
+'about'      => 'Atajangeng',
+'article'    => 'Lontara',
+'cancel'     => 'Rusa',
+'mypage'     => "Leppana iya'",
+'mytalk'     => 'Bicarana iyya',
+'anontalk'   => 'Bicarana IP édé',
+'navigation' => 'Navigasi',
+'and'        => '&#32;na',
+
+# Cologne Blue skin
 'qbfind'         => 'Assapparang',
 'qbbrowse'       => 'Berowoso',
 'qbedit'         => 'Padécéŋ',
@@ -68,16 +75,17 @@ $messages = array(
 'qbpageinfo'     => 'Konteks',
 'qbmyoptions'    => "Leppana iya'",
 'qbspecialpages' => 'Leppa spésiala',
-'mypage'         => "Leppana iya'",
-'mytalk'         => 'Bicarana iyya',
-'anontalk'       => 'Bicarana IP édé',
-'navigation'     => 'Navigasi',
-'and'            => '&#32;na',
+'faq'            => 'FAQ',
+'faqpage'        => 'Project:FAQ',
 
-# Metadata in edit box
-'metadata_help' => 'Metadata:',
+# Vector skin
+'vector-action-move'     => "Paléccé'",
+'vector-view-create'     => 'Ebbu',
+'vector-view-edit'       => 'Padéccéng',
+'vector-view-view'       => 'Baca',
+'vector-view-viewsource' => 'Ita sumber',
 
-'errorpagetitle'   => 'Éro',
+'errorpagetitle'   => 'Asalaŋ',
 'returnto'         => 'Lisu ri $1.',
 'tagline'          => 'Polé {{SITENAME}}',
 'help'             => 'Paŋinriŋ',
@@ -87,7 +95,6 @@ $messages = array(
 'searcharticle'    => 'Lao',
 'history'          => 'Versi riolo leppaë',
 'history_short'    => 'versi riolo',
-'info_short'       => 'Informasi',
 'permalink'        => 'Pranala permanen',
 'edit'             => 'Padécéŋ',
 'create'           => 'Ebbu',
@@ -127,8 +134,6 @@ $messages = array(
 'disclaimers'          => 'Diseklaima',
 'edithelp'             => 'Paŋinriŋ mapadécéŋ',
 'edithelppage'         => 'Help:Mapadécéŋ',
-'faq'                  => 'FAQ',
-'faqpage'              => 'Project:FAQ',
 'helppage'             => 'Help:Lise',
 'mainpage'             => 'Leppa Indoë',
 'mainpage-description' => 'Leppa Indoë',
@@ -140,12 +145,13 @@ $messages = array(
 'viewsourceold'   => 'ita sumber',
 'editlink'        => 'padécéŋ',
 'viewsourcelink'  => 'ita sumber',
+'editsectionhint' => 'Padécéŋ kajuru: $1',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Leppa',
 'nstab-user'      => 'Leppa papaké',
 'nstab-media'     => 'Leppa média',
-'nstab-special'   => 'Spésiala',
+'nstab-special'   => 'Leppa spésiala',
 'nstab-project'   => 'Proyek',
 'nstab-image'     => 'Rapang',
 'nstab-mediawiki' => 'Pappaseŋ',
@@ -171,10 +177,8 @@ $messages = array(
 'virus-unknownscanner' => "Antivirus dé' riisseŋ:",
 
 # Login and logout pages
-'logouttitle'             => 'Log maessu papaké',
-'loginpagetitle'          => 'Log mattama papaké',
 'yourname'                => 'Aseŋ papaké:',
-'yourpassword'            => 'Pasewodo:',
+'yourpassword'            => 'Adacili:',
 'login'                   => 'log attama',
 'nav-login-createaccount' => 'Log attama / ebbu akun',
 'userlogin'               => 'Log attama / ebbu akun',
@@ -186,14 +190,10 @@ $messages = array(
 'createaccount'           => 'Ebbu akun',
 'gotaccount'              => "Purani eŋka akun? '''$1'''.",
 'gotaccountlink'          => 'Log attama',
-'youremail'               => 'E-mail:',
-'username'                => 'Aseŋ papaké:',
-'uid'                     => 'ID papaké:',
-'email'                   => 'E-mail',
 'loginerror'              => 'Éro log attama',
-'mailmypassword'          => 'E-mail pasewodo baru',
+'mailmypassword'          => 'E-mail adacili baru',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => 'Pasewodo matoa:',
 
 # Edit page toolbar
@@ -218,14 +218,13 @@ $messages = array(
 'previousrevision'    => '←Revisi riolo',
 'currentrevisionlink' => 'Revisi tannapa',
 'page_first'          => 'séuwani',
-'deletedrev'          => '[ripeddé]',
 'histfirst'           => 'Poŋ loa',
 'histlast'            => 'Poŋ nappa',
 'historysize'         => '($1 {{PLURAL:$1|bita|bita}})',
 'historyempty'        => '(kapa)',
 
 # Revision feed
-'history-feed-item-nocomment' => '$1 ri $2', # user at time
+'history-feed-item-nocomment' => '$1 ri $2',
 
 # Revision deletion
 'rev-deleted-comment'    => '(komentar ripeddé)',
@@ -243,41 +242,31 @@ $messages = array(
 'revdelete-hid'          => 'tapo $1',
 
 # Diffs
-'editundo'             => 'undo',
-'diff-movedto'         => 'naésu ri $1',
-'diff-changedto'       => 'naséllé ri $1',
-'diff-movedoutof'      => 'naéssu polé $1',
-'diff-removed'         => '$1 ripeddéni',
-'diff-changedfrom'     => 'naséllé polé $1',
-'diff-src'             => 'sumber',
-'diff-with'            => '&#32;sibawa $1 $2',
-'diff-with-additional' => '$1 $2',
-'diff-with-final'      => '&#32;na $1 $2',
-'diff-height'          => 'lampé',
-'diff-input'           => "séuwa '''input'''",
-'diff-a'               => "séuwa '''linke'''",
-'diff-i'               => "'''italik'''",
-'diff-b'               => "'''umpek'''",
-'diff-strong'          => "'''terek'''",
-'diff-big'             => "'''loppo'''",
-'diff-del'             => "'''ripeddé'''",
+'editundo' => 'undo',
 
 # Search results
 'searchsubtitle'        => "Masappa iko '''[[:$1]]'''",
 'searchsubtitleinvalid' => "Massappa iko '''$1'''",
-'viewprevnext'          => 'Ita ($1 ) ($2) ($3)',
+'viewprevnext'          => 'Ita ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url'        => 'Help:Lise',
+'search-result-size'    => '$1 ({{PLURAL:$2|1 ada|$2 ada}})',
 'search-redirect'       => '(redirect $1)',
 
+# Quickbar
+'qbsettings-none' => 'Dégaga',
+
 # Preferences page
 'mypreferences'     => 'Bérékkeŋeŋna iyya',
 'prefsnologin'      => "Déppa ma'log attama'",
-'qbsettings-none'   => 'Dégaga',
 'prefs-watchlist'   => 'Watchlist',
 'prefs-misc'        => 'Misc',
 'saveprefs'         => 'Taro',
-'textboxsize'       => 'Mapadécéŋ',
+'prefs-editing'     => 'Mapadécéŋ',
 'searchresultshead' => 'Masappa',
+'youremail'         => 'E-mail:',
+'username'          => 'Aseŋ papaké:',
+'uid'               => 'ID papaké:',
+'email'             => 'E-mail',
 
 # Groups
 'group-sysop' => 'Puŋgawa',
@@ -305,7 +294,9 @@ $messages = array(
 'boteditletter'   => 'b',
 
 # Recent changes linked
-'recentchangeslinked' => 'Pappakapinra terkait',
+'recentchangeslinked'         => 'Pappakapinra terkait',
+'recentchangeslinked-feed'    => 'Pappakapinra terkait',
+'recentchangeslinked-toolbox' => 'Pappakapinra terkait',
 
 # Upload
 'upload'    => 'Lureng berkas',
@@ -315,6 +306,7 @@ $messages = array(
 'listfiles_name' => 'Aseŋ',
 
 # File description page
+'file-anchor-link'    => 'Rapang',
 'filehist-user'       => 'Papaké',
 'filehist-dimensions' => 'Dimensi',
 'imagelinks'          => 'Liŋke',
@@ -360,7 +352,7 @@ $messages = array(
 'allpages'          => 'Maneng halamang',
 'alphaindexline'    => '$1 ri $2',
 'allpagesfrom'      => 'Mappaitang halamang-halamang rimulai:',
-'allarticles'       => 'Maneŋ leppa',
+'allarticles'       => 'Sininna leppa',
 'allinnamespace'    => 'Maneŋ leppa (namespace $1)',
 'allnotinnamespace' => 'Maneŋ leppa (tania rilaleŋ namespace $1)',
 'allpagesnext'      => 'Selanjutnya',
@@ -371,12 +363,13 @@ $messages = array(
 'categories' => 'Maneŋ kategori',
 
 # Watchlist
-'addedwatch'     => 'Tamba ri jagaan',
 'addedwatchtext' => "Halamang \"[[:\$1]]\" ni ritamba ri ida [[Special:Watchlist|watchlist]].
 Halamang bicara éréngé gabungan halamang bicara pada wettu depan didaftarkan koe,
 éréngé halamang akan wessi '''umpek''' ri [[Special:RecentChanges|daftar pinra tanappa]] barak lebih lemmak ita.
 
 Apak ida ronnak mappedde halamang édé ri daftar jagaan, klik \"Mangedda jaga\" pada kolom ri sedde.",
+'watch'          => 'Ampi',
+'unwatch'        => 'Tenriampi',
 
 # Delete
 'actioncomplete' => 'Proses makkapo',
@@ -388,8 +381,10 @@ Apak ida ronnak mappedde halamang édé ri daftar jagaan, klik \"Mangedda jaga\"
 # Namespace form on various pages
 'blanknamespace' => '(Utama)',
 
+'sp-contributions-talk' => 'Bicara',
+
 # What links here
-'whatlinkshere'          => 'Pranala ri halamang édé',
+'whatlinkshere'          => 'Pranala ri leppa iyéwé',
 'whatlinkshere-page'     => 'Leppa:',
 'whatlinkshere-backlink' => '← $1',
 'whatlinkshere-links'    => '← liŋke',
@@ -400,9 +395,9 @@ Apak ida ronnak mappedde halamang édé ri daftar jagaan, klik \"Mangedda jaga\"
 'contribslink'       => 'kontrib',
 
 # Move page
-'articleexists'             => 'Halamang béla ida pile ni ujuk, a dek essa.
+'articleexists'             => 'Leppa béla ida pile ni ujuk, a dek essa.
 Silakan pile aseng laing.',
-'1movedto2'                 => '[[$1]] ésuk ri [[$2]]',
+'1movedto2'                 => '[[$1]] léccé lao [[$2]]',
 '1movedto2_redir'           => '[[$1]] rileccé lao ri[[$2]] paké redirect',
 'movelogpage'               => 'Log leccé',
 'movereason'                => 'Saba:',
@@ -422,15 +417,16 @@ Eloko peddéï supaya weddiŋi mapalecé?',
 'allmessagescurrent' => 'Teks kokkoro',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'    => "Leppa papaké iya'",
-'tooltip-pt-mytalk'      => "Leppa bicara iya'",
-'tooltip-pt-preferences' => "Preferencena iya'",
-'tooltip-pt-logout'      => 'Log maessu',
-'tooltip-ca-talk'        => 'Appabicaranna iyé leppa',
-'tooltip-ca-move'        => 'Paléccé leppa édé',
-'tooltip-search'         => 'Sappa ri {{SITENAME}}',
-'tooltip-search-go'      => 'Lao ri leppa aseŋna pappada iyyé rekko eŋkaï',
-'tooltip-n-mainpage'     => 'Lao ri Leppa Indoë',
+'tooltip-pt-userpage'      => "Leppa papaké iya'",
+'tooltip-pt-mytalk'        => "Leppa bicara iya'",
+'tooltip-pt-preferences'   => "Preferencena iya'",
+'tooltip-pt-logout'        => 'Log maessu',
+'tooltip-ca-talk'          => 'Pabicarana iyé leppa',
+'tooltip-ca-move'          => 'Paléccé leppa édé',
+'tooltip-search'           => 'Sappa ri {{SITENAME}}',
+'tooltip-search-go'        => 'Lao ri leppa aseŋna pappada iyyé rekko eŋkaï',
+'tooltip-n-mainpage'       => 'Lao ri Leppa Indoë',
+'tooltip-ca-nstab-special' => "Iyanaéwé séuwa leppa spésiala', dé'na idi' ullé padécéŋiki",
 
 # Attribution
 'anonymous' => 'Pabbuak anonim {{SITENAME}}',
@@ -442,7 +438,6 @@ Eloko peddéï supaya weddiŋi mapalecé?',
 'ilsubmit' => 'Sappa',
 
 # 'all' in various places, this might be different for inflected languages
-'imagelistall'  => 'maneng',
 'watchlistall2' => 'maneŋ',
 'namespacesall' => 'maneŋ',
 'monthsall'     => 'maneŋ',
