@@ -627,6 +627,10 @@ For informasjoon füliet di leeste üttooch üt dåt benjüterspär-logbök:',
 '''Dåt as nuch ai spiikerd!'''",
 'userjspreview'                    => "'''Påås aw dåt dü bloot din brüker JavaScript präiwest/forbekiikest.'''
 '''Dåt as nuch ai spiikerd!'''",
+'sitecsspreview'                   => "'''Påås aw dåt dü jüdeer CSS bloot forbekiikest.'''
+'''Dåt as nuch ai spiikerd!'''",
+'sitejspreview'                    => "'''Påås aw dåt dü jüdeer JavaScript code bloot forbekiikest.'''
+'''Dåt as nuch ai spiikerd!'''",
 'userinvalidcssjstitle'            => "''Woorschauing:''' Skin \"\$1\"jeeft dåt ai. Betånk, dåt brükerspetsiifische .css- än .js-side ma en latj bökstääw önjfånge mönje, ålsü biispelswise ''{{ns:user}}:Münsterkjarl/vector.css'' önj stää foon ''{{ns:user}}:Münsterkjarl/Vector.css''.",
 'updated'                          => '(Änred)',
 'note'                             => "'''Påås aw:'''",
@@ -938,6 +942,7 @@ Stal sääker, dåt jü färsjoonshistoori foon en sid histoorisch koräkt as.',
 'prefsnologin'                => 'Ai önjmälded',
 'changepassword'              => 'Pååsuurd änre',
 'skin-preview'                => 'Forlök',
+'datedefault'                 => 'Foor-önjstaling',
 'prefs-personal'              => 'Brüker dooten',
 'prefs-rc'                    => 'Leeste änringe',
 'prefs-watchlist-days-max'    => 'Ai lunger as 7 deege',
@@ -970,6 +975,7 @@ Stal sääker, dåt jü färsjoonshistoori foon en sid histoorisch koräkt as.',
 'email'                       => 'E-mail',
 'prefs-help-email'            => 'Dü säärst din e-mail-adres ei uundu, oober do könst dü uk nian mädialangen fu, wan dü ans din paaswurd ferjiden heest.',
 'prefs-help-email-others'     => 'Mä ööder brükern könst dü uk auer hör an din brükersidj kontakt apnem. Diarför woort din e-mail-adres ei brükt.',
+'prefs-i18n'                  => 'Spriak',
 'prefs-signature'             => 'Signatuur',
 'prefs-advancedediting'       => 'Ütwided möölikhäide',
 'prefs-advancedrc'            => 'Ütwided möölikhäide',
@@ -988,10 +994,12 @@ Stal sääker, dåt jü färsjoonshistoori foon en sid histoorisch koräkt as.',
 'group-bureaucrat'    => 'Bürokraate',
 'group-suppress'      => 'Oversighter',
 
-'group-user-member'       => 'brüker',
-'group-bot-member'        => 'bot',
-'group-sysop-member'      => 'administraator',
-'group-bureaucrat-member' => 'bürokraat',
+'group-user-member'          => 'brüker',
+'group-autoconfirmed-member' => 'Registriirde brükere',
+'group-bot-member'           => 'bot',
+'group-sysop-member'         => 'administraator',
+'group-bureaucrat-member'    => 'bürokraat',
+'group-suppress-member'      => 'oversighter',
 
 'grouppage-user'          => '{{ns:project}}:Brükere',
 'grouppage-autoconfirmed' => '{{ns:project}}:Registriirde brükere',
