@@ -41,100 +41,101 @@ $namespaceAliases = array(
 );
 
 $specialPageAliases = array(
-	'DoubleRedirects'           => array( 'RedireksyonDoub' ),
+	'Activeusers'               => array( 'ItilizatèAktif' ),
+	'Allmessages'               => array( 'ToutMesaj' ),
+	'Allpages'                  => array( 'ToutPaj' ),
+	'Ancientpages'              => array( 'PajAnsyen' ),
+	'Blankpage'                 => array( 'PajVid' ),
+	'Block'                     => array( 'Bloke', 'BlokeIP', 'BlokeItilizatè' ),
+	'Blockme'                   => array( 'BlokeM' ),
+	'Booksources'               => array( 'SousLiv' ),
 	'BrokenRedirects'           => array( 'RedireksyonKase' ),
-	'Disambiguations'           => array( 'Tokay' ),
-	'Userlogin'                 => array( 'Koneksyon' ),
-	'Userlogout'                => array( 'Dekoneksyon' ),
+	'Categories'                => array( 'Kategori' ),
+	'ChangePassword'            => array( 'ChanjeMopas', 'ResètMopas' ),
+	'ComparePages'              => array( 'KonparePaj' ),
+	'Confirmemail'              => array( 'VerifyeImèl' ),
+	'Contributions'             => array( 'Kontribisyon', 'Kontrib' ),
 	'CreateAccount'             => array( 'KreyeKont' ),
-	'Preferences'               => array( 'Preferans' ),
-	'Watchlist'                 => array( 'LisSwivi' ),
-	'Recentchanges'             => array( 'ChanjmanResan' ),
-	'Upload'                    => array( 'Chaje' ),
-	'UploadStash'               => array( 'ChajePil' ),
+	'Deadendpages'              => array( 'PajEnpas' ),
+	'DeletedContributions'      => array( 'SiprimeKontribisyon' ),
+	'Disambiguations'           => array( 'Tokay' ),
+	'DoubleRedirects'           => array( 'RedireksyonDoub' ),
+	'Emailuser'                 => array( 'ImèlItilizatè' ),
+	'Export'                    => array( 'Ekspòte' ),
+	'Fewestrevisions'           => array( 'MwensRevizyon' ),
+	'FileDuplicateSearch'       => array( 'ChacheFichyeDoub' ),
+	'Filepath'                  => array( 'ChemenFichye' ),
+	'Import'                    => array( 'Enpòte' ),
+	'Invalidateemail'           => array( 'EnvalideImèl' ),
+	'BlockList'                 => array( 'LisBloke', 'LisIPBloke' ),
+	'LinkSearch'                => array( 'ChacheLyen' ),
+	'Listadmins'                => array( 'LisAdmin' ),
+	'Listbots'                  => array( 'LisWobo' ),
 	'Listfiles'                 => array( 'LisFichye', 'Lis_Fichye', 'LisImaj' ),
-	'Newimages'                 => array( 'NouvoImaj' ),
-	'Listusers'                 => array( 'LisItilizatè' ),
 	'Listgrouprights'           => array( 'LisDwaGwoup' ),
-	'Statistics'                => array( 'Estatistik' ),
-	'Randompage'                => array( 'Oaza', 'PajOaza' ),
+	'Listredirects'             => array( 'LisRedireksyon' ),
+	'Listusers'                 => array( 'LisItilizatè' ),
+	'Lockdb'                    => array( 'KadnaseDB' ),
+	'Log'                       => array( 'Jounal' ),
 	'Lonelypages'               => array( 'PajPoukontli', 'PajOfelen' ),
-	'Uncategorizedpages'        => array( 'PajPakategorize' ),
-	'Uncategorizedcategories'   => array( 'KategoriPakategorize' ),
-	'Uncategorizedimages'       => array( 'ImajPakategorize' ),
-	'Uncategorizedtemplates'    => array( 'ModèlPakategorize' ),
-	'Unusedcategories'          => array( 'KategoriPaItilize' ),
-	'Unusedimages'              => array( 'FichyePaItilize', 'ImajPaItilize' ),
-	'Wantedpages'               => array( 'PajNouBezwen', 'LyenKase' ),
-	'Wantedcategories'          => array( 'KategoriNouBezwen' ),
-	'Wantedfiles'               => array( 'FichyeNouBezwen' ),
-	'Wantedtemplates'           => array( 'ModèlNouBezwen' ),
+	'Longpages'                 => array( 'PajLong' ),
+	'MergeHistory'              => array( 'FizyoneIstwa' ),
+	'MIMEsearch'                => array( 'ChacheMIME' ),
+	'Mostcategories'            => array( 'PlisKategori' ),
+	'Mostimages'                => array( 'ImajPlisLye', 'PlisFichye', 'PlisImaj' ),
 	'Mostlinked'                => array( 'PajPlisLye', 'PlisLye' ),
 	'Mostlinkedcategories'      => array( 'KategoriPlisLye', 'KategoriPlisItilize' ),
 	'Mostlinkedtemplates'       => array( 'ModèlPlisLye', 'ModèlPlisItilize' ),
-	'Mostimages'                => array( 'ImajPlisLye', 'PlisFichye', 'PlisImaj' ),
-	'Mostcategories'            => array( 'PlisKategori' ),
 	'Mostrevisions'             => array( 'PlisRevizyon' ),
-	'Fewestrevisions'           => array( 'MwensRevizyon' ),
-	'Shortpages'                => array( 'PajKout' ),
-	'Longpages'                 => array( 'PajLong' ),
-	'Newpages'                  => array( 'PajNouvo' ),
-	'Ancientpages'              => array( 'PajAnsyen' ),
-	'Deadendpages'              => array( 'PajEnpas' ),
-	'Protectedpages'            => array( 'PajPwoteje' ),
-	'Protectedtitles'           => array( 'TitPwoteje' ),
-	'Allpages'                  => array( 'ToutPaj' ),
-	'Prefixindex'               => array( 'EndèksPrefiks' ),
-	'Ipblocklist'               => array( 'LisBloke', 'LisIPBloke' ),
-	'Unblock'                   => array( 'Debloke' ),
-	'Specialpages'              => array( 'PajEspesyal' ),
-	'Contributions'             => array( 'Kontribisyon', 'Kontrib' ),
-	'Emailuser'                 => array( 'ImèlItilizatè' ),
-	'Confirmemail'              => array( 'VerifyeImèl' ),
-	'Whatlinkshere'             => array( 'SakLye' ),
-	'Recentchangeslinked'       => array( 'LyenChanjmanResan', 'ChanjmanAk' ),
 	'Movepage'                  => array( 'DeplasePaj' ),
-	'Blockme'                   => array( 'BlokeM' ),
-	'Booksources'               => array( 'SousLiv' ),
-	'Categories'                => array( 'Kategori' ),
-	'Export'                    => array( 'Ekspòte' ),
-	'Version'                   => array( 'Vèsyon' ),
-	'Allmessages'               => array( 'ToutMesaj' ),
-	'Log'                       => array( 'Jounal' ),
-	'Blockip'                   => array( 'Bloke', 'BlokeIP', 'BlokeItilizatè' ),
-	'Undelete'                  => array( 'Restore' ),
-	'Import'                    => array( 'Enpòte' ),
-	'Lockdb'                    => array( 'KadnaseDB' ),
-	'Unlockdb'                  => array( 'DekadnaseDB' ),
-	'Userrights'                => array( 'DwaItilizatè', 'FèSysop', 'FèBot' ),
-	'MIMEsearch'                => array( 'ChacheMIME' ),
-	'FileDuplicateSearch'       => array( 'ChacheFichyeDoub' ),
-	'Unwatchedpages'            => array( 'PajPaSiveye' ),
-	'Listredirects'             => array( 'LisRedireksyon' ),
-	'Revisiondelete'            => array( 'RevizyonSiprime' ),
-	'Unusedtemplates'           => array( 'ModèlVyèj' ),
-	'Randomredirect'            => array( 'RedireksyonOaza' ),
+	'Mycontributions'           => array( 'KontribisyonM' ),
 	'Mypage'                    => array( 'PajMwen' ),
 	'Mytalk'                    => array( 'DiskisyonM' ),
-	'Mycontributions'           => array( 'KontribisyonM' ),
 	'Myuploads'                 => array( 'ChajmanM' ),
-	'Listadmins'                => array( 'LisAdmin' ),
-	'Listbots'                  => array( 'LisWobo' ),
+	'Newimages'                 => array( 'NouvoImaj' ),
+	'Newpages'                  => array( 'PajNouvo' ),
+	'PasswordReset'             => array( 'ResètMopas2' ),
+	'PermanentLink'             => array( 'LyenPouToutTan' ),
 	'Popularpages'              => array( 'PajPopilè' ),
+	'Preferences'               => array( 'Preferans' ),
+	'Prefixindex'               => array( 'EndèksPrefiks' ),
+	'Protectedpages'            => array( 'PajPwoteje' ),
+	'Protectedtitles'           => array( 'TitPwoteje' ),
+	'Randompage'                => array( 'Oaza', 'PajOaza' ),
+	'Randomredirect'            => array( 'RedireksyonOaza' ),
+	'Recentchanges'             => array( 'ChanjmanResan' ),
+	'Recentchangeslinked'       => array( 'LyenChanjmanResan', 'ChanjmanAk' ),
+	'Revisiondelete'            => array( 'RevizyonSiprime' ),
+	'RevisionMove'              => array( 'DeplaseRevizyon' ),
 	'Search'                    => array( 'Chache', 'Fouye' ),
-	'Resetpass'                 => array( 'ChanjeMopas', 'ResètMopas' ),
-	'Withoutinterwiki'          => array( 'SanEntèwiki' ),
-	'MergeHistory'              => array( 'FizyoneIstwa' ),
-	'Filepath'                  => array( 'ChemenFichye' ),
-	'Invalidateemail'           => array( 'EnvalideImèl' ),
-	'Blankpage'                 => array( 'PajVid' ),
-	'LinkSearch'                => array( 'ChacheLyen' ),
-	'DeletedContributions'      => array( 'SiprimeKontribisyon' ),
+	'Shortpages'                => array( 'PajKout' ),
+	'Specialpages'              => array( 'PajEspesyal' ),
+	'Statistics'                => array( 'Estatistik' ),
 	'Tags'                      => array( 'Etikèt' ),
-	'Activeusers'               => array( 'ItilizatèAktif' ),
-	'ComparePages'              => array( 'KonparePaj' ),
-	'Badtitle'                  => array( 'MovèTit' ),
-	'DisableAccount'            => array( 'DeaktiveKont' ),
+	'Unblock'                   => array( 'Debloke' ),
+	'Uncategorizedcategories'   => array( 'KategoriPakategorize' ),
+	'Uncategorizedimages'       => array( 'ImajPakategorize' ),
+	'Uncategorizedpages'        => array( 'PajPakategorize' ),
+	'Uncategorizedtemplates'    => array( 'ModèlPakategorize' ),
+	'Undelete'                  => array( 'Restore' ),
+	'Unlockdb'                  => array( 'DekadnaseDB' ),
+	'Unusedcategories'          => array( 'KategoriPaItilize' ),
+	'Unusedimages'              => array( 'FichyePaItilize', 'ImajPaItilize' ),
+	'Unusedtemplates'           => array( 'ModèlVyèj' ),
+	'Unwatchedpages'            => array( 'PajPaSiveye' ),
+	'Upload'                    => array( 'Chaje' ),
+	'UploadStash'               => array( 'ChajePil' ),
+	'Userlogin'                 => array( 'Koneksyon' ),
+	'Userlogout'                => array( 'Dekoneksyon' ),
+	'Userrights'                => array( 'DwaItilizatè', 'FèSysop', 'FèBot' ),
+	'Version'                   => array( 'Vèsyon' ),
+	'Wantedcategories'          => array( 'KategoriNouBezwen' ),
+	'Wantedfiles'               => array( 'FichyeNouBezwen' ),
+	'Wantedpages'               => array( 'PajNouBezwen', 'LyenKase' ),
+	'Wantedtemplates'           => array( 'ModèlNouBezwen' ),
+	'Watchlist'                 => array( 'LisSwivi' ),
+	'Whatlinkshere'             => array( 'SakLye' ),
+	'Withoutinterwiki'          => array( 'SanEntèwiki' ),
 );
 
 $linkTrail = '/^([a-zàèòÀÈÒ]+)(.*)$/sDu';
@@ -268,15 +269,6 @@ $messages = array(
 'index-category'                 => 'Paj endèkse yo',
 'noindex-category'               => 'Paj ki pa endèkse yo',
 
-'mainpagetext'      => "'''MedyaWiki byen enstale l.'''",
-'mainpagedocfooter' => 'Konsilte [http://meta.wikimedia.org/wiki/Help:Konteni Gid Itilizatè] pou enfòmasyon sou kijan pou w itilize logisyèl wiki a.
-
-== Kijan pou kòmanse ==
-
-* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Lis paramèt yo pou konfigirasyon]
-* [http://www.mediawiki.org/wiki/Manyèl:FAQ MediaWiki FAQ]
-* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce Lis diskisyon ki parèt sou MediaWiki]',
-
 'about'         => 'Apwopo',
 'article'       => 'Atik',
 'newwindow'     => '(Ouvè nan yon lòt fenèt)',
@@ -327,10 +319,10 @@ $messages = array(
 'history'           => 'Istorik paj la',
 'history_short'     => 'Istorik',
 'updatedmarker'     => 'Aktyalize depi dènyè visit mwen',
-'info_short'        => 'Enfòmasyon',
 'printableversion'  => 'Vèsyon ou kapab enprime',
 'permalink'         => 'Lyen pou tout tan',
 'print'             => 'Enprime',
+'view'              => 'Gade',
 'edit'              => 'Modifye',
 'create'            => 'Kreye',
 'editthispage'      => 'Modifye paj sa a',
@@ -338,6 +330,7 @@ $messages = array(
 'delete'            => 'Efase',
 'deletethispage'    => 'Efase paj sa',
 'undelete_short'    => 'Restore {{PLURAL:$1|Yon modifikasyon| $1 modifikasyon yo}}',
+'viewdeleted_short' => 'Gade {{PLURAL:$1|yon modifikasyon ki te efase|$1 modifikasyon yo ki te efase}}',
 'protect'           => 'Pwoteje',
 'protect_change'    => 'Chanje pwoteksyon paj sa',
 'protectthispage'   => 'Pwoteje paj sa',
@@ -421,6 +414,8 @@ $1',
 'toc'                     => 'Kontni yo',
 'showtoc'                 => 'montre',
 'hidetoc'                 => 'kache',
+'collapsible-collapse'    => 'Redui',
+'collapsible-expand'      => 'Etann',
 'thisisdeleted'           => 'Ou vle wè oubyen restore $1 ?',
 'viewdeleted'             => 'Wè $1 ?',
 'restorelink'             => '{{PLURAL:$1|yon revizion efase|$1 revizion efase yo}}',
@@ -514,12 +509,11 @@ Demann : $2',
 'protectedpagetext'    => 'Paj sa pwoteje pou anpeche tout modifikasyon nou ta kapab fè sou li. Gade paj diskisyon sou li pito.',
 'viewsourcetext'       => 'Ou kapab gade epitou modifye kontni atik sa a pou ou travay anlè li :',
 'protectedinterface'   => 'Paj sa ap bay tèks pou entèfas lojisyèl an e li pwoteje pou anpeche move itilizasyon nou ta kapab fè ak li.',
-'editinginterface'     => "'''Pòte atansyon :''' ou ap modifye yon paj ki itilize nan kreyasyon tèks entèfas lojisyèl an. Chanjman yo ap ritounen, li ap depann de kèk sityasyon, nan tout paj ke lòt itilizatè yo kapab wè tou. Pou tradiksyon yo, nap envite w itilize pwojè MediaWiki pou mesaj entènasyonal yo (tradiksyon) nan paj sa [http://translatewiki.net/wiki/Main_Page?setlang=fr translatewiki.net].",
+'editinginterface'     => "'''Pòte atansyon :''' ou ap modifye yon paj ki itilize nan kreyasyon tèks entèfas lojisyèl an. Chanjman yo ap ritounen, li ap depann de kèk sityasyon, nan tout paj ke lòt itilizatè yo kapab wè tou. Pou tradiksyon yo, nap envite w itilize pwojè MediaWiki pou mesaj entènasyonal yo (tradiksyon) nan paj sa [//translatewiki.net/wiki/Main_Page?setlang=fr translatewiki.net].",
 'sqlhidden'            => '(Demann SQL an kache)',
 'cascadeprotected'     => 'Paj sa pwoteje kounye a paske l nan {{PLURAL:$1|paj ki douvan l|paj yo ki douvan l}}, paske {{PLURAL:$1|l te pwoteje|yo te pwoteje}} ak opsyon « pwoteksyon pou tout paj ki nan premye paj an - kaskad » aktive :
 $2',
 'namespaceprotected'   => "Ou pa gen dwa modifye paj nan espas non « '''$1''' ».",
-'customcssjsprotected' => 'Ou pa kapab modifye paj sa paske li manke w kèk otorizasyon; li genyen preferans yon lòt itilizatè.',
 'ns-specialprotected'  => 'Paj yo ki nan espas non « {{ns:special}} » pa kapab modifye.',
 'titleprotected'       => "Tit, sijè sa pwoteje pandan kreyasyon l pa [[User:$1|$1]].
 Rezon li bay yo se « ''$2'' ».",
@@ -565,13 +559,15 @@ Kont ou an kreye. Pa bliye pèsonalize l nan  [[Special:Preferences|preferans ou
 'createaccounterror'         => 'Pa kapab kreye kont: $1',
 'nocookiesnew'               => "Kont itilizatè a kreye, men ou pa konekte. {{SITENAME}} ap itilize koukiz (''cookies'') pou konekte l.Li sanble ou dezaktive fonksyon sa. Tanpri, aktive fonksyon sa epi rekonekte ou ak menm non epi mopas ou yo.",
 'nocookieslogin'             => "{{SITENAME}} ap itilize koukiz (''cookies'') pou li kapab konekte kò l. Men li sanble ou dezaktive l; tanpri, aktive fonksyon sa epi rekonekte w.",
+'nocookiesfornew'            => 'Kont itilizatè pa t kreye poutèt nou pa kapab konnen sous li.
+Asire w koukiz (cookies) yo aktive nan navigatè w, chaje paj la ankò epi eseye ankò.',
 'noname'                     => 'Ou pa bay sistèm an yon non itilizatè ki bon.',
 'loginsuccesstitle'          => 'Ou byen konekte nan sistèm la',
 'loginsuccess'               => 'Ou konekte kounye a nan {{SITENAME}} ak idantifyan sa a « $1 ».',
 'nosuchuser'                 => 'Itilizatè "$1" pa ekziste.
 Majiskil ak miniskil chanje non itilizatè.
 Byen gade ke ou te byen ekri non ou, oubyen [[Special:UserLogin/signup|kreye yon nouvo kont]].',
-'nosuchusershort'            => 'Pa genyen itilizatè ak non « <nowiki>$1</nowiki> » sa a. Byen gade lòtograf ou an.',
+'nosuchusershort'            => 'Pa genyen itilizatè ak non « $1 » sa a. Byen gade lòtograf ou an.',
 'nouserspecified'            => 'Ou dwe mete non itilizatè ou an.',
 'login-userblocked'          => 'Itilizatè sa bloke.  Li pa gendwa konekte.',
 'wrongpassword'              => 'Mopas an pa korèk. Eseye ankò.',
@@ -613,7 +609,7 @@ Pa pòte atansyon pou mesaj sa si kont sa kreye pa erè.',
 # E-mail sending
 'php-mail-error-unknown' => 'Erè nou pa konnen nan fonksyon mail() PHP a.',
 
-# Password reset dialog
+# Change password dialog
 'resetpass'                 => 'Chanje mopas ou an',
 'resetpass_announce'        => 'Ou konekte ou ak yon mopas ki valab yon moman; mopas sa te voye pa imèl. Pou ou kapab fini anrejistreman an, ou dwe mete yon nouvo mopas la :',
 'resetpass_header'          => 'Chanje mopas kont ou an',
@@ -641,8 +637,6 @@ Gendwa ou te deja modifye li oubyen ou te mande yon nouvo mopas tanporè.',
 'extlink_tip'     => 'Lyen andeyò (pa blye prefiks http:// an)',
 'headline_sample' => 'Tèks pou tit',
 'headline_tip'    => 'Sou-tit nivo 2',
-'math_sample'     => 'Antre fòmil ou an isit',
-'math_tip'        => 'Fòmil matematik (LaTeX)',
 'nowiki_sample'   => 'Antre tèks ki pa fòmate a',
 'nowiki_tip'      => 'Pa konte sentaks wiki an',
 'image_tip'       => 'Fichye anndan paj sa',
@@ -720,7 +714,7 @@ Si se paske ou fè yon erè ke ou rive nan paj sa a, klike anlè bouton '''fè b
 Ou mèt [[Special:Search/{{PAGENAME}}|fè yon rechèch, fouye ak non paj sa a]] nan lòt paj yo, oubyen <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} chache jounal modifikasyon yo ki an relasyon ak paj sa] oubyen tou [{{fullurl:{{FULLPAGENAME}}|action=edit}} modifye paj sa]</span>.',
 'noarticletext-nopermission'       => 'Poko genyen tèks nan paj sa a.
 Ou mèt [[Special:Search/{{PAGENAME}}|fè yon rechèch, fouye ak non paj sa a]] nan lòt paj yo, oubyen <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} chache jounal modifikasyon yo ki an relasyon ak paj sa].',
-'userpage-userdoesnotexist'        => 'Kont itilizatè « $1 » sa pa anrejistre. Verifye toutbon ke ou vle kreye paj sa.',
+'userpage-userdoesnotexist'        => 'Kont itilizatè « <nowiki>$1</nowiki> » sa pa anrejistre. Verifye toutbon ke ou vle kreye paj sa.',
 'userpage-userdoesnotexist-view'   => 'Itilizatè "$1" pa ekziste.',
 'blocked-notice-logextract'        => 'Itilizatè sa a bloke kounye a.
 Dènye jounal pou blokaj yo parèt anba kòm referans:',
@@ -1136,10 +1130,8 @@ Gade tou [[Special:WantedCategories|kategori moun mande]].',
 # Watchlist
 'watchlist'         => 'Lis swivi mwen',
 'mywatchlist'       => 'Lis swivi mwen',
-'addedwatch'        => 'Ajoute nan lis swivi',
 'addedwatchtext'    => 'Paj « [[:$1]] » te byen ajoute nan [[Special:Watchlist|lis swivi ou an]].
 Depi kounye a, tout modifikasyon nan paj sa a ak nan paj diskisyon li pral parèt <b>fonse</b> nan [[Special:RecentChanges|lis chanjman ki fèk fèt]] pou ou ka wè yo pi byen.',
-'removedwatch'      => 'Retire nan lis swivi',
 'removedwatchtext'  => 'Paj "[[:$1]]" byen retire nan [[Special:Watchlist|lis swivi ou an]].',
 'watch'             => 'Swiv',
 'watchthispage'     => 'Swiv paj sa a',
@@ -1157,7 +1149,7 @@ Depi kounye a, tout modifikasyon nan paj sa a ak nan paj diskisyon li pral parè
 'historywarning'        => "'''Atansyon:''' paj w ap efase a genyen yon istorik ki genyen $1 {{PLURAL:$1|revizyon|revizyon yo}} ladan l:",
 'confirmdeletetext'     => 'W ap efase yon paj oubyen yon imaj epi tout vèsyon li yo toutbon nan bazdone a. Tanpri, konfime aksyon enpòtan sa a, ke ou konprann sa w ap fè, epi ke ou fè l nan dwa ak [[{{MediaWiki:Policy-url}}|lwa medyawiki a]].',
 'actioncomplete'        => 'Aksyon an fèt',
-'deletedtext'           => '« <nowiki>$1</nowiki> » efase.
+'deletedtext'           => '« $1 » efase.
 Gade $2 pou wè yon lis efasman resan.',
 'deletedarticle'        => 'efase « [[$1]] »',
 'dellogpage'            => 'Jounal efasman yo',
@@ -1178,7 +1170,7 @@ Gade $2 pou wè yon lis efasman resan.',
 'protectexpiry'               => 'Ekspirasyon:',
 'protect_expiry_invalid'      => 'Dat ou mete a pou li ekspire pa bon',
 'protect_expiry_old'          => 'Dat ekspirasyon an deja pase.',
-'protect-text'                => "Ou mèt konsilte epi modifye nivo pwoteksyon paj '''<nowiki>$1</nowiki>''' isit.",
+'protect-text'                => "Ou mèt konsilte epi modifye nivo pwoteksyon paj '''$1''' isit.",
 'protect-locked-access'       => "Ou pa genyen dwa ki ap pèmèt ou modifye pwoteksyon paj sa a.
 Men reglaj pou paj '''$1''' an kounye a:",
 'protect-cascadeon'           => 'Paj sa a pwoteje kounye a paske li nan {{PLURAL:$1|paj|paj yo}}, ki gen opsyon pwoteksyon "enbrike" aktif. Ou mèt chanje nivo pwoteksyon paj sa a men li pap modifye pwoteksyon enbrike an.',
@@ -1360,11 +1352,10 @@ Li pèmèt retabli vèsyon ki te anvan li epi ajoute yon rezon ki esplike poukis
 'nextdiff'     => 'Modifikasyon swivan →',
 
 # Media information
-'file-info-size'       => '$1 × $2 piksèl, gwosè fichye a : $3, tip MIME li ye : $4',
-'file-nohires'         => '<small>Pa genyen rezolisyon ki pi wo ki disponib.</small>',
-'svg-long-desc'        => 'Fichye SVG, rezolisyon de $1 × $2 piksèl, gwosè fichye : $3',
-'show-big-image'       => 'Pi bon rezolisyon',
-'show-big-image-thumb' => '<small>Lajè apèsi sa a : $1 × $2 piksèl</small>',
+'file-info-size' => '$1 × $2 piksèl, gwosè fichye a : $3, tip MIME li ye : $4',
+'file-nohires'   => '<small>Pa genyen rezolisyon ki pi wo ki disponib.</small>',
+'svg-long-desc'  => 'Fichye SVG, rezolisyon de $1 × $2 piksèl, gwosè fichye : $3',
+'show-big-image' => 'Pi bon rezolisyon',
 
 # Special:NewFiles
 'newimages' => 'Galri pou nouvo fichye yo',
@@ -1388,11 +1379,17 @@ Nenpòt lòt lyen nan menm liy nan konsidere kòm yon eksèpsyon, i.e. paj kote
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength',
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => 'Modifye fichye sa a nan aplikasyon pa ou (ki pa nan sistèm an, sou machin ou pa egzanp).',
-'edit-externally-help' => '(Gade [http://www.mediawiki.org/wiki/Manual:External_editors komand ak enstriksyon yo] pou plis enfòmasyon oubyen pou konnen plis)',
+'edit-externally-help' => '(Gade [//www.mediawiki.org/wiki/Manual:External_editors komand ak enstriksyon yo] pou plis enfòmasyon oubyen pou konnen plis)',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'tout',
