@@ -121,9 +121,6 @@ $messages = array(
 'hidden-category-category' => 'Skjulte klynger',
 'listingcontinuesabbrev'   => 'førtgøte',
 
-'mainpagetext'      => "'''MediaWiki er nu installeret.'''",
-'mainpagedocfooter' => "Se vores engelskspråĝede [http://meta.wikimedia.org/wiki/MediaWiki_localisation dokumentåsje tilpasnenge'm åf æ brugergrænseflade] og [http://meta.wikimedia.org/wiki/MediaWiki_User%27s_Guide æ brugervejlednenge] før åplysnenger åpsætnenge'm og anvendelse.",
-
 'about'         => 'Åm',
 'article'       => 'Ertikel',
 'newwindow'     => '(åbner i et nyt vendue)',
@@ -157,7 +154,6 @@ $messages = array(
 'history'           => 'Skigt',
 'history_short'     => 'Skigte',
 'updatedmarker'     => '(ændret)',
-'info_short'        => 'Informåsje',
 'printableversion'  => 'Utskreftsvelig utgåf',
 'permalink'         => 'Permanent henvesnenge',
 'print'             => 'Udskrev',
@@ -328,7 +324,7 @@ Førespørgsel: $2',
 'loginsuccesstitle'       => 'Du er nu loĝget på',
 'loginsuccess'            => 'Du er nu loĝget på {{SITENAME}} søm "$1".',
 'nosuchuser'              => 'Der er ig\'n bruger ve navnet "$1". Kontrollér æ stavemåde ig\'n, æller brug æ formulår herunder til at åprette en ny brugerkonto.',
-'nosuchusershort'         => 'Der er ig\'n bruger ve navn "<nowiki>$1</nowiki>". Tjek din stavnenge.',
+'nosuchusershort'         => 'Der er ig\'n bruger ve navn "$1". Tjek din stavnenge.',
 'nouserspecified'         => 'Angæv venlegst et brugernavn.',
 'wrongpassword'           => "Den endtastede adgangskode var førkert. Prøv ig'n.",
 'wrongpasswordempty'      => "Du glemte at endtaste password. Prøv ig'n.",
@@ -350,7 +346,7 @@ Du bør loĝge på og ændre din adgangskode straks æfter du harst modtaget æ
 
 Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, skel æ adresse og dens tilhørsførholt til denne bruger bekræftes. Følg venlegst anvesnengerne i denne mail.',
 
-# Password reset dialog
+# Change password dialog
 'retypenew' => 'Gentag ny adgangskode',
 
 # Edit page toolbar
@@ -364,8 +360,6 @@ Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, s
 'extlink_tip'     => 'Utsende henvesnenge (husk http:// førgøret)',
 'headline_sample' => 'Skrevselenger til åverskreft',
 'headline_tip'    => 'Skå 2 åverskreft',
-'math_sample'     => 'Endsæt åpstælsel her (LaTeX)',
-'math_tip'        => 'Matematisk åpstælsel (LaTeX)',
 'nowiki_sample'   => 'Endsæt skrevselenger her søm ekke skal redigær påke wikiskrevselenger',
 'nowiki_tip'      => 'Ekke wikiskrevselenger utse',
 'image_tip'       => 'Endlejret billet',
@@ -628,9 +622,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 # Watchlist
 'watchlist'         => 'Åvervågnengsliste',
 'mywatchlist'       => 'Åvervågnengsliste',
-'addedwatch'        => 'Tilføjet til din åvervågnengsliste',
 'addedwatchtext'    => "Æ side \"[[:\$1]]\" er blevet tilføjet til din [[Special:Watchlist|åvervågningsliste]]. Fremtidige ændrenger til denne side og den tilhørende diskusjeside hvil bleve listet der, og æ side hvil fremstå '''fremhævet''' i'n [[Special:RecentChanges|liste ve de seneste ændrenger]] før at gøre det lettere at finde den. Hves du senere hvilst fjerne'n side frå din åvervågningsliste, så klik \"Fjern åvervågnenge\".",
-'removedwatch'      => 'Fjernet frå åvervågnengsliste',
 'removedwatchtext'  => 'Æ side "[[:$1]]" er blevet fjernet frå din åvervågnengsliste.',
 'watch'             => 'Åvervåg',
 'watchthispage'     => 'Åvervåg side',
@@ -649,7 +641,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 æller et billet sammen ve hæle den tilhørende skigte frå'n database. Bekræft venlegst at du virkelg hvilst gøre dette, at du førstårst konsekvenserne, og at du gør dette i åverensstemmelse ve
 [[{{MediaWiki:Policy-url}}]].",
 'actioncomplete'        => 'Gennemført',
-'deletedtext'           => '"<nowiki>$1</nowiki>" er slettet. Sæg $2 før en førtegnelse åver de nyeste sletnenger.',
+'deletedtext'           => '"$1" er slettet. Sæg $2 før en førtegnelse åver de nyeste sletnenger.',
 'deletedarticle'        => 'slettede "[[$1]]"',
 'dellogpage'            => 'Sletnengslog',
 'deletecomment'         => 'Begrundelse:',
@@ -666,7 +658,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'protectexpiry'               => 'Udløb:',
 'protect_expiry_invalid'      => 'Æ udløbstiid er ugyldeg.',
 'protect_expiry_old'          => "Æ udløbstiid legger i'n førtiid.",
-'protect-text'                => "Her ken beskyttelsesståt før æ side '''<nowiki>$1</nowiki>''' ses og ændres.",
+'protect-text'                => "Her ken beskyttelsesståt før æ side '''$1''' ses og ændres.",
 'protect-locked-access'       => "Den brugerkonto har ekke de nødvendege rettegheder til at æ ændre sidebeskyttelse. Her er de aktuelle beskyttelsesendstellenger før æ side '''„$1“:'''",
 'protect-cascadeon'           => 'Denne side er del åf en nedarvet skrevebeskyttelse. Wen er endeholt i nedenstående {{PLURAL:$1|side|sider}}, søm er skrevebeskyttet ve tilvalg åf "nedarvende sidebeskyttelse" Æ sidebeskyttelse ken ændres før denne side, det påverker dog ekke\'n kaskadespærrenge:',
 'protect-default'             => 'Ål (standård)',
@@ -817,11 +809,10 @@ navn du harst valgt er ekke gyldegt. Vælg et andet navn.',
 'nextdiff'     => 'Gå til næste førskel →',
 
 # Media information
-'file-info-size'       => '$1 × $2 pixel, gøretstørrelse: $3, MIME-senenge: $4',
-'file-nohires'         => '<small>Engen højere åpløsnenge fundet.</small>',
-'svg-long-desc'        => 'SVG gøret, wønetstørrelse $1 × $2 pixel, gøretstørrelse: $3',
-'show-big-image'       => 'Hersenenge i større åpløsnenge',
-'show-big-image-thumb' => '<small>Størrelse åf førhåndsvesnenge: $1 × $2 pixel</small>',
+'file-info-size' => '$1 × $2 pixel, gøretstørrelse: $3, MIME-senenge: $4',
+'file-nohires'   => '<small>Engen højere åpløsnenge fundet.</small>',
+'svg-long-desc'  => 'SVG gøret, wønetstørrelse $1 × $2 pixel, gøretstørrelse: $3',
+'show-big-image' => 'Hersenenge i større åpløsnenge',
 
 # Special:NewFiles
 'newimages' => 'Liste ve de nyeste billeter',
@@ -843,11 +834,17 @@ Kun endholtet åf æ liste (lenjer startende ve *) bliver brugt. Den første hen
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength',
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => "Redigær denne gøret ve'n utsende redigærstøme",
-'edit-externally-help' => 'Se [http://www.mediawiki.org/wiki/Manual:External_editors setup hjælpje] før mære informasje.',
+'edit-externally-help' => 'Se [//www.mediawiki.org/wiki/Manual:External_editors setup hjælpje] før mære informasje.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'åle',
