@@ -59,32 +59,32 @@ $namespaceAliases = array(
 );
 
 $specialPageAliases = array(
-	'Preferences'               => array( 'Dewisyansow' ),
-	'Watchlist'                 => array( 'Rol_golyas' ),
-	'Recentchanges'             => array( 'Chanjyow_a-dhiwedhes' ),
-	'Upload'                    => array( 'Ughcarga' ),
-	'Randompage'                => array( 'FolenDreJons' ),
-	'Wantedpages'               => array( 'FolennowWhansus' ),
-	'Wantedcategories'          => array( 'ClassysWhansus' ),
-	'Wantedfiles'               => array( 'RestrennowWhansus' ),
-	'Wantedtemplates'           => array( 'ScantlynsWhansus' ),
-	'Newpages'                  => array( 'FolennowNowyth' ),
-	'Ancientpages'              => array( 'FolennowCoth' ),
+	'Allmessages'               => array( 'OllMessajow' ),
 	'Allpages'                  => array( 'OllFolennow' ),
-	'Specialpages'              => array( 'FolennowArbennek' ),
+	'Ancientpages'              => array( 'FolennowCoth' ),
+	'Block'                     => array( 'Lettya' ),
+	'Categories'                => array( 'Classys' ),
 	'Contributions'             => array( 'Kevrohow' ),
 	'Emailuser'                 => array( 'EbostyaDevnydhyer' ),
-	'Movepage'                  => array( 'GwayaFolen' ),
-	'Categories'                => array( 'Classys' ),
 	'Export'                    => array( 'Esperthy' ),
-	'Version'                   => array( 'Versyon' ),
-	'Allmessages'               => array( 'OllMessajow' ),
-	'Blockip'                   => array( 'Lettya' ),
 	'Import'                    => array( 'Ymperthy' ),
+	'Movepage'                  => array( 'GwayaFolen' ),
+	'Mycontributions'           => array( 'OwHevrohow' ),
 	'Mypage'                    => array( 'OwFolen' ),
 	'Mytalk'                    => array( 'OwHows' ),
-	'Mycontributions'           => array( 'OwHevrohow' ),
+	'Newpages'                  => array( 'FolennowNowyth' ),
+	'Preferences'               => array( 'Dewisyansow' ),
+	'Randompage'                => array( 'FolenDreJons' ),
+	'Recentchanges'             => array( 'Chanjyow_a-dhiwedhes' ),
 	'Search'                    => array( 'Whilans' ),
+	'Specialpages'              => array( 'FolennowArbennek' ),
+	'Upload'                    => array( 'Ughcarga' ),
+	'Version'                   => array( 'Versyon' ),
+	'Wantedcategories'          => array( 'ClassysWhansus' ),
+	'Wantedfiles'               => array( 'RestrennowWhansus' ),
+	'Wantedpages'               => array( 'FolennowWhansus' ),
+	'Wantedtemplates'           => array( 'ScantlynsWhansus' ),
+	'Watchlist'                 => array( 'Rol_golyas' ),
 );
 
 $messages = array(
@@ -211,10 +211,10 @@ $messages = array(
 'searcharticle'     => 'Ke',
 'history'           => 'Istory an folen',
 'history_short'     => 'Istory',
-'info_short'        => 'Kedhlow',
 'printableversion'  => 'Versyon pryntyadow',
 'permalink'         => 'Kevren fast',
 'print'             => 'Pryntya',
+'view'              => 'Gweles',
 'edit'              => 'Chanjya',
 'create'            => 'Gwruthyl',
 'editthispage'      => 'Chanjya an folen-ma',
@@ -222,6 +222,7 @@ $messages = array(
 'delete'            => 'Dilea',
 'deletethispage'    => 'Dilea an folen-ma',
 'undelete_short'    => 'Disdhilea {{PLURAL:$1|udn janj|$1 chanj}}',
+'viewdeleted_short' => 'Gweles {{PLURAL:$1|udn janj dileys|$1 chanj dileys}}',
 'protect'           => 'Difres',
 'protect_change'    => 'chanjya',
 'protectthispage'   => 'Difres an folen-ma',
@@ -289,6 +290,7 @@ $messages = array(
 'toc'                     => 'Synsys',
 'showtoc'                 => 'disqwedhes',
 'hidetoc'                 => 'cudha',
+'collapsible-expand'      => 'Efany',
 'thisisdeleted'           => 'Gweles po restorya $1?',
 'viewdeleted'             => 'Gweles $1?',
 'restorelink'             => '{{PLURAL:$1|udn janj dileys|$1 chanj dileys}}',
@@ -350,6 +352,7 @@ Na wrewgh nakevy dhe janjya agas [[Special:Preferences|dowisyanjow rag {{SITENAM
 'createaccount'           => 'Formya acont noweth',
 'gotaccount'              => "Eus acont genowgh seulabres? '''$1'''.",
 'gotaccountlink'          => 'Omgelmy',
+'userlogin-resetlink'     => 'Eus nakevys genowgh agas kedhlow omgelmy?',
 'createaccountmail'       => 'der e-bost',
 'createaccountreason'     => 'Acheson:',
 'badretype'               => 'Na wra parya an geryow-tremena an eyl gen y gila.',
@@ -376,7 +379,7 @@ Assayowgh arta.',
 'accountcreatedtext'      => 'Formys ew an acont rag $1.',
 'loginlanguagelabel'      => 'Yeth: $1',
 
-# Password reset dialog
+# Change password dialog
 'resetpass'                 => 'Chanjya ger-tremena',
 'resetpass_header'          => 'Chanjya ger-tremena an acont',
 'oldpassword'               => 'Ger-tremena coth:',
@@ -384,6 +387,10 @@ Assayowgh arta.',
 'resetpass-submit-loggedin' => 'Chanjya an ger-tremena',
 'resetpass-submit-cancel'   => 'Hedhy',
 
+# Special:PasswordReset
+'passwordreset-username' => 'Hanow-usyer:',
+'passwordreset-email'    => 'Trigva ebost:',
+
 # Edit page toolbar
 'bold_sample'     => 'Text tew',
 'bold_tip'        => 'Text tew',
@@ -395,8 +402,6 @@ Assayowgh arta.',
 'extlink_tip'     => 'Kevren a-mes (na nakevowgh an rager http://)',
 'headline_sample' => 'Text an titel',
 'headline_tip'    => 'Pednlinen nivel 2',
-'math_sample'     => 'Keworrewgh an furvel obma',
-'math_tip'        => 'Furvel galcoriethek (LaTeX)',
 'image_tip'       => 'Restren neythys',
 'media_tip'       => 'Kevren restren',
 'sig_tip'         => 'Agas sinans gen stampa-termen',
@@ -794,8 +799,6 @@ En '''tew''' ew folednow eus war agas [[Special:Watchlist|rol golyas]].",
 'watchlist'         => 'Ow rol golyas',
 'mywatchlist'       => 'Ow rol golyas',
 'watchlistfor2'     => 'Rag $1 ($2)',
-'addedwatch'        => "Keworrys dhe'n rol golyas",
-'removedwatch'      => 'Dileys dhort an rol golyas',
 'watch'             => 'Golyas',
 'watchthispage'     => 'Golyas an folen-ma',
 'unwatch'           => 'Diswolyas',
@@ -810,8 +813,8 @@ En '''tew''' ew folednow eus war agas [[Special:Watchlist|rol golyas]].",
 'delete-confirm'        => 'Dilea "$1"',
 'delete-legend'         => 'Dilea',
 'actioncomplete'        => 'An gwryans ew cowlwres',
-'deletedtext'           => '"<nowiki>$1</nowiki>" yw dileys.
-Gwelewgh $2 rag covath a dhileansow a-dhiwedhes.',
+'deletedtext'           => '"$1" yw dileys.
+Gwelowgh $2 rag covadh a dhileanjow a-dhiwedhes.',
 'deletedarticle'        => 'a dhileas "[[$1]]"',
 'dellogpage'            => 'Covnoten dilea',
 'deletecomment'         => 'Acheson:',
@@ -889,7 +892,6 @@ Gwelewgh $2 rag covath a dhileansow a-dhiwedhes.',
 
 # Block/unblock
 'blockip'                    => 'Lettya devnydhyer',
-'ipaddress'                  => 'Trigva IP:',
 'ipadressorusername'         => 'Trigva IP po hanow-usyer:',
 'ipbreason'                  => 'Acheson:',
 'ipbreasonotherlist'         => 'Acheson aral',
@@ -1006,11 +1008,10 @@ Whi a ell gweles hy fednfenten.',
 'nextdiff'     => 'Chanj nowettha →',
 
 # Media information
-'file-info-size'       => '$1 × $2 pixel, mens an restren: $3, sort MIME : $4',
-'file-nohires'         => '<small>Nag eus clerder uhella cavadow.</small>',
-'svg-long-desc'        => 'Restren SVG, $1 × $2 pixel en hanow, mens an restren: $3',
-'show-big-image'       => 'Clerder leun',
-'show-big-image-thumb' => '<small>Mens an ragwel-ma: $1 × $2 pixel</small>',
+'file-info-size' => '$1 × $2 pixel, mens an restren: $3, sort MIME : $4',
+'file-nohires'   => '<small>Nag eus clerder uhella cavadow.</small>',
+'svg-long-desc'  => 'Restren SVG, $1 × $2 pixel en hanow, mens an restren: $3',
+'show-big-image' => 'Clerder leun',
 
 # Special:NewFiles
 'ilsubmit' => 'Whila',
@@ -1035,11 +1036,9 @@ Whi a ell gweles hy fednfenten.',
 'edit-externally' => 'Chanjya an restren-ma dre towlen a-ves',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'oll',
-'imagelistall'     => 'oll',
-'watchlistall2'    => 'oll',
-'namespacesall'    => 'oll',
-'monthsall'        => 'oll',
+'watchlistall2' => 'oll',
+'namespacesall' => 'oll',
+'monthsall'     => 'oll',
 
 # Trackbacks
 'trackbackremove' => '([$1 Dilea])',
