@@ -25,54 +25,56 @@ $messages = array(
 'tog-rememberpassword' => 'Komíkundola bokitoli na molúki (ekosúkisa na {{PLURAL:$1|mokɔlɔ|mikɔlɔ}} $1)',
 
 # Dates
+'sunday'        => 'Lomíngo',
 'monday'        => 'mokɔlɔ ya libosó',
 'tuesday'       => 'mokɔlɔ ya míbalé',
 'wednesday'     => 'mokɔlɔ ya mísáto',
 'thursday'      => 'mokɔlɔ ya mínei',
 'friday'        => 'mokɔlɔ ya mítáno',
-'sun'           => 'eye',
-'mon'           => 'm1',
-'tue'           => 'm2',
-'wed'           => 'm3',
-'thu'           => 'm4',
-'fri'           => 'm5',
-'sat'           => 'mps',
-'january'       => 'sánzá ya yambo',
-'february'      => 'sánzá ya míbalé',
-'march'         => 'sánzá ya mísáto',
-'april'         => 'sánzá ya mínei',
-'may_long'      => 'sánzá ya mítáno',
-'june'          => 'sánzá ya motóbá',
-'july'          => 'sánzá ya nsambo',
-'august'        => 'sánzá ya mwambe',
-'september'     => 'sánzá ya libwá',
-'october'       => 'sánzá ya zómi',
-'november'      => 'sánzá ya zómi na mɔ̌kɔ́',
-'december'      => 'sánzá ya zómi na míbalé',
-'january-gen'   => 'sánzá ya yambo',
-'february-gen'  => 'sánzá ya míbalé',
-'march-gen'     => 'sánzá ya mísáto',
-'april-gen'     => 'sánzá ya mínei',
-'may-gen'       => 'sánzá ya mítáno',
-'june-gen'      => 'sánzá ya motóbá',
-'july-gen'      => 'sánzá ya nsambo',
-'august-gen'    => 'sánzá ya mwambe',
-'september-gen' => 'sánzá ya libwá',
-'october-gen'   => 'sánzá ya zómi',
+'saturday'      => 'Mpɔ́sɔ',
+'sun'           => 'Lom',
+'mon'           => 'Mɔ̌k',
+'tue'           => 'Míb',
+'wed'           => 'Mís',
+'thu'           => 'Mín',
+'fri'           => 'Mít',
+'sat'           => 'Mpɔ́',
+'january'       => 'yanwáli',
+'february'      => 'febwáli',
+'march'         => 'mársi',
+'april'         => 'apríli',
+'may_long'      => 'máyí',
+'june'          => 'yúni',
+'july'          => 'yúli',
+'august'        => 'augústo',
+'september'     => 'sɛtɛ́mbɛ',
+'october'       => 'ɔkɔtɔ́bɛ',
+'november'      => 'novɛ́mbɛ',
+'december'      => 'dɛsɛ́mbɛ',
+'january-gen'   => 'yanwáli',
+'february-gen'  => 'febwáli',
+'march-gen'     => 'mársi',
+'april-gen'     => 'apríli',
+'may-gen'       => 'máyí',
+'june-gen'      => 'yúni',
+'july-gen'      => 'yúli',
+'august-gen'    => 'augústo',
+'september-gen' => 'sɛtɛ́mbɛ',
+'october-gen'   => 'ɔkɔtɔ́bɛ',
 'november-gen'  => 'novɛ́mbɛ',
-'december-gen'  => 'sánzá ya zómi na míbalé',
-'jan'           => 's1',
-'feb'           => 's2',
-'mar'           => 's3',
-'apr'           => 's4',
-'may'           => 's4',
-'jun'           => 's5',
-'jul'           => 's7',
-'aug'           => 's8',
-'sep'           => 's9',
-'oct'           => 's10',
-'nov'           => 's11',
-'dec'           => 's12',
+'december-gen'  => 'dɛsɛ́mbɛ',
+'jan'           => 'Yan',
+'feb'           => 'Feb',
+'mar'           => 'Már',
+'apr'           => 'Apr',
+'may'           => 'Máy',
+'jun'           => 'Yún',
+'jul'           => 'Yúl',
+'aug'           => 'Aug',
+'sep'           => 'Sɛt',
+'oct'           => 'Ɔkɔ',
+'nov'           => 'Nov',
+'dec'           => 'Dɛs',
 
 # Categories related messages
 'pagecategories'        => '{{PLURAL:$1|Katégoli|Katégoli}}',
@@ -547,7 +549,7 @@ Ezalí listɛ́ ya nkásá gudi bizalí  na [[Special:SpecialPages|{{int:special
 'contributions-title' => 'Mosálá mwa mosáleli $1',
 'mycontris'           => 'Nkásá nakomí',
 'contribsub2'         => 'Mpɔ̂ na $1 ($2)',
-'month'               => 'Bandá sánzá (mpé yangó ilekí) :',
+'month'               => 'Bandá sánzá (mpé yangó ilekí):',
 'year'                => 'Bandá mobú (mpé myangó milekí) :',
 
 'sp-contributions-blocklog' => 'zuluná ya botɛ́lɛmisi',
