@@ -10,7 +10,6 @@
  * @author Amdf
  * @author Azim
  * @author Jose77
- * @author Kaganer
  * @author Lifeway
  * @author Сай
  */
@@ -25,8 +24,8 @@ $namespaceNames = array(
 	NS_PROJECT_TALK     => '$1ын_каҥашымаш',
 	NS_FILE             => 'Файл',
 	NS_FILE_TALK        => 'Файл_шотышто_каҥашымаш',
-	NS_TEMPLATE         => 'Ямдылык',
-	NS_TEMPLATE_TALK    => 'Ямдылык_шотышто_каҥашымаш',
+	NS_TEMPLATE         => 'Кышкар',
+	NS_TEMPLATE_TALK    => 'Кышкар_шотышто_каҥашымаш',
 	NS_HELP             => 'Полшык',
 	NS_HELP_TALK        => 'Полшык_шотышто_каҥашымаш',
 	NS_CATEGORY         => 'Категорий',
@@ -35,35 +34,37 @@ $namespaceNames = array(
 
 $namespaceAliases = array(
 	// Fallbacks for all 'ru' namespace aliases
-	'Медиа' => NS_MEDIA,
-	'Служебная' => NS_SPECIAL,
-	'Обсуждение' => NS_TALK,
-	'Участник' => NS_USER,
-	'Обсуждение_участника' => NS_USER_TALK,
+	'Медиа'                              => NS_MEDIA,
+	'Служебная'                          => NS_SPECIAL,
+	'Обсуждение'                         => NS_TALK,
+	'Участник'                           => NS_USER,
+	'Обсуждение_участника'               => NS_USER_TALK,
 	'Обсуждение_{{GRAMMAR:genitive|$1}}' => NS_PROJECT_TALK,
-	'Файл' => NS_FILE,
-	'Обсуждение_файла' => NS_FILE_TALK,
-	'Обсуждение_MediaWiki' => NS_MEDIAWIKI_TALK,
-	'Шаблон' => NS_TEMPLATE,
-	'Обсуждение_шаблона' => NS_TEMPLATE_TALK,
-	'Справка' => NS_HELP,
-	'Обсуждение_справки' => NS_HELP_TALK,
-	'Категория' => NS_CATEGORY,
-	'Обсуждение_категории' => NS_CATEGORY_TALK,
+	'Файл'                               => NS_FILE,
+	'Обсуждение_файла'                   => NS_FILE_TALK,
+	'Обсуждение_MediaWiki'               => NS_MEDIAWIKI_TALK,
+	'Шаблон'                             => NS_TEMPLATE,
+	'Обсуждение_шаблона'                 => NS_TEMPLATE_TALK,
+	'Справка'                            => NS_HELP,
+	'Обсуждение_справки'                 => NS_HELP_TALK,
+	'Категория'                          => NS_CATEGORY,
+	'Обсуждение_категории'               => NS_CATEGORY_TALK,
 
 	// Namspace changes
-	'Файлын_каҥашымаш' => NS_FILE_TALK,
-	'Ямдылыкын_каҥашымаш' => NS_TEMPLATE_TALK,
-	'Полшыкын_каҥашымаш' => NS_HELP_TALK,
-	'Категорийын_каҥашымаш' => NS_CATEGORY_TALK,
+	'Файлын_каҥашымаш'          => NS_FILE_TALK,
+	'Ямдылык'                   => NS_TEMPLATE,
+	'Ямдылык_шотышто_каҥашымаш' => NS_TEMPLATE_TALK,
+	'Ямдылыкын_каҥашымаш'       => NS_TEMPLATE_TALK,
+	'Полшыкын_каҥашымаш'        => NS_HELP_TALK,
+	'Категорийын_каҥашымаш'     => NS_CATEGORY_TALK,
 );
 
 $specialPageAliases = array(
 	'Preferences'               => array( 'Келыштарымаш' ),
-	'Watchlist'                 => array( 'Эскерымаш_лӱмер' ),
 	'Recentchanges'             => array( 'Пытартыш_тӧрлатымаш-влак' ),
-	'Statistics'                => array( 'Иктешлымаш' ),
 	'Search'                    => array( 'Кычалмаш' ),
+	'Statistics'                => array( 'Иктешлымаш' ),
+	'Watchlist'                 => array( 'Эскерымаш_лӱмер' ),
 );
 
 $magicWords = array(
@@ -176,8 +177,6 @@ $messages = array(
 'category-article-count'   => '{{PLURAL:$2|Тиде категорийыш ик лаштык гына пура.|{{PLURAL:$1|Тыгай $1 лаштык|Тыгане $1 лаштык-влак}} тиде категорийыште, чыла $2.}}',
 'listingcontinuesabbrev'   => '(умбакыжым)',
 
-'mainpagetext' => "'''MediaWiki сай шындыме.'''",
-
 'about'         => 'Нерген',
 'article'       => 'Возымо лаштык',
 'newwindow'     => '(у тӧрзаште почылтеш)',
@@ -356,7 +355,7 @@ $messages = array(
 'nosuchuser'              => '"$1" лӱман пайдаланыше уке.
 Пайдаланышын лӱмыштӧ йӱкпале-влакын кугытшо тӱрыс лийшаш.
 Лӱмым чын возымым терге але [[Special:UserLogin/signup|регистрацийым эрте]].',
-'nosuchusershort'         => '"<nowiki>$1</nowiki>" лӱман пайдаланыше уке.
+'nosuchusershort'         => '"$1" лӱман пайдаланыше уке.
 Лӱмым чын возымым терге.',
 'nouserspecified'         => 'Тылат пайдаланышын лӱмжым пуртыман.',
 'wrongpassword'           => 'Тый йоҥылыш шолыпмутым пуртенат.
@@ -375,13 +374,16 @@ $messages = array(
 'emailauthenticated'      => 'Тыйын почто адресетым пеҥгыдемдыме $2, $3.',
 'loginlanguagelabel'      => 'Йылме: $1',
 
-# Password reset dialog
+# Change password dialog
 'resetpass'                 => 'Шолыпмутым вашталташ',
 'oldpassword'               => 'Тошто шолыпмут:',
 'newpassword'               => 'У шолыпмут:',
 'retypenew'                 => 'Пеҥгыдемдыза у шолыпмутым:',
 'resetpass-submit-loggedin' => 'Шолыпмутым вашталташ',
 
+# Special:PasswordReset
+'passwordreset-username' => 'Пайдаланышын лӱмжӧ',
+
 # Edit page toolbar
 'bold_sample'     => 'Кӱжгӧ текст',
 'bold_tip'        => 'Кӱжгӧ текст',
@@ -393,8 +395,6 @@ $messages = array(
 'extlink_tip'     => 'Ӧрдыж кылвер (http:// префиксым ит мондо)',
 'headline_sample' => 'Вуймут',
 'headline_tip'    => '2-шо кӱкшытан вуймут',
-'math_sample'     => 'Формулым тышке шынде',
-'math_tip'        => 'Математик формул (LaTeX)',
 'nowiki_sample'   => 'Форматироватлыдыме текстым тышке шынде',
 'nowiki_tip'      => 'Вики-форматированийым шотыш налаш огыл',
 'image_tip'       => 'Пуртымо сӱрет',
@@ -537,7 +537,6 @@ $messages = array(
 'changepassword'            => 'Шолыпмутым вашталташ',
 'prefs-skin'                => 'Сӧрастарыме йӧн',
 'skin-preview'              => 'Ончылгоч ончымаш',
-'prefs-math'                => 'Формуло-влак',
 'prefs-datetime'            => 'Кече да жап',
 'prefs-personal'            => 'Пайдаланышын профильже',
 'prefs-rc'                  => 'Шукертсе огыл тӧрлымаш-влак',
@@ -779,10 +778,8 @@ $messages = array(
 # Watchlist
 'watchlist'         => 'Мыйын эскерымаш лӱмер',
 'mywatchlist'       => 'Мыйын эскерымаш лӱмер',
-'addedwatch'        => 'Эскерымаш лӱмерыш ешарыме',
 'addedwatchtext'    => "\"[[:\$1]]\" лаштыкым тыйын [[Special:Watchlist|эскерымаш лӱмерыш]] ешарыме.
 Тиде лаштыкын да тудын каҥашымаш лаштыкым умбакысе тӧрлатымашым тиде спискыште ончыктымо лиеш да, сайрак ужаш манын, [[Special:RecentChanges|пытартыш тӧрлатымаш лӱмерыште]] '''кӱжгӧ шрифт''' дене ойырымо.",
-'removedwatch'      => 'Эскерымаш лӱмер гыч шӧрымӧ',
 'removedwatchtext'  => '«[[:$1]]» лаштыкым [[Special:Watchlist|тыйын эскерыме лӱмер]] гыч кораҥдыме.',
 'watch'             => 'Эскераш',
 'watchthispage'     => 'Тиде лаштыкым эскераш',
@@ -807,7 +804,7 @@ $messages = array(
 'confirmdeletetext'     => 'Тый тиде лаштыкым пӱтынь эртымгорныже дене йӧршын шӧрынет.
 Пеҥгыдемде тидым [[{{MediaWiki:Policy-url}}|правил]] почеш ыштыметым да, мо тидын деч вара лиймым, умылыметым.',
 'actioncomplete'        => 'Ыштыме',
-'deletedtext'           => '«<nowiki>$1</nowiki>» шӧрымӧ.
+'deletedtext'           => '«$1» шӧрымӧ.
 Ончо $2 пытартыш шӧрымӧ-влак лӱмер гыч.',
 'deletedarticle'        => '«[[$1]]» шӧрымӧ',
 'dellogpage'            => 'Шӧрымӧ нерген журнал',
@@ -827,7 +824,7 @@ $messages = array(
 'protectexpiry'               => 'Мучашлалтеш:',
 'protect_expiry_invalid'      => 'Йоҥылыш мучашлалтше жап.',
 'protect_expiry_old'          => 'Мучашлалтше жап эртен.',
-'protect-text'                => "Тыште тый '''<nowiki>$1</nowiki>''' лаштыкын шыгыремдымашыжым ончалаш да тӧрлаташ кертат.",
+'protect-text'                => "Тыште тый '''$1''' лаштыкын шыгыремдымашыжым ончалаш да тӧрлаташ кертат.",
 'protect-locked-access'       => "Тыйын лаштыкын шыгыремдымашыжым тӧрлаш кертмешет шагал.
 Ӱлнӧ '''$1''' лаштыкын кызытсе келыштарымаш.",
 'protect-cascadeon'           => 'Тиде лаштыкым кыдалтше аралтышан {{PLURAL:$1|лаштыкыш, куштыжо|лаштык-влакыш, куштыжо}} пурымылан кӧра кызыт аралыме. Тый тиде лаштыкын шыгыремдымашыжым тӧрлатен кертат, тидын годым кылдалтше аралтыш огеш вашталт.',
@@ -1009,25 +1006,16 @@ $messages = array(
 'tooltip-undo'                    => '"Чараш" тиде тӧрлатымашым мӧҥгешла пӧртыла да ончылгоч ончымашым почеш.
 Тый тӧрлатымаш амалже нерген возымо верыште  возын кертат.',
 
-# Math options
-'mw_math_png'    => 'Эре PNG-ым генерироватлаш',
-'mw_math_simple' => 'Тыглай годым - HTML, уке гын - PNG',
-'mw_math_html'   => 'Лиеш гын - HTML, уке гын - PNG',
-'mw_math_source' => 'TeX-ым разметкыште кодаш (текст браузер-влаклан)',
-'mw_math_modern' => 'Кызытлык (у) брузер-влаклан темлыме',
-'mw_math_mathml' => 'Лиеш гын - MathML (эксперимент опций)',
-
 # Browsing diffs
 'previousdiff' => '← Ондакрак тӧрлатымаш',
 'nextdiff'     => 'Вес тӧрлатымаш →',
 
 # Media information
-'widthheightpage'      => '$1 × $2, $3 {{PLURAL:$3|лаштык|лаштык}}',
-'file-info-size'       => '$1 × $2 пиксел, файлын кугытшо: $3, MIME-тип: $4',
-'file-nohires'         => '<small>Кугурак чаплык уке.</small>',
-'svg-long-desc'        => 'SVG файл, шкенжын кугытшо: $1 × $2 пиксел, файлын кугытшо: $3',
-'show-big-image'       => 'Шкенжын чаплыкше',
-'show-big-image-thumb' => '<small>Ончылгоч ончымашын кугытшо $1 × $2 пиксель</small>',
+'widthheightpage' => '$1×$2, $3 {{PLURAL:$3|лаштык|лаштык}}',
+'file-info-size'  => '$1 × $2 пиксел, файлын кугытшо: $3, MIME-тип: $4',
+'file-nohires'    => '<small>Кугурак чаплык уке.</small>',
+'svg-long-desc'   => 'SVG файл, шкенжын кугытшо: $1 × $2 пиксел, файлын кугытшо: $3',
+'show-big-image'  => 'Шкенжын чаплыкше',
 
 # Special:NewFiles
 'newimages-legend' => 'Фильтр',
@@ -1047,25 +1035,29 @@ $messages = array(
 Файлым ыштыме деч вара тӧрлымӧ гын, южо данныйже тиде файллан келшыдыме лийын кертеш.',
 'metadata-expand'   => 'Ешартыш рашлык-влакым ончыкташ',
 'metadata-collapse' => 'Ешартыш рашлык-влакым шылташ',
-'metadata-fields'   => 'Тиде лӱмер гыч EXIF кумдыкпале пасу сӱретын лаштыкыште эре ончыкталтеш, посна каласыме огыл гын, вес пасу ок ончыкталт.
+'metadata-fields'   => 'Тиде лӱмер гыч EXIF кумдыкпале алан ойыпын лаштыкыште эре ончыкталтеш, посна каласыме огыл гын, вес алан ок ончыкталт.
 * make
 * model
 * datetimeoriginal
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength',
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => 'Файлым ӧрдыж программыште тӧрлаташ',
-'edit-externally-help' => '(Сайрак палашлан ончал [http://www.mediawiki.org/wiki/Manual:External_editors шындымаш нерген туныктымашым])',
+'edit-externally-help' => '(Сайрак палашлан ончал [//www.mediawiki.org/wiki/Manual:External_editors шындымаш нерген туныктымашым])',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'чыла',
-'imagelistall'     => 'чыла',
-'watchlistall2'    => 'чыла',
-'namespacesall'    => 'чыла',
-'monthsall'        => 'чыла',
+'watchlistall2' => 'чыла',
+'namespacesall' => 'чыла',
+'monthsall'     => 'чыла',
 
 # action=purge
 'confirm_purge_button' => 'Йӧра',
