@@ -288,8 +288,6 @@ $messages = array(
 'extlink_tip'     => 'Тӱнӹш ажедмӓш (префиксӹм идӓ монды  http:// )',
 'headline_sample' => 'Текстӹн лӹмжӹ',
 'headline_tip'    => '2-шы кӱкшӹцӓн тӹнг лӹм',
-'math_sample'     => 'Тишкӹ формулым шӹндӹдӓ',
-'math_tip'        => 'Математика формула (формат LaTeX)',
 'nowiki_sample'   => 'Тишкӹ форматируйымы агыл текствлӓм шӹндӹдӓ',
 'nowiki_tip'      => 'Вики-форматированим мондаш',
 'image_tip'       => 'Кӧргӹш пыртен шӹндӹмӹ файл',
@@ -496,9 +494,7 @@ $messages = array(
 # Watchlist
 'watchlist'         => 'Вӓнгӹмӹ список',
 'mywatchlist'       => 'Вӓнгӹмӹ сирмӓш, список',
-'addedwatch'        => 'Вӓнгӹмӓш списокыш пыртымы',
 'addedwatchtext'    => 'Ӹлӹштӓшӹм«[[:$1]]» тӓмдӓн вӓнгӹмӹ [[Special:Watchlist|ӹлӹштӓшӹшкӹдӓ пыртымы]]. Тидӹ паштек ӹштӹмӹ ӹлӹштӓшӹн вашталтымашвлӓ  ти списокышты анжыктымы дӓ тенгеок кӹжгӹ буквавлӓ доно у вашталтымашвлӓн списокышты пӓлдӹртӹмӹ лиэш[[Special:RecentChanges| пӓлдӹртӹмӹ лит]] нӹнӹм  айыраш куштылгырак лижӹ манын.',
-'removedwatch'      => 'Вӓнгӹмӹ список гӹц карангдымы',
 'removedwatchtext'  => 'Ӹлӹштӓш «[[:$1]]» тӓмдӓн вӓнгӹмӹ ӹлӹштӓшдӓ гӹц [[Special:Watchlist|карангдымы]].',
 'watch'             => 'Вӓнгӓш',
 'watchthispage'     => 'Ти ӹлӹштӓшӹм вӓнгӓш',
@@ -515,7 +511,7 @@ $messages = array(
 'deletepage'            => 'Ӹлӹштӓшӹм карангдаш',
 'confirmdeletetext'     => 'Тӓ ӹлӹштӓшӹн (изображенин) цилӓ информацижӹм  дӓ базышты ылшы вашталтымашвлӓн историм ӹштӹл шуаш ядыда. Пуры лидӓ, дӓ лачокат ма тенге ӹштӹнедӓ, шаналтыда. Махань последствивлӓ тидӹ паштек вычат, ынгылышашлык ылыда дӓ тидӹм  ти кӹдешӹтӹ анжыктымы правилывлӓштӹ анжалда [[{{MediaWiki:Policy-url}}]].',
 'actioncomplete'        => 'Лачокат ӹштӹмӹ',
-'deletedtext'           => '«<nowiki>$1</nowiki>» карангдымы.
+'deletedtext'           => '«$1» карангдымы.
 Анжы: $2 тидӹ мам карангдымы тӹ списокым анжыкта',
 'deletedarticle'        => '«[[$1]]» карангдымы',
 'dellogpage'            => 'Мам карангдымы анжыктышы сирмӓш',
@@ -534,7 +530,7 @@ $messages = array(
 'protectexpiry'               => 'Жепшӹ пӹтӓ:',
 'protect_expiry_invalid'      => 'Ӹшӹклӹмӹ жепӹм самынь анжыктымы.',
 'protect_expiry_old'          => 'Пӹтӹм жепшӹ эртен',
-'protect-text'                => "Тиштӹ тӓ ӹлӹштӓшӹн ӹшӹклӹмӹ кӱкшӹцшӹм анжал дӓ вашталтен кердӹдӓ'''<nowiki>$1</nowiki>'''.",
+'protect-text'                => "Тиштӹ тӓ ӹлӹштӓшӹн ӹшӹклӹмӹ кӱкшӹцшӹм анжал дӓ вашталтен кердӹдӓ'''$1'''.",
 'protect-locked-access'       => "Тӓмдӓн учетный карточкыдан ӹшӹклӹмӓш кӱкшӹцӹм вашталташ манын ситӓлык праважы уке. Ти ӹлӹштӓшӹм шӹндӹдӓ'''$1''':",
 'protect-cascadeon'           => 'Ти ӹлӹштӓшӹм {{PLURAL:$1|-шкы пыртымат, ӹшӹклӓлтеш, кыды ӱлнӹрӓк ылшы ӹлӹштӓшӹш|ӹлӹштӓшвлӓшкӹ ажедеш, кышкы }} каскадан ӹшӹклӹмашӹм шӹндӹмӹ. Тӓ ти ӹлӹштӓшӹн ӹшӹклӹмӹ кӱкшӹцшӹм вашталтен кердӹдӓ, но тидӹ каскадан ӹшӹклӹмашӹм ак тӹкӓл лиэш.',
 'protect-default'             => 'Ӹшӹклӹмӹ агыл',
@@ -692,11 +688,10 @@ $messages = array(
 'nextdiff'     => 'Вес тӧрлӹмӓш →',
 
 # Media information
-'file-info-size'       => '$1 × $2 пиксел,  файлын размержӹ: $3, MIME-тип: $4',
-'file-nohires'         => '<small>Кого разрешени доно верси уке.</small>',
-'svg-long-desc'        => 'SVG-файл, номинально $1 × $2 пиксель,  файлын размержӹ: $3',
-'show-big-image'       => 'Кӱкшӹрӓк разрешениӓн изображени',
-'show-big-image-thumb' => '<small>Размер анзыц анжымы годым: $1 × $2 пиксель</small>',
+'file-info-size' => '$1 × $2 пиксел,  файлын размержӹ: $3, MIME-тип: $4',
+'file-nohires'   => '<small>Кого разрешени доно верси уке.</small>',
+'svg-long-desc'  => 'SVG-файл, номинально $1 × $2 пиксель,  файлын размержӹ: $3',
+'show-big-image' => 'Кӱкшӹрӓк разрешениӓн изображени',
 
 # Bad image list
 'bad_image_list' => 'Техень форматан лишӓшлык:
@@ -717,11 +712,17 @@ $messages = array(
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength',
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => 'Тӱнӹш программым кычылт, ти файлым тӧрлӓш',
-'edit-externally-help' => '(шукыракым анжал: [http://www.mediawiki.org/wiki/Manual:External_editors установкын правилывлӓжӹ])',
+'edit-externally-help' => '(шукыракым анжал: [//www.mediawiki.org/wiki/Manual:External_editors установкын правилывлӓжӹ])',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'цилӓ',
