@@ -179,8 +179,6 @@ $messages = array(
 'category-file-count'            => "{{PLURAL:$2|Dins cisse categoreye ci, gn a k' ene pådje.|{{PLURAL:$1|Gn a cisse pådje ci|Gn a les $1 pådjes ki shuvèt}} dins cisse categoreye ci, po $2 pådjes å totå.}}",
 'category-file-count-limited'    => "{{PLURAL:$1|Gn a k' cisse pådje cial|Gn a les $1 pådjes ciddé padzo}} dins cisse categoreye ci.",
 
-'mainpagetext' => "'''Li programe Wiki a stî astalé a l' idêye.'''",
-
 'about'         => 'Åd fwait',
 'article'       => 'Årtike',
 'newwindow'     => '(drovant en on novea purnea)',
@@ -212,7 +210,6 @@ $messages = array(
 'history'           => 'Istwere del pådje',
 'history_short'     => 'Istwere',
 'updatedmarker'     => 'candjî dispoy mi dierinne vizite',
-'info_short'        => 'Infôrmåcions',
 'printableversion'  => 'Modêye sicrirece-amiståve',
 'permalink'         => 'Hårdêye viè cisse modêye ci',
 'print'             => 'Imprimer',
@@ -392,7 +389,7 @@ Vosse conte a stî ahivé.
 'nosuchuser'                 => "I g na nou uzeu dizo l' no «$1».
 Verifyîz çou k' vos avoz tapé, oudonbén rimplixhoz les ôtes tchamps
 et clitchîz sol boton po-z ahiver on novea conte.",
-'nosuchusershort'            => "I g na nou uzeu dizo l' no «<nowiki>$1</nowiki>». Verifyîz çou k' vos avoz tapé.",
+'nosuchusershort'            => "I g na nou uzeu dizo l' no «$1». Verifyîz çou k' vos avoz tapé.",
 'nouserspecified'            => "Vos dvoz dner on no d' elodjaedje.",
 'wrongpassword'              => "Li scret ki vs avoz dné est måva. Rissayîz s' i vs plait.",
 'wrongpasswordempty'         => "Vos avoz dné on vude sicret. Rissayîz s' i vs plait.",
@@ -421,7 +418,7 @@ Divant d' poleur evoyî èn ôte emile a ci conte la, vos dvroz shure les instru
 'accountcreatedtext'         => "Li conte d' uzeu «$1» a stî ahivé.",
 'loginlanguagelabel'         => 'Lingaedje: $1',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => 'Vî scret',
 'newpassword' => 'Noû scret',
 'retypenew'   => "Ritapez l' noû scret",
@@ -437,8 +434,6 @@ Divant d' poleur evoyî èn ôte emile a ci conte la, vos dvroz shure les instru
 'extlink_tip'     => 'Difoûtrinne hårdêye (en rovyîz nén di mete «http://» pa dvant)',
 'headline_sample' => 'Tecse di tite',
 'headline_tip'    => 'Tite di 2inme livea',
-'math_sample'     => "Tapez l' formule matematike chal",
-'math_tip'        => 'Formule matematike (LaTeX)',
 'nowiki_sample'   => "Tapez l' tecse nén wiki chal",
 'nowiki_tip'      => 'Èn nén analijhî des côdes wiki, eyet purade les håyner sins fôrmater',
 'image_sample'    => 'Egzimpe.jpg',
@@ -653,7 +648,6 @@ Les ôtes manaedjeus so ç' wiki ci pôront todi vey li contnou catchî eyet l'
 'changepassword'        => "Candjî l' sicret",
 'prefs-skin'            => 'Pea',
 'skin-preview'          => 'vey divant',
-'prefs-math'            => 'Formules matematikes',
 'datedefault'           => 'Nole preferince',
 'prefs-datetime'        => 'Cogne del date',
 'prefs-personal'        => 'Dinêyes da vosse',
@@ -669,8 +663,6 @@ Les ôtes manaedjeus so ç' wiki ci pôront todi vey li contnou catchî eyet l'
 'columns'               => 'Colones',
 'searchresultshead'     => 'Håynaedje des rzultats di cweraedje',
 'resultsperpage'        => 'Nombe di responses a håyner so ene pådje',
-'contextlines'          => 'Nombe di royes a håyner po ene response',
-'contextchars'          => 'Nombe di caracteres di contecse pa roye',
 'recentchangesdays'     => 'Nombe di djoûs po les dierins candjmints:',
 'recentchangescount'    => 'Nombe di tites dins les dierins candjmints',
 'savedprefs'            => 'Vos preferinces ont stî schapêyes.',
@@ -1006,14 +998,12 @@ Do côp, c' est nén possibe di lyi evoyî èn emile.",
 'watchlistanontext'    => 'I vs fåt $1 po vey ou candjî les cayets di vosse djivêye des shuvous.',
 'watchnologin'         => "Vos n' estoz nén elodjî",
 'watchnologintext'     => 'I vs fåt esse [[Special:UserLogin|elodjî]] po pleur candjî vosse djivêye des pådjes a shuve.',
-'addedwatch'           => 'Radjouté ås shuvous',
 'addedwatchtext'       => "Li pådje «<nowiki>$1</nowiki>» a stî radjoutêye a vosse [[Special:Watchlist|djivêye des pådjes a shuve]].
 Tos les candjmints k' i gn årè di cisse pådje chal,
 eyet di si pådje di copene, seront håynés chal, eyet li pådje serè metowe e '''cråssès letes'''
 el [[Special:RecentChanges|djivêye des dierins candjmints]] po k' ça soeye pus åjhey por vos del rimårker.
 
 Si vos vloz bodjî l' pådje foû di vosse djivêye des shuvous, clitchîz so «Èn pus shuve li pådje» dins l' bår di menu sol costé.",
-'removedwatch'         => 'Bodjî foû des shuvous',
 'removedwatchtext'     => 'Li pådje «[[:$1]]» a stî bodjeye foû di vosse djivêye des pådjes a shuve.',
 'watch'                => 'Shuve',
 'watchthispage'        => 'Shuve cisse pådje',
@@ -1057,10 +1047,10 @@ I n\' årè nén d\' ôtes notifiaedjes po ds ôtes candjmints di ç\' minme på
 
 --
 Po candjî l\' apontiaedje di vosse djivêye a shuve, loukîz
-{{fullurl:{{#special:Watchlist}}/edit}}
+{{canonicalurl:{{#special:EditWatchlist}}}}
 
 Po pus d\' aidance:
-{{fullurl:{{ns:help}}:Aidance}}',
+{{canonicalurl:{{ns:help}}:Aidance}}',
 
 # Delete
 'deletepage'        => "Disfacer l' pådje",
@@ -1076,7 +1066,7 @@ Acertinez s' i vs plait ki c' est bén çoula ki vos vloz fé,
 ki vos comprindoz les consecwinces, et ki vos fjhoz çoula
 tot [[{{MediaWiki:Policy-url}}|shuvant les rîles]].",
 'actioncomplete'    => 'Fwait',
-'deletedtext'       => 'Li pådje «<nowiki>$1</nowiki>» a stî disfacêye. Loukîz li $2 po ene
+'deletedtext'       => 'Li pådje «$1» a stî disfacêye. Loukîz li $2 po ene
 djivêye des dierins disfaçaedjes.',
 'deletedarticle'    => 'pådje «[[$1]]» disfacêye',
 'dellogpage'        => 'Djournå des disfaçaedjes',
@@ -1103,7 +1093,7 @@ Li dierin candjmint a stî fwait pa [[User:$3|$3]] ([[User talk:$3|Copene]]).",
 'prot_1movedto2'              => '[[$1]] displaecî viè [[$2]]',
 'protect-legend'              => "Acertinez l' protedjaedje",
 'protectcomment'              => 'Råjhon:',
-'protect-text'                => "Vos ploz droci vey eyet candjî l' livea d' protedjaedje pol pådje '''<nowiki>$1</nowiki>'''.",
+'protect-text'                => "Vos ploz droci vey eyet candjî l' livea d' protedjaedje pol pådje '''$1'''.",
 'protect-default'             => '(prémetou)',
 'protect-level-autoconfirmed' => 'Bloker les uzeus nén eredjîstrés',
 'protect-level-sysop'         => 'Seulmint les manaedjeus',
@@ -1184,7 +1174,6 @@ vandales, et çoula doet esse fwait tot shuvant les
 [[{{MediaWiki:Policy-url}}|rîles]].
 Dinez ene råjhon do blocaedje (eg: dijhoz les pådjes k' ont
 stî vandalijheyes).",
-'ipaddress'                   => "Adresse IP/no d' uzeu",
 'ipadressorusername'          => "Adresse IP ou no d' uzeu",
 'ipbexpiry'                   => 'Tins do blocaedje',
 'ipbreason'                   => 'Råjhon:',
@@ -1200,8 +1189,8 @@ stî vandalijheyes).",
 'ipusubmit'                   => 'Disbloker ciste adresse ci',
 'unblocked'                   => '«[[User:$1|$1]]» a stî disbloké',
 'ipblocklist'                 => "Djivêye d' adresses IP et di nos d' uzeus ki sont blokés",
+'blocklist-reason'            => 'Råjhon',
 'ipblocklist-submit'          => 'Cweri',
-'blocklistline'               => '$1, $2 a bloké $3 ($4)',
 'infiniteblock'               => 'po todi',
 'expiringblock'               => "disk' å $1 $2",
 'blocklink'                   => 'bloker',
@@ -1210,7 +1199,7 @@ stî vandalijheyes).",
 'autoblocker'                 => "Bloké otomaticmint paski vos eployîz li minme adresse IP ki «[[User:$1|$1]]». Råjhon do blocaedje «'''$2'''».",
 'blocklogpage'                => 'Djournå des blocaedjes',
 'blocklogentry'               => '«[[$1]]» a stî bloké po ene termene di $2',
-'blocklogtext'                => "Çouchal, c' est on djournå des blocaedjes eyet disblocaedjes d' uzeus. Les adresses IP blokêyes otomaticmint èn sont nén håynêyes. Loukîz li [[Special:IPBlockList|djivêye des adresses IP blokêyes]] po vey les blocaedjes d' adresses IP do moumint.",
+'blocklogtext'                => "Çouchal, c' est on djournå des blocaedjes eyet disblocaedjes d' uzeus. Les adresses IP blokêyes otomaticmint èn sont nén håynêyes. Loukîz li [[Special:BlockList|djivêye des adresses IP blokêyes]] po vey les blocaedjes d' adresses IP do moumint.",
 'unblocklogentry'             => '«$1» a stî disbloké',
 'range_block_disabled'        => "Li possibilité po les manaedjeus di bloker des fortchetes d' adresses IP a stî dismetowe.",
 'ipb_expiry_invalid'          => 'Tins di blocaedje nén valide.',
@@ -1391,31 +1380,6 @@ Totes les accions di rcopiaedje eterwiki sont metowes e [[Special:Log/import|djo
 'creditspage'      => 'Pådje di credits',
 'nocredits'        => "I n' a pont d' infôrmåcion di credits po cisse pådje ci.",
 
-# Info page
-'infosubtitle'   => 'Infôrmåcions pol pådje',
-'numedits'       => 'Nombe di candjmints (årtike): $1',
-'numtalkedits'   => 'Nombe di candjmints (pådje di copene): $1',
-'numwatchers'    => 'Nombe di shuveus: $1',
-'numauthors'     => "Nombe d' oteurs diferins (årtike): $1",
-'numtalkauthors' => "Nombe d' oteurs diferins (pådje di copene): $1",
-
-# Math options
-'mw_math_png'    => 'Håyner tofer come ene imådje PNG',
-'mw_math_simple' => "Håyner en HTML si c' est foirt simpe, ôtmint e PNG",
-'mw_math_html'   => "Håyner en HTML si c' est possibe, ôtmint e PNG",
-'mw_math_source' => 'El leyî e TeX (po les betchteus e môde tecse)',
-'mw_math_modern' => 'Ricmandé po les betchteus modienes',
-'mw_math_mathml' => "Eployî MathML si c' est possibe (esperimintå)",
-
-# Math errors
-'math_unknown_error'    => 'aroke nén cnoxhowe',
-'math_unknown_function' => 'fonccion nén cnoxhowe',
-'math_syntax_error'     => 'aroke di sintacse',
-'math_image_error'      => 'Li cviersaedje e PNG a fwait berwete; verifyîz ki les programes latex, dvips, gs eyet convert ont stî astalés comifåt',
-'math_bad_tmpdir'       => "Dji n' sai nén scrire ou ahiver l' ridant timporaire po les formules matematikes",
-'math_bad_output'       => "Dji n' sai nén scrire ou ahiver l' ridant po les fitchîs di rexhowe des formules matematikes",
-'math_notexvc'          => 'I manke li fitchî enondåve texvc; lijhoz math/README po-z apontyî.',
-
 # Image deletion
 'deletedrevision' => 'Viye modêye $1 disfacêye',
 
@@ -1424,12 +1388,11 @@ Totes les accions di rcopiaedje eterwiki sont metowes e [[Special:Log/import|djo
 'nextdiff'     => 'Diferinces des candjmints shuvants →',
 
 # Media information
-'mediawarning'         => "'''Asteme''': Ci fitchî chal pôreut esse evirussé, si vos l' enondez vos pôrîz infecter l' sistinme da vosse.",
-'imagemaxsize'         => "Limite pol håynaedje ezès pådjes d' imådje:",
-'thumbsize'            => 'Grandeu po les imådjetes (thumb):',
-'file-info-size'       => '$1 × $2 picsels, groxheur do fitchî: $3, del sôre "MIME": $4',
-'show-big-image'       => 'Pus grande imådje',
-'show-big-image-thumb' => '<small>Grandeur di ci prevoeyaedje ci : $1 × $2 picsels</small>',
+'mediawarning'   => "'''Asteme''': Ci fitchî chal pôreut esse evirussé, si vos l' enondez vos pôrîz infecter l' sistinme da vosse.",
+'imagemaxsize'   => "Limite pol håynaedje ezès pådjes d' imådje:",
+'thumbsize'      => 'Grandeu po les imådjetes (thumb):',
+'file-info-size' => '$1 × $2 picsels, groxheur do fitchî: $3, del sôre "MIME": $4',
+'show-big-image' => 'Pus grande imådje',
 
 # Special:NewFiles
 'newimages'             => 'Galreye des nouvès imådjes',
@@ -1454,7 +1417,13 @@ est raptiti. Les ôtes seront catchîs.
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength",
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude",
 
 # EXIF tags
 'exif-imagewidth'                => 'Lårdjeur',
@@ -1465,7 +1434,6 @@ est raptiti. Les ôtes seront catchîs.
 'exif-samplesperpixel'           => 'Nombe di compôzants',
 'exif-xresolution'               => "Finté d' coûtchî",
 'exif-yresolution'               => "Finté d' astampé",
-'exif-resolutionunit'            => "Unité pol finté d' coûtchî/astampé",
 'exif-datetime'                  => "Date ey eure ki l' fitchî a stî candjî",
 'exif-imagedescription'          => "Tite di l' imådje",
 'exif-make'                      => 'Måke del camera',
@@ -1475,7 +1443,6 @@ est raptiti. Les ôtes seront catchîs.
 'exif-copyright'                 => 'Ditinteu des abondroets',
 'exif-exifversion'               => "Modêye d' exif",
 'exif-colorspace'                => 'Espåce di coleurs',
-'exif-makernote'                 => 'Notes do fabricant',
 'exif-usercomment'               => "Comintaires di l' uzeu",
 'exif-datetimeoriginal'          => 'Date ey eure ki les dnêyes ont stî fwaites',
 'exif-datetimedigitized'         => 'Date ey eure do scanaedje',
@@ -1566,14 +1533,12 @@ est raptiti. Les ôtes seront catchîs.
 
 # External editor support
 'edit-externally'      => "Candjî ç' fitchî ci avou on dfoûtrin programe",
-'edit-externally-help' => "Loukîz les [http://www.mediawiki.org/wiki/Manual:External_editors instruccions d' apontiaedje] po pus di racsegnes.",
+'edit-externally-help' => "Loukîz les [//www.mediawiki.org/wiki/Manual:External_editors instruccions d' apontiaedje] po pus di racsegnes.",
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'totafwait',
-'imagelistall'     => 'totafwait',
-'watchlistall2'    => 'totafwait',
-'namespacesall'    => 'tos',
-'monthsall'        => 'tos',
+'watchlistall2' => 'totafwait',
+'namespacesall' => 'tos',
+'monthsall'     => 'tos',
 
 # E-mail address confirmation
 'confirmemail'            => "Acertinaedje di l' adresse emile",
