@@ -540,7 +540,7 @@ $messages = array(
 'filehist-dimensions'       => 'განზომილებეფ',
 'filehist-filesize'         => 'ფაილიშ ზომა',
 'filehist-comment'          => 'კომენტარ',
-'imagelinks'                => 'ფაილეფიშ რცხუეფ',
+'imagelinks'                => 'ფაილი გჷმორინაფილი რე',
 'linkstoimage'              => 'გეყ’ვენჯი {{PLURAL:$1|ხასილა|ხასილეფ}} მერცხილ რე თე ფაილშა',
 'nolinkstoimage'            => 'ვა რე თე ფაილწკუმა მერსხილ ხასილეფ.',
 'sharedupload'              => 'თე ფაილ რე $1-შე დო შილებე თენა შხვა პროექტეფც ხოლო გიმირინაუფუდასინ',
