@@ -87,19 +87,12 @@ $messages = array(
 'faqpage'        => 'Project:Cam caeuq dap',
 
 # Vector skin
-'vector-action-delete'       => 'Ca',
-'vector-action-move'         => 'Daen',
-'vector-action-protect'      => 'Bauj',
-'vector-namespace-category'  => 'Faendingz',
-'vector-namespace-help'      => 'Yieb bangcoh',
-'vector-namespace-image'     => 'Vwnzgen',
-'vector-namespace-main'      => 'Yieb',
-'vector-namespace-media'     => 'Yieb moizdij',
-'vector-namespace-mediawiki' => 'Siusik',
-'vector-namespace-template'  => 'Mozbanj',
-'vector-view-create'         => 'Laeb',
-'vector-view-edit'           => 'gaij',
-'vector-view-history'        => 'Cazyawj lizsij',
+'vector-action-delete'  => 'Ca',
+'vector-action-move'    => 'Daen',
+'vector-action-protect' => 'Bauj',
+'vector-view-create'    => 'Laeb',
+'vector-view-edit'      => 'gaij',
+'vector-view-history'   => 'Cazyawj lizsij',
 
 'errorpagetitle'   => 'Loengloek',
 'tagline'          => 'okcih {{SITENAME}}',
