@@ -27,12 +27,12 @@ class SkinSimple extends SkinTemplate {
 		$out->addModuleStyles( 'skins.simple' );
 
 		/* Add some userprefs specific CSS styling */
-		global $wgUser, $wgContLang;
+		global $wgUser;
 		$rules = array();
 		$underline = "";
 
 		if ( $wgUser->getOption( 'underline' ) < 2 ) {
-			$underline = "text-decoration: " . $wgUser->getOption( 'underline' ) ? 'underline' : 'none' . ";";
+			$underline = "text-decoration: " . $wgUser->getOption( 'underline' ) ? 'underline !important' : 'none' . ";";
 		}
 
 		/* Also inherits from resourceloader */
@@ -42,10 +42,7 @@ class SkinSimple extends SkinTemplate {
 			$rules[] = "a.stub:after { $underline; }";
 		}
 		$style = implode( "\n", $rules );
-		if ( $wgContLang->getDir() === 'rtl' ) {
-			$style = CSSJanus::transform( $style, true, false );
-		}
-		$out->addInlineStyle( $style );
+		$out->addInlineStyle( $style, 'flip' );
 
 	}
 }
