@@ -50,18 +50,15 @@ window.os_animation_timer = null;
 window.os_enabled = true;
 
 /**
- * <datalist> is a new HTML5 element that allows you to manually supply
- * suggestion lists and have them rendered according to the right platform
- * conventions.  Opera as of version 11 has a fatal problem: the suggestion
- * lags behind what the user types by one keypress.  (Reported as DSK-276870 to
- * Opera's secret bug tracker.)  However, Firefox 4 supports it without
- * problems, so Opera is just blacklisted here.  Ideally we wouldn't blacklist
- * future versions, in case they fix it, but the fallback isn't bad at all and
- * the failure if they don't fix it is very annoying, so in this case we'll
- * blacklist future versions too.
+ * <datalist> is a new HTML5 element that allows you to manually
+ * supply suggestion lists and have them rendered according to the
+ * right platform conventions.  Opera as of version 11 has a fatal
+ * problem: the suggestion lags behind what the user types by one
+ * keypress.  (Reported as DSK-276870 to Opera's secret bug tracker.)
+ * There are also problems with other browsers, including Firefox and
+ * Safari: See bug 31602 for details.
  */
-window.os_use_datalist = 'list' in document.createElement( 'input' )
-	&& $.client.profile().name != 'opera';
+window.os_use_datalist = false;
 
 /** Timeout timer class that will fetch the results */
 window.os_Timer = function( id, r, query ) {
